@@ -834,7 +834,18 @@ ULONG WINAPI UnregisterTraceGuids( TRACEHANDLE RegistrationHandle )
 ULONG WINAPI EventRegister( LPCGUID provider, PENABLECALLBACK callback, PVOID context, PREGHANDLE handle )
 {
     FIXME("%s, %p, %p, %p\n", debugstr_guid(provider), callback, context, handle);
-    return ERROR_CALL_NOT_IMPLEMENTED;
+
+    *handle = 0xdeadbeef;
+    return ERROR_SUCCESS;
+}
+
+/******************************************************************************
+ * EventUnregister [ADVAPI32.@]
+ */
+ULONG WINAPI EventUnregister( REGHANDLE handle )
+{
+    FIXME("%s: stub\n", wine_dbgstr_longlong(handle));
+    return ERROR_SUCCESS;
 }
 
 /******************************************************************************
@@ -847,6 +858,16 @@ BOOLEAN WINAPI EventEnabled( REGHANDLE handle, PCEVENT_DESCRIPTOR descriptor )
     return FALSE;
 }
 
+/******************************************************************************
+ * EventWrite [ADVAPI32.@]
+ */
+ULONG WINAPI EventWrite( REGHANDLE handle, PCEVENT_DESCRIPTOR descriptor, ULONG count,
+                         PEVENT_DATA_DESCRIPTOR data )
+{
+    FIXME("%s, %p, %u, %p: stub\n", wine_dbgstr_longlong(handle), descriptor, count, data);
+    return ERROR_SUCCESS;
+}
+
 /******************************************************************************
  * QueryTraceW [ADVAPI32.@]
  */
@@ -884,3 +905,46 @@ ULONG WINAPI ProcessTrace( PTRACEHANDLE HandleArray, ULONG HandleCount, LPFILETI
     FIXME("%p %u %p %p: stub\n", HandleArray, HandleCount, StartTime, EndTime);
     return ERROR_CALL_NOT_IMPLEMENTED;
 }
+
+/******************************************************************************
+ * TraceMessage [ADVAPI32.@]
+ */
+ULONG WINAPIV TraceMessage( TRACEHANDLE handle, ULONG flags, LPGUID guid, USHORT number, ... )
+{
+    __ms_va_list valist;
+    ULONG ret;
+
+    __ms_va_start( valist, number );
+    ret = TraceMessageVa( handle, flags, guid, number, valist );
+    __ms_va_end( valist );
+    return ret;
+}
+
+/******************************************************************************
+ * TraceMessageVa [ADVAPI32.@]
+ */
+ULONG WINAPI TraceMessageVa( TRACEHANDLE handle, ULONG flags, LPGUID guid, USHORT number,
+                            __ms_va_list args )
+{
+    FIXME("(%s %x %s %d) : stub\n", wine_dbgstr_longlong(handle), flags, debugstr_guid(guid), number);
+    return ERROR_SUCCESS;
+}
+
+/******************************************************************************
+ * CloseTrace [ADVAPI32.@]
+ */
+ULONG WINAPI CloseTrace( TRACEHANDLE handle )
+{
+    FIXME("%s: stub\n", wine_dbgstr_longlong(handle));
+    return ERROR_INVALID_HANDLE;
+}
+
+/******************************************************************************
+ * EnumerateTraceGuids [ADVAPI32.@]
+ */
+ULONG WINAPI EnumerateTraceGuids(PTRACE_GUID_PROPERTIES *propertiesarray,
+                                 ULONG arraycount, PULONG guidcount)
+{
+    FIXME("%p %d %p: stub\n", propertiesarray, arraycount, guidcount);
+    return ERROR_INVALID_PARAMETER;
+}
