@@ -40,7 +40,7 @@
 
 WINE_DEFAULT_DEBUG_CHANNEL(atl);
 
-HINSTANCE hInst;
+DECLSPEC_HIDDEN HINSTANCE hInst;
 
 BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved)
 {
