@@ -995,6 +995,7 @@ HRESULT WINAPI AVIBuildFilterA(LPSTR szFilter, LONG cbFilter, BOOL fSaving)
  */
 HRESULT WINAPI AVIBuildFilterW(LPWSTR szFilter, LONG cbFilter, BOOL fSaving)
 {
+  static const WCHAR all_files[] = { '*','.','*',0,0 };
   static const WCHAR szClsid[] = {'C','L','S','I','D',0};
   static const WCHAR szExtensionFmt[] = {';','*','.','%','s',0};
   static const WCHAR szAVIFileExtensions[] =
@@ -1023,8 +1024,8 @@ HRESULT WINAPI AVIBuildFilterW(LPWSTR szFilter, LONG cbFilter, BOOL fSaving)
 
   /*
    * 1. iterate over HKEY_CLASSES_ROOT\\AVIFile\\Extensions and collect
-   *    extensions and CLSID's
-   * 2. iterate over collected CLSID's and copy its description and its
+   *    extensions and CLSIDs
+   * 2. iterate over collected CLSIDs and copy its description and its
    *    extensions to szFilter if it fits
    *
    * First filter is named "All multimedia files" and its filter is a
@@ -1117,22 +1118,12 @@ HRESULT WINAPI AVIBuildFilterW(LPWSTR szFilter, LONG cbFilter, BOOL fSaving)
 
   /* add "All files" "*.*" filter if enough space left */
   size = LoadStringW(AVIFILE_hModule, IDS_ALLFILES,
-		     szAllFiles, sizeof(szAllFiles)/sizeof(szAllFiles[0])) + 1;
+                     szAllFiles, (sizeof(szAllFiles) - sizeof(all_files))/sizeof(WCHAR)) + 1;
+  memcpy( szAllFiles + size, all_files, sizeof(all_files) );
+  size += sizeof(all_files) / sizeof(WCHAR);
+
   if (cbFilter > size) {
-    int i;
-
-    /* replace '@' with \000 to separate description of filter */
-    for (i = 0; i < size && szAllFiles[i] != 0; i++) {
-      if (szAllFiles[i] == '@') {
-	szAllFiles[i] = 0;
-	break;
-      }
-    }
-      
     memcpy(szFilter, szAllFiles, size * sizeof(szAllFiles[0]));
-    szFilter += size;
-    szFilter[0] = 0;
-
     return AVIERR_OK;
   } else {
     szFilter[0] = 0;
@@ -2150,9 +2141,7 @@ HRESULT WINAPI EditStreamSetInfoA(PAVISTREAM pstream, LPAVISTREAMINFOA asi,
 
   TRACE("(%p,%p,%d)\n", pstream, asi, size);
 
-  if (pstream == NULL)
-    return AVIERR_BADHANDLE;
-  if ((DWORD)size < sizeof(AVISTREAMINFOA))
+  if (size >= 0 && size < sizeof(AVISTREAMINFOA))
     return AVIERR_BADSIZE;
 
   memcpy(&asiw, asi, sizeof(asiw) - sizeof(asiw.szName));
@@ -2173,6 +2162,9 @@ HRESULT WINAPI EditStreamSetInfoW(PAVISTREAM pstream, LPAVISTREAMINFOW asi,
 
   TRACE("(%p,%p,%d)\n", pstream, asi, size);
 
+  if (size >= 0 && size < sizeof(AVISTREAMINFOA))
+    return AVIERR_BADSIZE;
+
   hr = IAVIStream_QueryInterface(pstream, &IID_IAVIEditStream,(LPVOID*)&pEdit);
   if (SUCCEEDED(hr) && pEdit != NULL) {
     hr = IAVIEditStream_SetInfo(pEdit, asi, size);
