@@ -286,6 +286,11 @@ static const struct message delete_focus_seq[] = {
     { 0 }
 };
 
+static const struct message rbuttonup_seq[] = {
+    { WM_RBUTTONUP, sent|wparam|lparam, 0, 0 },
+    { WM_CONTEXTMENU, sent|defwinproc },
+    { 0 }
+};
 
 static HWND
 create_tabcontrol (DWORD style, DWORD mask)
@@ -1254,7 +1259,7 @@ static void test_removeimage(void)
 static void test_delete_selection(void)
 {
     HWND hTab;
-    DWORD ret;
+    INT ret;
 
     hTab = createFilledTabControl(parent_wnd, TCS_FIXEDWIDTH, TCIF_TEXT|TCIF_IMAGE, 4);
     ok(hTab != NULL, "Failed to create tab control\n");
@@ -1312,7 +1317,8 @@ static void test_TCM_SETITEMEXTRA(void)
 
 static void test_TCS_OWNERDRAWFIXED(void)
 {
-    LPARAM lparam, lparam2;
+    LPARAM lparam;
+    ULONG_PTR itemdata, itemdata2;
     TCITEMA item;
     HWND hTab;
     BOOL ret;
@@ -1335,9 +1341,9 @@ static void test_TCS_OWNERDRAWFIXED(void)
     ShowWindow(hTab, SW_SHOW);
     RedrawWindow(hTab, NULL, 0, RDW_UPDATENOW);
 
-    lparam = 0;
-    memset(&lparam, 0xde, 4);
-    ok(g_drawitem.itemData == lparam, "got %lx, expected %lx\n", g_drawitem.itemData, lparam);
+    itemdata = 0;
+    memset(&itemdata, 0xde, 4);
+    ok(g_drawitem.itemData == itemdata, "got 0x%lx, expected 0x%lx\n", g_drawitem.itemData, itemdata);
 
     DestroyWindow(hTab);
 
@@ -1367,7 +1373,8 @@ static void test_TCS_OWNERDRAWFIXED(void)
     ShowWindow(hTab, SW_SHOW);
     RedrawWindow(hTab, NULL, 0, RDW_UPDATENOW);
 
-    ok(*(ULONG_PTR*)g_drawitem.itemData == lparam, "got %lx, expected %lx\n", g_drawitem.itemData, lparam);
+    memset(&itemdata, 0xde, sizeof(ULONG_PTR));
+    ok(*(ULONG_PTR*)g_drawitem.itemData == itemdata, "got 0x%lx, expected 0x%lx\n", g_drawitem.itemData, itemdata);
 
     DestroyWindow(hTab);
 
@@ -1396,11 +1403,27 @@ static void test_TCS_OWNERDRAWFIXED(void)
     ShowWindow(hTab, SW_SHOW);
     RedrawWindow(hTab, NULL, 0, RDW_UPDATENOW);
 
-    lparam = 0;
-    memset(&lparam, 0xde, 4);
-    memset(&lparam2, 0xde, sizeof(LPARAM)-1);
-    ok(g_drawitem.itemData == lparam || broken(g_drawitem.itemData == lparam2) /* win98 */,
-        "got 0x%lx, expected 0x%lx\n", g_drawitem.itemData, lparam);
+    itemdata = itemdata2 = 0;
+    memset(&itemdata, 0xde, 4);
+    memset(&itemdata2, 0xde, sizeof(LPARAM)-1);
+    ok(g_drawitem.itemData == itemdata || broken(g_drawitem.itemData == itemdata2) /* win98 */,
+        "got 0x%lx, expected 0x%lx\n", g_drawitem.itemData, itemdata);
+
+    DestroyWindow(hTab);
+}
+
+static void test_WM_CONTEXTMENU(void)
+{
+    HWND hTab;
+
+    hTab = createFilledTabControl(parent_wnd, TCS_FIXEDWIDTH, TCIF_TEXT|TCIF_IMAGE, 4);
+    ok(hTab != NULL, "Failed to create tab control\n");
+
+    flush_sequences(sequences, NUM_MSG_SEQUENCES);
+
+    SendMessageA(hTab, WM_RBUTTONUP, 0, 0);
+
+    ok_sequence(sequences, TAB_SEQ_INDEX, rbuttonup_seq, "WM_RBUTTONUP response sequence", FALSE);
 
     DestroyWindow(hTab);
 }
@@ -1441,6 +1464,7 @@ START_TEST(tab)
     test_removeimage();
     test_TCM_SETITEMEXTRA();
     test_TCS_OWNERDRAWFIXED();
+    test_WM_CONTEXTMENU();
 
     DestroyWindow(parent_wnd);
 }
