@@ -171,6 +171,8 @@ typedef struct
 #define ICON_HEIGHT 16
 #define ICON_WIDTH  16
 
+#define MAX_TEXT_SIZE_A 80 /* maximum retriving text size by ANSI message */
+
 static LRESULT CALLBACK
 TOOLTIPS_SubclassProc (HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lParam, UINT_PTR uId, DWORD_PTR dwRef);
 
@@ -943,6 +945,22 @@ TOOLTIPS_GetToolFromPoint (const TOOLTIPS_INFO *infoPtr, HWND hwnd, const POINT
     return -1;
 }
 
+static inline void
+TOOLTIPS_CopyInfoT (const TTTOOL_INFO *toolPtr, TTTOOLINFOW *ti, BOOL isW)
+{
+    if (ti->lpszText) {
+        if (toolPtr->lpszText == NULL ||
+            IS_INTRESOURCE(toolPtr->lpszText) ||
+            toolPtr->lpszText == LPSTR_TEXTCALLBACKW)
+            ti->lpszText = toolPtr->lpszText;
+        else if (isW)
+            strcpyW (ti->lpszText, toolPtr->lpszText);
+        else
+            /* ANSI version, the buffer is maximum 80 bytes without null. */
+            WideCharToMultiByte(CP_ACP, 0, toolPtr->lpszText, -1,
+                                (LPSTR)ti->lpszText, MAX_TEXT_SIZE_A, NULL, NULL);
+    }
+}
 
 static BOOL
 TOOLTIPS_IsWindowActive (HWND hwnd)
@@ -1199,8 +1217,7 @@ TOOLTIPS_EnumToolsT (const TOOLTIPS_INFO *infoPtr, UINT uIndex, TTTOOLINFOW *ti,
     ti->uId      = toolPtr->uId;
     ti->rect     = toolPtr->rect;
     ti->hinst    = toolPtr->hinst;
-/*    ti->lpszText = toolPtr->lpszText; */
-    ti->lpszText = NULL;  /* FIXME */
+    TOOLTIPS_CopyInfoT (toolPtr, ti, isW);
 
     if (ti->cbSize >= TTTOOLINFOA_V2_SIZE)
 	ti->lParam = toolPtr->lParam;
@@ -1246,8 +1263,7 @@ TOOLTIPS_GetCurrentToolT (const TOOLTIPS_INFO *infoPtr, TTTOOLINFOW *ti, BOOL is
 	    ti->uFlags   = toolPtr->uFlags;
 	    ti->rect     = toolPtr->rect;
 	    ti->hinst    = toolPtr->hinst;
-/*	    ti->lpszText = toolPtr->lpszText; */
-	    ti->lpszText = NULL;  /* FIXME */
+	    TOOLTIPS_CopyInfoT (toolPtr, ti, isW);
 
 	    if (ti->cbSize >= TTTOOLINFOW_V2_SIZE)
 		ti->lParam = toolPtr->lParam;
@@ -1328,12 +1344,13 @@ TOOLTIPS_GetTextT (const TOOLTIPS_INFO *infoPtr, TTTOOLINFOW *ti, BOOL isW)
 
         /* NB this API is broken, there is no way for the app to determine
            what size buffer it requires nor a way to specify how long the
-           one it supplies is.  We'll assume it's up to INFOTIPSIZE */
+           one it supplies is.  According to the test result, it's up to
+           80 bytes by the ANSI version. */
 
         buffer[0] = '\0';
         TOOLTIPS_GetTipText(infoPtr, nTool, buffer);
         WideCharToMultiByte(CP_ACP, 0, buffer, -1, (LPSTR)ti->lpszText,
-                                                   INFOTIPSIZE, NULL, NULL);
+                                                   MAX_TEXT_SIZE_A, NULL, NULL);
     }
 
     return 0;
@@ -1385,8 +1402,7 @@ TOOLTIPS_GetToolInfoT (const TOOLTIPS_INFO *infoPtr, TTTOOLINFOW *ti, BOOL isW)
     ti->uFlags   = toolPtr->uFlags;
     ti->rect     = toolPtr->rect;
     ti->hinst    = toolPtr->hinst;
-/*    lpToolInfo->lpszText = toolPtr->lpszText; */
-    ti->lpszText = NULL;  /* FIXME */
+    TOOLTIPS_CopyInfoT (toolPtr, ti, isW);
 
     if (ti->cbSize >= TTTOOLINFOW_V2_SIZE)
 	ti->lParam = toolPtr->lParam;
@@ -1420,8 +1436,7 @@ TOOLTIPS_HitTestT (const TOOLTIPS_INFO *infoPtr, LPTTHITTESTINFOW lptthit,
 	lptthit->ti.uId      = toolPtr->uId;
 	lptthit->ti.rect     = toolPtr->rect;
 	lptthit->ti.hinst    = toolPtr->hinst;
-/*	lptthit->ti.lpszText = toolPtr->lpszText; */
-	lptthit->ti.lpszText = NULL;  /* FIXME */
+	TOOLTIPS_CopyInfoT (toolPtr, &lptthit->ti, isW);
 	if (lptthit->ti.cbSize >= TTTOOLINFOW_V2_SIZE)
 	    lptthit->ti.lParam   = toolPtr->lParam;
     }
@@ -2014,7 +2029,7 @@ TOOLTIPS_SetFont (TOOLTIPS_INFO *infoPtr, HFONT hFont, BOOL redraw)
     lf.lfWeight = FW_BOLD;
     infoPtr->hTitleFont = CreateFontIndirectW(&lf);
 
-    if (redraw & (infoPtr->nCurrentTool != -1)) {
+    if (redraw && infoPtr->nCurrentTool != -1) {
 	FIXME("full redraw needed!\n");
     }
 
@@ -2051,7 +2066,7 @@ TOOLTIPS_OnWMGetText (const TOOLTIPS_INFO *infoPtr, WPARAM size, LPWSTR pszText)
 {
     LRESULT res;
 
-    if(!infoPtr->szTipText || !size)
+    if(!size)
         return 0;
 
     res = min(strlenW(infoPtr->szTipText)+1, size);
