@@ -29,6 +29,7 @@
 #  include <linux/input.h>
 #  undef SW_MAX
 #endif
+#include <limits.h>
 #include <errno.h>
 #ifdef HAVE_UNISTD_H
 #  include <unistd.h>
@@ -518,7 +519,7 @@ static HRESULT WINAPI LinuxInputEffectImpl_Start(
 
     event.type = EV_FF;
     event.code = This->effect.id;
-    event.value = dwIterations;
+    event.value = min( dwIterations, INT_MAX );
     if (write(*(This->fd), &event, sizeof(event)) == -1) {
 	FIXME("Unable to write event.  Assuming device disconnected.\n");
 	return DIERR_INPUTLOST;
@@ -779,7 +780,7 @@ static ULONG WINAPI LinuxInputEffectImpl_Release(LPDIRECTINPUTEFFECT iface)
  *      LinuxInputEffect
  */
 
-HRESULT linuxinput_create_effect(
+DECLSPEC_HIDDEN HRESULT linuxinput_create_effect(
 	int* fd,
 	REFGUID rguid,
         struct list *parent_list_entry,
@@ -851,7 +852,7 @@ HRESULT linuxinput_create_effect(
     return DI_OK;
 }
 
-HRESULT linuxinput_get_info_A(
+DECLSPEC_HIDDEN HRESULT linuxinput_get_info_A(
 	int fd,
 	REFGUID rguid,
 	LPDIEFFECTINFOA info)
@@ -885,7 +886,7 @@ HRESULT linuxinput_get_info_A(
     return DI_OK;
 }
 
-HRESULT linuxinput_get_info_W(
+DECLSPEC_HIDDEN HRESULT linuxinput_get_info_W(
 	int fd,
 	REFGUID rguid,
 	LPDIEFFECTINFOW info)
