@@ -467,14 +467,24 @@ static int get_overlap( const dib_info *dst, const RECT *dst_rect,
 }
 
 static DWORD copy_rect( dib_info *dst, const RECT *dst_rect, const dib_info *src, const RECT *src_rect,
-                        HRGN clip, INT rop2 )
+                        const struct clipped_rects *clipped_rects, INT rop2 )
 {
     POINT origin;
-    RECT clipped_rect;
-    const WINEREGION *clip_data;
-    int i, start, end, overlap;
+    const RECT *rects;
+    int i, count, start, end, overlap;
     DWORD and = 0, xor = 0;
 
+    if (clipped_rects)
+    {
+        rects = clipped_rects->rects;
+        count = clipped_rects->count;
+    }
+    else
+    {
+        rects = dst_rect;
+        count = 1;
+    }
+
     switch (rop2)
     {
     case R2_NOT:   and = ~0u;
@@ -482,92 +492,63 @@ static DWORD copy_rect( dib_info *dst, const RECT *dst_rect, const dib_info *src
     case R2_WHITE: xor = ~0u;
         /* fall through */
     case R2_BLACK:
-        if (clip)
-        {
-            clip_data = get_wine_region( clip );
-            for (i = 0; i < clip_data->numRects; i++)
-                if (intersect_rect( &clipped_rect, dst_rect, clip_data->rects + i ))
-                    dst->funcs->solid_rects( dst, 1, &clipped_rect, and, xor );
-            release_wine_region( clip );
-        }
-        else dst->funcs->solid_rects( dst, 1, dst_rect, and, xor );
+        dst->funcs->solid_rects( dst, count, rects, and, xor );
         /* fall through */
     case R2_NOP:
         return ERROR_SUCCESS;
     }
 
-    origin.x = src_rect->left;
-    origin.y = src_rect->top;
     overlap = get_overlap( dst, dst_rect, src, src_rect );
-
-    if (clip == NULL) dst->funcs->copy_rect( dst, dst_rect, src, &origin, rop2, overlap );
-    else
+    if (overlap & OVERLAP_BELOW)
     {
-        clip_data = get_wine_region( clip );
-        if (overlap & OVERLAP_BELOW)
+        if (overlap & OVERLAP_RIGHT)  /* right to left, bottom to top */
         {
-            if (overlap & OVERLAP_RIGHT)  /* right to left, bottom to top */
+            for (i = count - 1; i >= 0; i--)
             {
-                for (i = clip_data->numRects - 1; i >= 0; i--)
-                {
-                    if (intersect_rect( &clipped_rect, dst_rect, clip_data->rects + i ))
-                    {
-                        origin.x = src_rect->left + clipped_rect.left - dst_rect->left;
-                        origin.y = src_rect->top  + clipped_rect.top  - dst_rect->top;
-                        dst->funcs->copy_rect( dst, &clipped_rect, src, &origin, rop2, overlap );
-                    }
-                }
+                origin.x = src_rect->left + rects[i].left - dst_rect->left;
+                origin.y = src_rect->top  + rects[i].top  - dst_rect->top;
+                dst->funcs->copy_rect( dst, &rects[i], src, &origin, rop2, overlap );
             }
-            else  /* left to right, bottom to top */
+        }
+        else  /* left to right, bottom to top */
+        {
+            for (start = count - 1; start >= 0; start = end)
             {
-                for (start = clip_data->numRects - 1; start >= 0; start = end)
-                {
-                    for (end = start - 1; end >= 0; end--)
-                        if (clip_data->rects[start].top != clip_data->rects[end].top) break;
+                for (end = start - 1; end >= 0; end--)
+                    if (rects[start].top != rects[end].top) break;
 
-                    for (i = end + 1; i <= start; i++)
-                    {
-                        if (intersect_rect( &clipped_rect, dst_rect, clip_data->rects + i ))
-                        {
-                            origin.x = src_rect->left + clipped_rect.left - dst_rect->left;
-                            origin.y = src_rect->top  + clipped_rect.top  - dst_rect->top;
-                            dst->funcs->copy_rect( dst, &clipped_rect, src, &origin, rop2, overlap );
-                        }
-                    }
+                for (i = end + 1; i <= start; i++)
+                {
+                    origin.x = src_rect->left + rects[i].left - dst_rect->left;
+                    origin.y = src_rect->top  + rects[i].top  - dst_rect->top;
+                    dst->funcs->copy_rect( dst, &rects[i], src, &origin, rop2, overlap );
                 }
             }
         }
-        else if (overlap & OVERLAP_RIGHT)  /* right to left, top to bottom */
+    }
+    else if (overlap & OVERLAP_RIGHT)  /* right to left, top to bottom */
+    {
+        for (start = 0; start < count; start = end)
         {
-            for (start = 0; start < clip_data->numRects; start = end)
-            {
-                for (end = start + 1; end < clip_data->numRects; end++)
-                    if (clip_data->rects[start].top != clip_data->rects[end].top) break;
+            for (end = start + 1; end < count; end++)
+                if (rects[start].top != rects[end].top) break;
 
-                for (i = end - 1; i >= start; i--)
-                {
-                    if (intersect_rect( &clipped_rect, dst_rect, clip_data->rects + i ))
-                    {
-                        origin.x = src_rect->left + clipped_rect.left - dst_rect->left;
-                        origin.y = src_rect->top  + clipped_rect.top  - dst_rect->top;
-                        dst->funcs->copy_rect( dst, &clipped_rect, src, &origin, rop2, overlap );
-                    }
-                }
-            }
-        }
-        else  /* left to right, top to bottom */
-        {
-            for (i = 0; i < clip_data->numRects; i++)
+            for (i = end - 1; i >= start; i--)
             {
-                if (intersect_rect( &clipped_rect, dst_rect, clip_data->rects + i ))
-                {
-                    origin.x = src_rect->left + clipped_rect.left - dst_rect->left;
-                    origin.y = src_rect->top  + clipped_rect.top  - dst_rect->top;
-                    dst->funcs->copy_rect( dst, &clipped_rect, src, &origin, rop2, overlap );
-                }
+                origin.x = src_rect->left + rects[i].left - dst_rect->left;
+                origin.y = src_rect->top  + rects[i].top  - dst_rect->top;
+                dst->funcs->copy_rect( dst, &rects[i], src, &origin, rop2, overlap );
             }
         }
-        release_wine_region( clip );
+    }
+    else  /* left to right, top to bottom */
+    {
+        for (i = 0; i < count; i++)
+        {
+            origin.x = src_rect->left + rects[i].left - dst_rect->left;
+            origin.y = src_rect->top  + rects[i].top  - dst_rect->top;
+            dst->funcs->copy_rect( dst, &rects[i], src, &origin, rop2, overlap );
+        }
     }
     return ERROR_SUCCESS;
 }
@@ -576,28 +557,17 @@ static DWORD blend_rect( dib_info *dst, const RECT *dst_rect, const dib_info *sr
                          HRGN clip, BLENDFUNCTION blend )
 {
     POINT origin;
-    RECT clipped_rect;
-    const WINEREGION *clip_data;
+    struct clipped_rects clipped_rects;
     int i;
 
-    origin.x = src_rect->left;
-    origin.y = src_rect->top;
-
-    if (clip == NULL) dst->funcs->blend_rect( dst, dst_rect, src, &origin, blend );
-    else
+    if (!get_clipped_rects( dst, dst_rect, clip, &clipped_rects )) return ERROR_SUCCESS;
+    for (i = 0; i < clipped_rects.count; i++)
     {
-        clip_data = get_wine_region( clip );
-        for (i = 0; i < clip_data->numRects; i++)
-        {
-            if (intersect_rect( &clipped_rect, dst_rect, clip_data->rects + i ))
-            {
-                origin.x = src_rect->left + clipped_rect.left - dst_rect->left;
-                origin.y = src_rect->top  + clipped_rect.top  - dst_rect->top;
-                dst->funcs->blend_rect( dst, &clipped_rect, src, &origin, blend );
-            }
-        }
-        release_wine_region( clip );
+        origin.x = src_rect->left + clipped_rects.rects[i].left - dst_rect->left;
+        origin.y = src_rect->top  + clipped_rects.rects[i].top  - dst_rect->top;
+        dst->funcs->blend_rect( dst, &clipped_rects.rects[i], src, &origin, blend );
     }
+    free_clipped_rects( &clipped_rects );
     return ERROR_SUCCESS;
 }
 
@@ -679,7 +649,8 @@ static void get_gradient_triangle_vertices( const GRADIENT_TRIANGLE *tri, const
 static BOOL gradient_rect( dib_info *dib, TRIVERTEX *v, int mode, HRGN clip )
 {
     int i;
-    RECT rect, clipped_rect;
+    struct clipped_rects clipped_rects;
+    RECT rect;
     BOOL ret = TRUE;
 
     if (mode == GRADIENT_FILL_TRIANGLE)
@@ -696,26 +667,13 @@ static BOOL gradient_rect( dib_info *dib, TRIVERTEX *v, int mode, HRGN clip )
         rect.right  = v[1].x;
         rect.bottom = v[1].y;
     }
-    rect.left   = max( rect.left, 0 );
-    rect.top    = max( rect.top, 0 );
-    rect.right  = min( rect.right, dib->width );
-    rect.bottom = min( rect.bottom, dib->height );
 
-    if (clip)
+    if (!get_clipped_rects( dib, &rect, clip, &clipped_rects )) return TRUE;
+    for (i = 0; i < clipped_rects.count; i++)
     {
-        const WINEREGION *clip_data = get_wine_region( clip );
-
-        for (i = 0; i < clip_data->numRects; i++)
-        {
-            if (intersect_rect( &clipped_rect, &rect, clip_data->rects + i ))
-            {
-                if (!(ret = dib->funcs->gradient_rect( dib, &clipped_rect, v, mode ))) break;
-            }
-        }
-        release_wine_region( clip );
+        if (!(ret = dib->funcs->gradient_rect( dib, &clipped_rects.rects[i], v, mode ))) break;
     }
-    else if (!is_rect_empty( &rect )) ret = dib->funcs->gradient_rect( dib, &rect, v, mode );
-
+    free_clipped_rects( &clipped_rects );
     return ret;
 }
 
@@ -757,7 +715,7 @@ static DWORD create_tmp_dib( const dib_info *copy, int width, int height, dib_in
 }
 
 static DWORD execute_rop( dibdrv_physdev *pdev, const RECT *dst_rect, dib_info *src,
-                          const RECT *src_rect, HRGN clip, DWORD rop )
+                          const RECT *src_rect, const struct clipped_rects *clipped_rects, DWORD rop )
 {
     dib_info *dibs[3], *result = src, tmp;
     RECT rects[3];
@@ -800,21 +758,22 @@ static DWORD execute_rop( dibdrv_physdev *pdev, const RECT *dst_rect, dib_info *
         case OP_ARGS(TMP,DST):
             copy_rect( dibs[OP_DST(*opcode)], &rects[OP_DST(*opcode)],
                        dibs[OP_SRC(*opcode)], &rects[OP_SRC(*opcode)],
-                       OP_DST(*opcode) == DST ? clip : NULL, OP_ROP(*opcode) );
+                       OP_DST(*opcode) == DST ? clipped_rects : NULL, OP_ROP(*opcode) );
             break;
         case OP_ARGS(PAT,DST):
+            pdev->brush.rects( pdev, &pdev->brush, dibs[DST], clipped_rects->count, clipped_rects->rects,
+                               OP_ROP(*opcode) );
+            break;
         case OP_ARGS(PAT,SRC):
-            update_brush_rop( pdev, OP_ROP(*opcode) );
-            pdev->brush_rects( pdev, dibs[OP_DST(*opcode)], 1, &rects[OP_DST(*opcode)],
-                               OP_DST(*opcode) == DST ? clip : NULL );
-            update_brush_rop( pdev, GetROP2(pdev->dev.hdc) );
+            pdev->brush.rects( pdev, &pdev->brush, dibs[SRC], 1, &rects[SRC], OP_ROP(*opcode) );
             break;
         }
     }
 
     if (dibs[TMP]) free_dib_info( dibs[TMP] );
 
-    if (result == src) copy_rect( dibs[DST], &rects[DST], dibs[SRC], &rects[SRC], clip, R2_COPYPEN );
+    if (result == src)
+        copy_rect( dibs[DST], &rects[DST], dibs[SRC], &rects[SRC], clipped_rects, R2_COPYPEN );
 
     return ERROR_SUCCESS;
 }
@@ -964,9 +923,10 @@ DWORD dibdrv_PutImage( PHYSDEV dev, HBITMAP hbitmap, HRGN clip, BITMAPINFO *info
                        struct bitblt_coords *dst, DWORD rop )
 {
     dib_info *dib = NULL, stand_alone;
+    struct clipped_rects clipped_rects;
     DWORD ret;
     dib_info src_dib;
-    HRGN saved_clip = NULL;
+    HRGN tmp_rgn = 0;
     dibdrv_physdev *pdev = NULL;
 
     TRACE( "%p %p %p\n", dev, hbitmap, info );
@@ -1009,21 +969,30 @@ DWORD dibdrv_PutImage( PHYSDEV dev, HBITMAP hbitmap, HRGN clip, BITMAPINFO *info
 
     if (!hbitmap)
     {
-        if (clip) saved_clip = add_extra_clipping_region( pdev, clip );
-        clip = pdev->clip;
+        if (clip && pdev->clip)
+        {
+            tmp_rgn = CreateRectRgn( 0, 0, 0, 0 );
+            CombineRgn( tmp_rgn, clip, pdev->clip, RGN_AND );
+            clip = tmp_rgn;
+        }
+        else if (!clip) clip = pdev->clip;
+    }
+
+    if (!get_clipped_rects( dib, &dst->visrect, clip, &clipped_rects ))
+    {
+        ret = ERROR_SUCCESS;
+        goto done;
     }
 
     if (!rop_uses_pat( rop ))
     {
         int rop2 = ((rop >> 16) & 0xf) + 1;
-        ret = copy_rect( dib, &dst->visrect, &src_dib, &src->visrect, clip, rop2 );
+        ret = copy_rect( dib, &dst->visrect, &src_dib, &src->visrect, &clipped_rects, rop2 );
     }
     else
     {
-        ret = execute_rop( pdev, &dst->visrect, &src_dib, &src->visrect, clip, rop );
+        ret = execute_rop( pdev, &dst->visrect, &src_dib, &src->visrect, &clipped_rects, rop );
     }
-
-    if (saved_clip) restore_clipping_region( pdev, saved_clip );
     goto done;
 
 update_format:
@@ -1033,6 +1002,7 @@ update_format:
     ret = ERROR_BAD_FORMAT;
 
 done:
+    if (tmp_rgn) DeleteObject( tmp_rgn );
     if (hbitmap) GDI_ReleaseObj( hbitmap );
     return ret;
 }
@@ -1251,7 +1221,7 @@ DWORD stretch_bitmapinfo( const BITMAPINFO *src_info, void *src_bits, struct bit
             else
             {
                 last_row.top = dst_start.y - v_params.dst_inc;
-                last_row.bottom = dst_start.y;
+                last_row.bottom = last_row.top + 1;
                 this_row = last_row;
                 offset_rect( &this_row, 0, v_params.dst_inc );
                 copy_rect( &dst_dib, &this_row, &dst_dib, &last_row, NULL, R2_COPYPEN );
@@ -1318,8 +1288,8 @@ DWORD gradient_bitmapinfo( const BITMAPINFO *info, void *bits, TRIVERTEX *vert_a
     unsigned int i;
     int y;
     TRIVERTEX vert[3];
+    RECT rc;
     DWORD ret = ERROR_SUCCESS;
-    HRGN tmp_rgn = 0;
 
     init_dib_info_from_bitmapinfo( &dib, info, bits, default_color_table );
 
@@ -1330,9 +1300,11 @@ DWORD gradient_bitmapinfo( const BITMAPINFO *info, void *bits, TRIVERTEX *vert_a
         {
             get_gradient_hrect_vertices( rect, vert_array, dev_pts, vert );
             gradient_rect( &dib, vert, mode, 0 );
-            if (!tmp_rgn) tmp_rgn = CreateRectRgn( vert[0].x, vert[0].y, vert[1].x, vert[1].y );
-            else SetRectRgn( tmp_rgn, vert[0].x, vert[0].y, vert[1].x, vert[1].y );
-            CombineRgn( rgn, rgn, tmp_rgn, RGN_OR );
+            rc.left   = vert[0].x;
+            rc.top    = vert[0].y;
+            rc.right  = vert[1].x;
+            rc.bottom = vert[1].y;
+            add_rect_to_region( rgn, &rc );
         }
         break;
 
@@ -1341,9 +1313,11 @@ DWORD gradient_bitmapinfo( const BITMAPINFO *info, void *bits, TRIVERTEX *vert_a
         {
             get_gradient_vrect_vertices( rect, vert_array, dev_pts, vert );
             gradient_rect( &dib, vert, mode, 0 );
-            if (!tmp_rgn) tmp_rgn = CreateRectRgn( vert[0].x, vert[0].y, vert[1].x, vert[1].y );
-            else SetRectRgn( tmp_rgn, vert[0].x, vert[0].y, vert[1].x, vert[1].y );
-            CombineRgn( rgn, rgn, tmp_rgn, RGN_OR );
+            rc.left   = vert[0].x;
+            rc.top    = vert[0].y;
+            rc.right  = vert[1].x;
+            rc.bottom = vert[1].y;
+            add_rect_to_region( rgn, &rc );
         }
         break;
 
@@ -1353,35 +1327,33 @@ DWORD gradient_bitmapinfo( const BITMAPINFO *info, void *bits, TRIVERTEX *vert_a
             get_gradient_triangle_vertices( tri, vert_array, dev_pts, vert );
             if (gradient_rect( &dib, vert, mode, 0 ))
             {
-                if (!tmp_rgn) tmp_rgn = CreateRectRgn( 0, 0, 0, 0 );
                 for (y = vert[0].y; y < vert[2].y; y++)
                 {
                     int x1, x2 = edge_coord( y, vert[0].x, vert[0].y, vert[2].x, vert[2].y );
                     if (y < vert[1].y) x1 = edge_coord( y, vert[0].x, vert[0].y, vert[1].x, vert[1].y );
                     else x1 = edge_coord( y, vert[1].x, vert[1].y, vert[2].x, vert[2].y );
 
-                    SetRectRgn( tmp_rgn, min(x1,x2), y, max(x1,x2), y + 1 );
-                    CombineRgn( rgn, rgn, tmp_rgn, RGN_OR );
+                    rc.left   = min( x1, x2 );
+                    rc.top    = y;
+                    rc.right  = max( x1, x2 );
+                    rc.bottom = y + 1;
+                    add_rect_to_region( rgn, &rc );
                 }
             }
             else ret = ERROR_INVALID_PARAMETER;
         }
         break;
     }
-    DeleteObject( tmp_rgn );
     return ret;
 }
 
 COLORREF get_pixel_bitmapinfo( const BITMAPINFO *info, void *bits, struct bitblt_coords *src )
 {
     dib_info dib;
-    POINT pt;
     DWORD pixel;
 
     init_dib_info_from_bitmapinfo( &dib, info, bits, default_color_table );
-    pt.x  = src->x;
-    pt.y  = src->y;
-    pixel = dib.funcs->get_pixel( &dib, &pt );
+    pixel = dib.funcs->get_pixel( &dib, src->x, src->y );
     return dib.funcs->pixel_to_colorref( &dib, pixel );
 }
 
