@@ -174,14 +174,17 @@ static inline INT GDI_ROUND(double val)
 typedef struct tagBITMAPOBJ
 {
     GDIOBJHDR           header;
-    BITMAP              bitmap;
+    DIBSECTION          dib;
     SIZE                size;   /* For SetBitmapDimension() */
-    const struct gdi_dc_funcs *funcs; /* DC function table */
-    /* For device-independent bitmaps: */
-    DIBSECTION         *dib;
     RGBQUAD            *color_table;  /* DIB color table if <= 8bpp (always 1 << bpp in size) */
+    const struct gdi_dc_funcs *funcs; /* DC function table */
 } BITMAPOBJ;
 
+static inline BOOL is_bitmapobj_dib( const BITMAPOBJ *bmp )
+{
+    return bmp->dib.dsBmih.biSize != 0;
+}
+
 /* bidi.c */
 
 /* Wine_GCPW Flags */
@@ -208,6 +211,9 @@ extern DWORD stretch_bits( const BITMAPINFO *src_info, struct bitblt_coords *src
                            struct gdi_image_bits *bits, int mode ) DECLSPEC_HIDDEN;
 
 /* brush.c */
+extern void cache_pattern_bits( PHYSDEV physdev, struct brush_pattern *pattern ) DECLSPEC_HIDDEN;
+extern BOOL store_brush_pattern( LOGBRUSH *brush, struct brush_pattern *pattern ) DECLSPEC_HIDDEN;
+extern void free_brush_pattern( struct brush_pattern *pattern ) DECLSPEC_HIDDEN;
 extern BOOL get_brush_bitmap_info( HBRUSH handle, BITMAPINFO *info, void **bits, UINT *usage ) DECLSPEC_HIDDEN;
 
 /* clipping.c */
@@ -318,6 +324,7 @@ extern UINT WINAPI GDIRealizePalette( HDC hdc ) DECLSPEC_HIDDEN;
 extern HPALETTE PALETTE_Init(void) DECLSPEC_HIDDEN;
 
 /* region.c */
+extern BOOL add_rect_to_region( HRGN rgn, const RECT *rect ) DECLSPEC_HIDDEN;
 extern INT mirror_region( HRGN dst, HRGN src, INT width ) DECLSPEC_HIDDEN;
 extern BOOL REGION_FrameRgn( HRGN dest, HRGN src, INT x, INT y ) DECLSPEC_HIDDEN;
 
@@ -430,12 +437,6 @@ static inline void offset_rect( RECT *rect, int offset_x, int offset_y )
     rect->bottom += offset_y;
 }
 
-static inline BOOL pt_in_rect( const RECT *rect, POINT pt )
-{
-    return ((pt.x >= rect->left) && (pt.x < rect->right) &&
-            (pt.y >= rect->top) && (pt.y < rect->bottom));
-}
-
 static inline void get_bounding_rect( RECT *rect, int x, int y, int width, int height )
 {
     rect->left   = x;
@@ -488,12 +489,6 @@ static inline void copy_bitmapinfo( BITMAPINFO *dst, const BITMAPINFO *src )
     memcpy( dst, src, get_dib_info_size( src, DIB_RGB_COLORS ));
 }
 
-static inline const struct gdi_dc_funcs *get_bitmap_funcs( const BITMAPOBJ *bitmap )
-{
-    if( bitmap->dib ) return &dib_driver;
-    return bitmap->funcs;
-}
-
 extern void free_heap_bits( struct gdi_image_bits *bits ) DECLSPEC_HIDDEN;
 
 extern HMODULE gdi32_module DECLSPEC_HIDDEN;
