@@ -112,6 +112,8 @@ static void test_GetRandomRgn(void)
     GetRgnBox(hrgn, &ret_rc);
     if(GetVersion() & 0x80000000)
         OffsetRect(&window_rc, -window_rc.left, -window_rc.top);
+    /* the window may be partially obscured so the region may be smaller */
+    IntersectRect( &window_rc, &ret_rc, &ret_rc );
     ok(EqualRect(&window_rc, &ret_rc) ||
        broken(IsRectEmpty(&ret_rc)), /* win95 */
        "GetRandomRgn %d,%d - %d,%d\n",
