@@ -200,7 +200,7 @@ static HRESULT WINAPI WebBrowser_GetTypeInfo(IWebBrowser2 *iface, UINT iTInfo, L
 
     TRACE("(%p)->(%d %d %p)\n", This, iTInfo, lcid, ppTInfo);
 
-    hres = get_typeinfo(&typeinfo);
+    hres = get_typeinfo(IWebBrowser2_tid, &typeinfo);
     if(FAILED(hres))
         return hres;
 
@@ -220,7 +220,7 @@ static HRESULT WINAPI WebBrowser_GetIDsOfNames(IWebBrowser2 *iface, REFIID riid,
     TRACE("(%p)->(%s %p %d %d %p)\n", This, debugstr_guid(riid), rgszNames, cNames,
           lcid, rgDispId);
 
-    hres = get_typeinfo(&typeinfo);
+    hres = get_typeinfo(IWebBrowser2_tid, &typeinfo);
     if(FAILED(hres))
         return hres;
 
@@ -239,7 +239,7 @@ static HRESULT WINAPI WebBrowser_Invoke(IWebBrowser2 *iface, DISPID dispIdMember
     TRACE("(%p)->(%d %s %d %08x %p %p %p %p)\n", This, dispIdMember, debugstr_guid(riid),
             lcid, wFlags, pDispParams, pVarResult, pExepInfo, puArgErr);
 
-    hres = get_typeinfo(&typeinfo);
+    hres = get_typeinfo(IWebBrowser2_tid, &typeinfo);
     if(FAILED(hres))
         return hres;
 
@@ -251,8 +251,8 @@ static HRESULT WINAPI WebBrowser_Invoke(IWebBrowser2 *iface, DISPID dispIdMember
 static HRESULT WINAPI WebBrowser_GoBack(IWebBrowser2 *iface)
 {
     WebBrowser *This = impl_from_IWebBrowser2(iface);
-    FIXME("(%p)\n", This);
-    return E_NOTIMPL;
+    TRACE("(%p)\n", This);
+    return go_back(&This->doc_host);
 }
 
 static HRESULT WINAPI WebBrowser_GoForward(IWebBrowser2 *iface)
@@ -1143,16 +1143,19 @@ static HRESULT STDMETHODCALLTYPE WBServiceProvider_QueryService(IServiceProvider
 {
     WebBrowser *This = impl_from_IServiceProvider(iface);
 
-    if(*ppv)
-        ppv = NULL;
+    if(IsEqualGUID(&SID_SHTMLWindow, riid)) {
+        TRACE("(%p)->(SID_SHTMLWindow)\n", This);
+        return IHTMLWindow2_QueryInterface(&This->doc_host.html_window.IHTMLWindow2_iface, riid, ppv);
+    }
 
     if(IsEqualGUID(&IID_IBrowserService2, riid)) {
         TRACE("(%p)->(IID_IBrowserService2 return E_FAIL)\n", This);
+        *ppv = NULL;
         return E_FAIL;
     }
 
     FIXME("(%p)->(%s, %s %p)\n", This, debugstr_guid(guidService), debugstr_guid(riid), ppv);
-
+    *ppv = NULL;
     return E_NOINTERFACE;
 }
 
@@ -1249,7 +1252,7 @@ static HRESULT create_webbrowser(int version, IUnknown *outer, REFIID riid, void
     ret->ref = 1;
     ret->version = version;
 
-    DocHost_Init(&ret->doc_host, (IDispatch*)&ret->IWebBrowser2_iface, &DocHostContainerVtbl);
+    DocHost_Init(&ret->doc_host, &ret->IWebBrowser2_iface, &DocHostContainerVtbl);
 
     ret->visible = VARIANT_TRUE;
     ret->menu_bar = VARIANT_TRUE;
