@@ -1032,8 +1032,8 @@ static ULONG get_dns_suffix(WCHAR *suffix, ULONG *len)
     return ERROR_SUCCESS;
 }
 
-ULONG WINAPI GetAdaptersAddresses(ULONG family, ULONG flags, PVOID reserved,
-                                  PIP_ADAPTER_ADDRESSES aa, PULONG buflen)
+ULONG WINAPI DECLSPEC_HOTPATCH GetAdaptersAddresses(ULONG family, ULONG flags, PVOID reserved,
+                                                    PIP_ADAPTER_ADDRESSES aa, PULONG buflen)
 {
     InterfaceIndexTable *table;
     ULONG i, size, dns_server_size, dns_suffix_size, total_size, ret = ERROR_NO_DATA;
@@ -1877,6 +1877,22 @@ DWORD WINAPI GetTcpTable(PMIB_TCPTABLE pTcpTable, PDWORD pdwSize, BOOL bOrder)
     return ret;
 }
 
+/******************************************************************
+ *    GetExtendedTcpTable (IPHLPAPI.@)
+ */
+DWORD WINAPI GetExtendedTcpTable(PVOID pTcpTable, PDWORD pdwSize, BOOL bOrder,
+                                 ULONG ulAf, TCP_TABLE_CLASS TableClass, ULONG Reserved)
+{
+    TRACE("pTcpTable %p, pdwSize %p, bOrder %d, ulAf %u, TableClass %u, Reserved %u\n",
+           pTcpTable, pdwSize, bOrder, ulAf, TableClass, Reserved);
+
+    if (ulAf == AF_INET6 || TableClass != TCP_TABLE_BASIC_ALL)
+    {
+        FIXME("ulAf = %u, TableClass = %u not supportted\n", ulAf, TableClass);
+        return ERROR_NOT_SUPPORTED;
+    }
+    return GetTcpTable(pTcpTable, pdwSize, bOrder);
+}
 
 /******************************************************************
  *    GetUdpTable (IPHLPAPI.@)
@@ -2260,3 +2276,30 @@ DWORD WINAPI PfCreateInterface(DWORD dwName, PFFORWARD_ACTION inAction, PFFORWAR
     FIXME("(%d %d %d %x %x %p) stub\n", dwName, inAction, outAction, bUseLog, bMustBeUnique, ppInterface);
     return ERROR_CALL_NOT_IMPLEMENTED;
 }
+
+/******************************************************************
+ *    GetTcpTable2 (IPHLPAPI.@)
+ */
+ULONG WINAPI GetTcpTable2(PMIB_TCPTABLE2 table, PULONG size, BOOL order)
+{
+    FIXME("pTcpTable2 %p, pdwSize %p, bOrder %d: stub\n", table, size, order);
+    return ERROR_NOT_SUPPORTED;
+}
+
+/******************************************************************
+ *    GetTcp6Table (IPHLPAPI.@)
+ */
+ULONG WINAPI GetTcp6Table(PMIB_TCP6TABLE table, PULONG size, BOOL order)
+{
+    FIXME("pTcp6Table %p, size %p, order %d: stub\n", table, size, order);
+    return ERROR_NOT_SUPPORTED;
+}
+
+/******************************************************************
+ *    GetTcp6Table2 (IPHLPAPI.@)
+ */
+ULONG WINAPI GetTcp6Table2(PMIB_TCP6TABLE2 table, PULONG size, BOOL order)
+{
+    FIXME("pTcp6Table2 %p, size %p, order %d: stub\n", table, size, order);
+    return ERROR_NOT_SUPPORTED;
+}
