@@ -1,5 +1,5 @@
 /*
- * Copyright 2008 Jacek Caban for CodeWeavers
+ * Copyright 2008,2011 Jacek Caban for CodeWeavers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,6 +19,7 @@
 typedef struct _source_elements_t source_elements_t;
 typedef struct _function_expression_t function_expression_t;
 typedef struct _expression_t expression_t;
+typedef struct _statement_t statement_t;
 
 typedef struct _function_declaration_t {
     function_expression_t *expr;
@@ -51,12 +52,17 @@ typedef struct _func_stack {
     X(call,       1, ARG_UINT,   ARG_UINT) \
     X(call_member,1, ARG_UINT,   ARG_UINT) \
     X(carray,     1, ARG_UINT,   0)        \
+    X(case,       0, ARG_ADDR,   0)        \
+    X(cnd_nz,     0, ARG_ADDR,   0)        \
+    X(cnd_z,      0, ARG_ADDR,   0)        \
     X(delete,     1, 0,0)                  \
     X(delete_ident,1,ARG_BSTR,   0)        \
     X(div,        1, 0,0)                  \
-    X(double,     1, ARG_SBL,    0)        \
+    X(double,     1, ARG_DBL,    0)        \
+    X(end_finally,1, 0,0)                  \
     X(eq,         1, 0,0)                  \
     X(eq2,        1, 0,0)                  \
+    X(forin,      0, ARG_ADDR,   0)        \
     X(func,       1, ARG_FUNC,   0)        \
     X(gt,         1, 0,0)                  \
     X(gteq,       1, 0,0)                  \
@@ -66,7 +72,6 @@ typedef struct _func_stack {
     X(instanceof, 1, 0,0)                  \
     X(int,        1, ARG_INT,    0)        \
     X(jmp,        0, ARG_ADDR,   0)        \
-    X(jmp_nz,     0, ARG_ADDR,   0)        \
     X(jmp_z,      0, ARG_ADDR,   0)        \
     X(lshift,     1, 0,0)                  \
     X(lt,         1, 0,0)                  \
@@ -85,17 +90,21 @@ typedef struct _func_stack {
     X(obj_prop,   1, ARG_BSTR,   0)        \
     X(or,         1, 0,0)                  \
     X(pop,        1, 0,0)                  \
+    X(pop_except, 1, 0,0)                  \
+    X(pop_scope,  1, 0,0)                  \
     X(postinc,    1, ARG_INT,    0)        \
     X(preinc,     1, ARG_INT,    0)        \
+    X(push_except,1, ARG_ADDR,   ARG_BSTR) \
+    X(push_scope, 1, 0,0)                  \
     X(regexp,     1, ARG_STR,    ARG_INT)  \
     X(rshift,     1, 0,0)                  \
     X(rshift2,    1, 0,0)                  \
     X(str,        1, ARG_STR,    0)        \
     X(this,       1, 0,0)                  \
-    X(throw,      0, ARG_UINT,   0)        \
-    X(throw_type, 0, ARG_UINT,   ARG_STR) \
+    X(throw,      0, 0,0)                  \
+    X(throw_ref,  0, ARG_UINT,   0)        \
+    X(throw_type, 0, ARG_UINT,   ARG_STR)  \
     X(tonum,      1, 0,0)                  \
-    X(tree,       1, ARG_EXPR,   0)        \
     X(typeof,     1, 0,0)                  \
     X(typeofid,   1, 0,0)                  \
     X(typeofident,1, 0,0)                  \
@@ -103,6 +112,7 @@ typedef struct _func_stack {
     X(ret,        0, 0,0)                  \
     X(sub,        1, 0,0)                  \
     X(undefined,  1, 0,0)                  \
+    X(var_set,    1, ARG_BSTR,   0)        \
     X(void,       1, 0,0)                  \
     X(xor,        1, 0,0)
 
@@ -114,7 +124,6 @@ OP_LIST
 } jsop_t;
 
 typedef union {
-    expression_t *expr;
     BSTR bstr;
     double *dbl;
     LONG lng;
@@ -127,10 +136,11 @@ typedef enum {
     ARG_NONE = 0,
     ARG_ADDR,
     ARG_BSTR,
-    ARG_EXPR,
+    ARG_DBL,
     ARG_FUNC,
     ARG_INT,
-    ARG_STR
+    ARG_STR,
+    ARG_UINT
 } instr_arg_type_t;
 
 typedef struct {
@@ -212,6 +222,8 @@ static inline void scope_addref(scope_chain_t *scope)
     scope->ref++;
 }
 
+typedef struct _except_frame_t except_frame_t;
+
 struct _exec_ctx_t {
     LONG ref;
 
@@ -224,9 +236,10 @@ struct _exec_ctx_t {
     VARIANT *stack;
     unsigned stack_size;
     unsigned top;
+    except_frame_t *except_frame;
 
     unsigned ip;
-    jsexcept_t ei;
+    jsexcept_t *ei;
 };
 
 static inline void exec_addref(exec_ctx_t *ctx)
@@ -238,7 +251,6 @@ void exec_release(exec_ctx_t*) DECLSPEC_HIDDEN;
 HRESULT create_exec_ctx(script_ctx_t*,IDispatch*,jsdisp_t*,scope_chain_t*,BOOL,exec_ctx_t**) DECLSPEC_HIDDEN;
 HRESULT exec_source(exec_ctx_t*,parser_ctx_t*,source_elements_t*,BOOL,jsexcept_t*,VARIANT*) DECLSPEC_HIDDEN;
 
-typedef struct _statement_t statement_t;
 typedef struct _parameter_t parameter_t;
 
 HRESULT create_source_function(parser_ctx_t*,parameter_t*,source_elements_t*,scope_chain_t*,
@@ -278,12 +290,27 @@ typedef struct _variable_declaration_t {
     struct _variable_declaration_t *next;
 } variable_declaration_t;
 
-typedef struct _return_type_t return_type_t;
-
-typedef HRESULT (*statement_eval_t)(script_ctx_t*,statement_t*,return_type_t*,VARIANT*);
+typedef enum {
+    STAT_BLOCK,
+    STAT_BREAK,
+    STAT_CONTINUE,
+    STAT_EMPTY,
+    STAT_EXPR,
+    STAT_FOR,
+    STAT_FORIN,
+    STAT_IF,
+    STAT_LABEL,
+    STAT_RETURN,
+    STAT_SWITCH,
+    STAT_THROW,
+    STAT_TRY,
+    STAT_VAR,
+    STAT_WHILE,
+    STAT_WITH
+} statement_type_t;
 
 struct _statement_t {
-    statement_eval_t eval;
+    statement_type_t type;
     statement_t *next;
 };
 
@@ -375,23 +402,6 @@ typedef struct {
     statement_t *finally_statement;
 } try_statement_t;
 
-HRESULT block_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT var_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT empty_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT expression_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT if_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT while_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT for_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT forin_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT continue_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT break_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT return_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT with_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT labelled_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT switch_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT throw_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-HRESULT try_statement_eval(script_ctx_t*,statement_t*,return_type_t*,VARIANT*) DECLSPEC_HIDDEN;
-
 typedef struct {
     enum {
         EXPRVAL_VARIANT,
@@ -404,7 +414,6 @@ typedef struct {
             IDispatch *disp;
             DISPID id;
         } idref;
-        BSTR identifier;
     } u;
 } exprval_t;
 
@@ -471,7 +480,6 @@ typedef enum {
 
 struct _expression_t {
     expression_type_t type;
-    unsigned instr_off;
 };
 
 struct _parameter_t {
@@ -485,6 +493,7 @@ struct _source_elements_t {
     statement_t *statement_tail;
     function_declaration_t *functions;
     var_list_t *variables;
+    unsigned instr_off;
 };
 
 struct _function_expression_t {
@@ -567,4 +576,4 @@ typedef struct {
     prop_val_t *property_list;
 } property_value_expression_t;
 
-HRESULT compile_subscript(parser_ctx_t*,expression_t*,BOOL,unsigned*) DECLSPEC_HIDDEN;
+HRESULT compile_subscript_stat(parser_ctx_t*,statement_t*,BOOL,unsigned*) DECLSPEC_HIDDEN;
