@@ -160,7 +160,8 @@ static int  get_console_bare_fd(HANDLE hin)
 {
     int         fd;
 
-    if (wine_server_handle_to_fd(wine_server_ptr_handle(console_handle_unmap(hin)),
+    if (is_console_handle(hin) &&
+        wine_server_handle_to_fd(wine_server_ptr_handle(console_handle_unmap(hin)),
                                  0, &fd, NULL) == STATUS_SUCCESS)
         return fd;
     return -1;
@@ -1998,6 +1999,8 @@ static DWORD WINAPI CONSOLE_SendEventThread(void* pmt)
  */
 int     CONSOLE_HandleCtrlC(unsigned sig)
 {
+    HANDLE thread;
+
     /* FIXME: better test whether a console is attached to this process ??? */
     extern    unsigned CONSOLE_GetNumHistoryEntries(void);
     if (CONSOLE_GetNumHistoryEntries() == (unsigned)-1) return 0;
@@ -2014,7 +2017,11 @@ int     CONSOLE_HandleCtrlC(unsigned sig)
          *    console critical section, we need another execution environment where
          *    we can wait on this critical section 
          */
-        CreateThread(NULL, 0, CONSOLE_SendEventThread, (void*)CTRL_C_EVENT, 0, NULL);
+        thread = CreateThread(NULL, 0, CONSOLE_SendEventThread, (void*)CTRL_C_EVENT, 0, NULL);
+        if (thread == NULL)
+            return 0;
+
+        CloseHandle(thread);
     }
     return 1;
 }
@@ -2928,8 +2935,6 @@ BOOL WINAPI SetConsoleDisplayMode(HANDLE hConsoleOutput, DWORD dwFlags,
 /* some missing functions...
  * FIXME: those are likely to be defined as undocumented function in kernel32 (or part of them)
  * should get the right API and implement them
- *	GetConsoleCommandHistory[AW] (dword dword dword)
- *	GetConsoleCommandHistoryLength[AW]
  *	SetConsoleCommandHistoryMode
  *	SetConsoleNumberOfCommands[AW]
  */
@@ -3135,3 +3140,87 @@ BOOL CONSOLE_Exit(void)
     /* the console is in raw mode, put it back in cooked mode */
     return restore_console_mode(GetStdHandle(STD_INPUT_HANDLE));
 }
+
+/* Undocumented, called by native doskey.exe */
+/* FIXME: Should use CONSOLE_GetHistory() above for full implementation */
+DWORD WINAPI GetConsoleCommandHistoryA(DWORD unknown1, DWORD unknown2, DWORD unknown3)
+{
+    FIXME(": (0x%x, 0x%x, 0x%x) stub!\n", unknown1, unknown2, unknown3);
+    SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
+    return 0;
+}
+
+/* Undocumented, called by native doskey.exe */
+/* FIXME: Should use CONSOLE_GetHistory() above for full implementation */
+DWORD WINAPI GetConsoleCommandHistoryW(DWORD unknown1, DWORD unknown2, DWORD unknown3)
+{
+    FIXME(": (0x%x, 0x%x, 0x%x) stub!\n", unknown1, unknown2, unknown3);
+    SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
+    return 0;
+}
+
+/* Undocumented, called by native doskey.exe */
+/* FIXME: Should use CONSOLE_GetHistory() above for full implementation */
+DWORD WINAPI GetConsoleCommandHistoryLengthA(LPCSTR unknown)
+{
+    FIXME(": (%s) stub!\n", debugstr_a(unknown));
+    SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
+    return 0;
+}
+
+/* Undocumented, called by native doskey.exe */
+/* FIXME: Should use CONSOLE_GetHistory() above for full implementation */
+DWORD WINAPI GetConsoleCommandHistoryLengthW(LPCWSTR unknown)
+{
+    FIXME(": (%s) stub!\n", debugstr_w(unknown));
+    SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
+    return 0;
+}
+
+DWORD WINAPI GetConsoleAliasesLengthA(LPSTR unknown)
+{
+    FIXME(": (%s) stub!\n", debugstr_a(unknown));
+    SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
+    return 0;
+}
+
+DWORD WINAPI GetConsoleAliasesLengthW(LPWSTR unknown)
+{
+    FIXME(": (%s) stub!\n", debugstr_w(unknown));
+    SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
+    return 0;
+}
+
+VOID WINAPI ExpungeConsoleCommandHistoryA(LPCSTR unknown)
+{
+    FIXME(": (%s) stub!\n", debugstr_a(unknown));
+    SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
+}
+
+VOID WINAPI ExpungeConsoleCommandHistoryW(LPCWSTR unknown)
+{
+    FIXME(": (%s) stub!\n", debugstr_w(unknown));
+    SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
+}
+
+BOOL WINAPI AddConsoleAliasA(LPSTR source, LPSTR target, LPSTR exename)
+{
+    FIXME(": (%s, %s, %s) stub!\n", debugstr_a(source), debugstr_a(target), debugstr_a(exename));
+    SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
+    return FALSE;
+}
+
+BOOL WINAPI AddConsoleAliasW(LPWSTR source, LPWSTR target, LPWSTR exename)
+{
+    FIXME(": (%s, %s, %s) stub!\n", debugstr_w(source), debugstr_w(target), debugstr_w(exename));
+    SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
+    return FALSE;
+}
+
+
+BOOL WINAPI SetConsoleIcon(HICON icon)
+{
+    FIXME(": (%p) stub!\n", icon);
+    SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
+    return FALSE;
+}
