@@ -133,7 +133,7 @@ static int format_exception_msg( const EXCEPTION_POINTERS *ptr, char *buffer, in
                  rec->ExceptionInformation[0]);
         break;
     case EXCEPTION_WINE_STUB:
-        if (HIWORD(rec->ExceptionInformation[1]))
+        if ((ULONG_PTR)rec->ExceptionInformation[1] >> 16)
             len = snprintf( buffer, size, "Unimplemented function %s.%s called",
                             (char *)rec->ExceptionInformation[0], (char *)rec->ExceptionInformation[1] );
         else
@@ -190,7 +190,7 @@ static BOOL	start_debugger(PEXCEPTION_POINTERS epointers, HANDLE hEvent)
     STARTUPINFOA	startup;
     char*		format = NULL;
     BOOL		ret = FALSE;
-    char buffer[256];
+    char 		buffer[256];
 
     static const WCHAR AeDebugW[] = {'M','a','c','h','i','n','e','\\',
                                      'S','o','f','t','w','a','r','e','\\',
@@ -212,15 +212,14 @@ static BOOL	start_debugger(PEXCEPTION_POINTERS epointers, HANDLE hEvent)
     attr.SecurityQualityOfService = NULL;
     RtlInitUnicodeString( &nameW, AeDebugW );
 
-    if (!NtOpenKey( &hDbgConf, KEY_ALL_ACCESS, &attr ))
+    if (!NtOpenKey( &hDbgConf, KEY_READ, &attr ))
     {
-        char buffer[64];
         KEY_VALUE_PARTIAL_INFORMATION *info;
         DWORD format_size = 0;
 
         RtlInitUnicodeString( &nameW, DebuggerW );
         if (NtQueryValueKey( hDbgConf, &nameW, KeyValuePartialInformation,
-                             NULL, 0, &format_size ) == STATUS_BUFFER_OVERFLOW)
+                             NULL, 0, &format_size ) == STATUS_BUFFER_TOO_SMALL)
         {
             char *data = HeapAlloc(GetProcessHeap(), 0, format_size);
             NtQueryValueKey( hDbgConf, &nameW, KeyValuePartialInformation,
@@ -265,15 +264,16 @@ static BOOL	start_debugger(PEXCEPTION_POINTERS epointers, HANDLE hEvent)
 
     if (format)
     {
-        cmdline = HeapAlloc(GetProcessHeap(), 0, strlen(format) + 2*20);
-        sprintf(cmdline, format, GetCurrentProcessId(), hEvent);
+        size_t format_size = strlen(format) + 2*20;
+        cmdline = HeapAlloc(GetProcessHeap(), 0, format_size);
+        snprintf(cmdline, format_size, format, (long)GetCurrentProcessId(), (long)HandleToLong(hEvent));
         HeapFree(GetProcessHeap(), 0, format);
     }
     else
     {
         cmdline = HeapAlloc(GetProcessHeap(), 0, 80);
-        sprintf(cmdline, "winedbg --auto %d %ld",
-                GetCurrentProcessId(), (ULONG_PTR)hEvent);
+        snprintf(cmdline, 80, "winedbg --auto %ld %ld", /* as in tools/wine.inf */
+                 (long)GetCurrentProcessId(), (long)HandleToLong(hEvent));
     }
 
     if (!bAuto)
@@ -285,7 +285,6 @@ static BOOL	start_debugger(PEXCEPTION_POINTERS epointers, HANDLE hEvent)
 	if (pMessageBoxA)
 	{
             static const char msg[] = ".\nDo you wish to debug it?";
-	    char buffer[256];
 
             format_exception_msg( epointers, buffer, sizeof(buffer)-sizeof(msg) );
             strcat( buffer, msg );
@@ -365,7 +364,7 @@ static	int	start_debugger_atomic(PEXCEPTION_POINTERS epointers)
 
 	/* ask for manual reset, so that once the debugger is started,
 	 * every thread will know it */
-	NtCreateEvent( &hEvent, EVENT_ALL_ACCESS, &attr, TRUE, FALSE );
+	NtCreateEvent( &hEvent, EVENT_ALL_ACCESS, &attr, NotificationEvent, FALSE );
         if (InterlockedCompareExchangePointer( &hRunOnce, hEvent, 0 ) == 0)
 	{
 	    /* ok, our event has been set... we're the winning thread */
@@ -413,7 +412,7 @@ static inline BOOL check_resource_write( void *addr )
         return FALSE;
     if (addr < rsrc || (char *)addr >= (char *)rsrc + size) return FALSE;
     TRACE( "Broken app is writing to the resource data, enabling work-around\n" );
-    VirtualProtect( rsrc, size, PAGE_WRITECOPY, NULL );
+    VirtualProtect( rsrc, size, PAGE_READWRITE, NULL );
     return TRUE;
 }
 
