@@ -1286,7 +1286,9 @@ HANDLE WINAPI CreateFileW( LPCWSTR filename, DWORD access, DWORD sharing,
 
     if (!strcmpiW(filename, coninW) || !strcmpiW(filename, conoutW))
     {
-        ret = OpenConsoleW(filename, access, (sa && sa->bInheritHandle), creation);
+        ret = OpenConsoleW(filename, access, (sa && sa->bInheritHandle),
+                           creation ? OPEN_EXISTING : 0);
+        if (ret == INVALID_HANDLE_VALUE) SetLastError(ERROR_INVALID_PARAMETER);
         goto done;
     }
 
@@ -1361,7 +1363,7 @@ HANDLE WINAPI CreateFileW( LPCWSTR filename, DWORD access, DWORD sharing,
     if (attributes & FILE_FLAG_NO_BUFFERING)
         options |= FILE_NO_INTERMEDIATE_BUFFERING;
     if (!(attributes & FILE_FLAG_OVERLAPPED))
-        options |= FILE_SYNCHRONOUS_IO_ALERT;
+        options |= FILE_SYNCHRONOUS_IO_NONALERT;
     if (attributes & FILE_FLAG_RANDOM_ACCESS)
         options |= FILE_RANDOM_ACCESS;
     attributes &= FILE_ATTRIBUTE_VALID_FLAGS;
@@ -1527,6 +1529,10 @@ BOOL WINAPI ReplaceFileW(LPCWSTR lpReplacedFileName, LPCWSTR lpReplacementFileNa
     IO_STATUS_BLOCK io;
     OBJECT_ATTRIBUTES attr;
 
+    TRACE("%s %s %s 0x%08x %p %p\n", debugstr_w(lpReplacedFileName),
+          debugstr_w(lpReplacementFileName), debugstr_w(lpBackupFileName),
+          dwReplaceFlags, lpExclude, lpReserved);
+
     if (dwReplaceFlags)
         FIXME("Ignoring flags %x\n", dwReplaceFlags);
 
