@@ -817,10 +817,10 @@ static BOOL PROFILE_Open( LPCWSTR filename, BOOL write_access )
                     CurProfile->LastWriteTime = LastWriteTime;
                 }
                 CloseHandle(hFile);
+                return TRUE;
             }
             else TRACE("(%s): already opened, not yet created (mru=%d)\n",
                        debugstr_w(buffer), i);
-            return TRUE;
         }
     }
 
@@ -1113,11 +1113,11 @@ INT WINAPI GetPrivateProfileStringW( LPCWSTR section, LPCWSTR entry,
 
         if (p >= def_val)
         {
-            int len = (int)(p - def_val) + 1;
+            int vlen = (int)(p - def_val) + 1;
 
-            defval_tmp = HeapAlloc(GetProcessHeap(), 0, (len + 1) * sizeof(WCHAR));
-            memcpy(defval_tmp, def_val, len * sizeof(WCHAR));
-            defval_tmp[len] = '\0';
+            defval_tmp = HeapAlloc(GetProcessHeap(), 0, (vlen + 1) * sizeof(WCHAR));
+            memcpy(defval_tmp, def_val, vlen * sizeof(WCHAR));
+            defval_tmp[vlen] = '\0';
             def_val = defval_tmp;
         }
     }
