@@ -427,7 +427,7 @@ static BOOL WINAPI localmon_AddPortExW(LPWSTR pName, DWORD level, LPBYTE pBuffer
  */
 static BOOL WINAPI localmon_ClosePort(HANDLE hPort)
 {
-    port_t * port = (port_t *) hPort;
+    port_t * port = hPort;
 
     TRACE("(%p)\n", port);
     EnterCriticalSection(&port_handles_cs);
@@ -530,8 +530,8 @@ static BOOL WINAPI localmon_OpenPortW(LPWSTR pName, PHANDLE phPort)
     if (!port) return FALSE;
 
     port->type = type;
-    memcpy(&port->nameW, pName, len);
-    *phPort = (HANDLE) port;
+    memcpy(port->nameW, pName, len);
+    *phPort = port;
 
     EnterCriticalSection(&port_handles_cs);
     list_add_tail(&port_handles, &port->entry);
@@ -556,7 +556,7 @@ static BOOL WINAPI localmon_OpenPortW(LPWSTR pName, PHANDLE phPort)
  */
 static BOOL WINAPI localmon_XcvClosePort(HANDLE hXcv)
 {
-    xcv_t * xcv = (xcv_t *) hXcv;
+    xcv_t * xcv = hXcv;
 
     TRACE("(%p)\n", xcv);
     /* No checks are done in Windows */
@@ -743,8 +743,8 @@ static BOOL WINAPI localmon_XcvOpenPort(LPCWSTR pName, ACCESS_MASK GrantedAccess
     xcv = heap_alloc( sizeof(xcv_t) + len);
     if (xcv) {
         xcv->GrantedAccess = GrantedAccess;
-        memcpy(&xcv->nameW, pName, len);
-        *phXcv = (HANDLE) xcv;
+        memcpy(xcv->nameW, pName, len);
+        *phXcv = xcv;
         EnterCriticalSection(&xcv_handles_cs);
         list_add_tail(&xcv_handles, &xcv->entry);
         LeaveCriticalSection(&xcv_handles_cs);
