@@ -27,8 +27,10 @@
 #include "winver.h"
 #include "dbghelp.h"
 #include "ole2.h"
+#include "mscoree.h"
 #include "corhdr.h"
 #include "metahost.h"
+#include "cordebug.h"
 #include "wine/list.h"
 #include "mscoree_private.h"
 
