@@ -883,6 +883,7 @@ static HRESULT WINAPI KeystrokeMgr_PreserveKey(ITfKeystrokeMgr *iface,
     newkey->guid  = *rguid;
     newkey->prekey = *prekey;
     newkey->tid = tid;
+    newkey->description = NULL;
     if (cchDesc)
     {
         newkey->description = HeapAlloc(GetProcessHeap(),0,cchDesc * sizeof(WCHAR));
@@ -1312,7 +1313,7 @@ HRESULT ThreadMgr_Constructor(IUnknown *pUnkOuter, IUnknown **ppOut)
 }
 
 /**************************************************
- * IEnumTfDocumentMgrs implementaion
+ * IEnumTfDocumentMgrs implementation
  **************************************************/
 static void EnumTfDocumentMgr_Destructor(EnumTfDocumentMgr *This)
 {
@@ -1469,5 +1470,5 @@ void ThreadMgr_OnDocumentMgrDestruction(ITfThreadMgr *tm, ITfDocumentMgr *mgr)
             return;
         }
     }
-    FIXME("ITfDocumenMgr %p not found in this thread\n",mgr);
+    FIXME("ITfDocumentMgr %p not found in this thread\n",mgr);
 }
