@@ -276,7 +276,8 @@ static HRESULT WINAPI HTMLLocation_put_protocol(IHTMLLocation *iface, BSTR v)
 static HRESULT WINAPI HTMLLocation_get_protocol(IHTMLLocation *iface, BSTR *p)
 {
     HTMLLocation *This = impl_from_IHTMLLocation(iface);
-    URL_COMPONENTSW url = {sizeof(URL_COMPONENTSW)};
+    BSTR protocol, ret;
+    unsigned len;
     HRESULT hres;
 
     TRACE("(%p)->(%p)\n", This, p);
@@ -284,22 +285,28 @@ static HRESULT WINAPI HTMLLocation_get_protocol(IHTMLLocation *iface, BSTR *p)
     if(!p)
         return E_POINTER;
 
-    url.dwSchemeLength = 1;
-    hres = get_url_components(This, &url);
+    if(!This->window || !This->window->uri) {
+        FIXME("No current URI\n");
+        return E_NOTIMPL;
+    }
+
+    hres = IUri_GetSchemeName(This->window->uri, &protocol);
     if(FAILED(hres))
         return hres;
-
-    if(!url.dwSchemeLength) {
-        FIXME("Unexpected blank protocol\n");
-        return E_NOTIMPL;
-    }else {
-        WCHAR *buf;
-        buf = *p = SysAllocStringLen(NULL, url.dwSchemeLength + 1);
-        memcpy(buf, url.lpszScheme, url.dwSchemeLength * sizeof(WCHAR));
-        buf[url.dwSchemeLength] = ':';
+    if(hres == S_FALSE) {
+        SysFreeString(protocol);
+        *p = NULL;
+        return S_OK;
     }
-    if(!*p)
+
+    len = SysStringLen(protocol);
+    ret = SysAllocStringLen(protocol, len+1);
+    SysFreeString(protocol);
+    if(!ret)
         return E_OUTOFMEMORY;
+
+    ret[len] = ':';
+    *p = ret;
     return S_OK;
 }
 
@@ -395,7 +402,7 @@ static HRESULT WINAPI HTMLLocation_put_port(IHTMLLocation *iface, BSTR v)
 static HRESULT WINAPI HTMLLocation_get_port(IHTMLLocation *iface, BSTR *p)
 {
     HTMLLocation *This = impl_from_IHTMLLocation(iface);
-    URL_COMPONENTSW url = {sizeof(URL_COMPONENTSW)};
+    DWORD port;
     HRESULT hres;
 
     TRACE("(%p)->(%p)\n", This, p);
@@ -403,18 +410,23 @@ static HRESULT WINAPI HTMLLocation_get_port(IHTMLLocation *iface, BSTR *p)
     if(!p)
         return E_POINTER;
 
-    hres = get_url_components(This, &url);
+    if(!This->window || !This->window->uri) {
+        FIXME("No current URI\n");
+        return E_NOTIMPL;
+    }
+
+    hres = IUri_GetPort(This->window->uri, &port);
     if(FAILED(hres))
         return hres;
 
-    if(url.nPort) {
-        const WCHAR format[] = {'%','u',0};
-        WCHAR buf[6];
-        snprintfW(buf, 6, format, url.nPort);
+    if(hres == S_OK) {
+        static const WCHAR formatW[] = {'%','u',0};
+        WCHAR buf[12];
+
+        sprintfW(buf, formatW, port);
         *p = SysAllocString(buf);
     }else {
-        const WCHAR empty[] = {0};
-        *p = SysAllocString(empty);
+        *p = SysAllocStringLen(NULL, 0);
     }
 
     if(!*p)
@@ -466,31 +478,29 @@ static HRESULT WINAPI HTMLLocation_put_search(IHTMLLocation *iface, BSTR v)
 static HRESULT WINAPI HTMLLocation_get_search(IHTMLLocation *iface, BSTR *p)
 {
     HTMLLocation *This = impl_from_IHTMLLocation(iface);
-    URL_COMPONENTSW url = {sizeof(URL_COMPONENTSW)};
+    BSTR query;
     HRESULT hres;
-    const WCHAR hash[] = {'#',0};
 
     TRACE("(%p)->(%p)\n", This, p);
 
     if(!p)
         return E_POINTER;
 
-    url.dwExtraInfoLength = 1;
-    hres = get_url_components(This, &url);
-    if(FAILED(hres))
-        return hres;
-
-    if(!url.dwExtraInfoLength){
-        *p = NULL;
-        return S_OK;
+    if(!This->window || !This->window->uri) {
+        FIXME("No current URI\n");
+        return E_NOTIMPL;
     }
 
-    url.dwExtraInfoLength = strcspnW(url.lpszExtraInfo, hash);
+    hres = IUri_GetQuery(This->window->uri, &query);
+    if(hres == S_OK) {
+        *p = query;
+    }else if(hres == S_FALSE) {
+        SysFreeString(query);
+        *p = NULL;
+    }else {
+        return hres;
+    }
 
-    *p = SysAllocStringLen(url.lpszExtraInfo, url.dwExtraInfoLength);
-
-    if(!*p)
-        return E_OUTOFMEMORY;
     return S_OK;
 }
 
@@ -504,9 +514,7 @@ static HRESULT WINAPI HTMLLocation_put_hash(IHTMLLocation *iface, BSTR v)
 static HRESULT WINAPI HTMLLocation_get_hash(IHTMLLocation *iface, BSTR *p)
 {
     HTMLLocation *This = impl_from_IHTMLLocation(iface);
-    URL_COMPONENTSW url = {sizeof(URL_COMPONENTSW)};
-    const WCHAR hash[] = {'#',0};
-    DWORD hash_pos = 0;
+    BSTR hash;
     HRESULT hres;
 
     TRACE("(%p)->(%p)\n", This, p);
@@ -514,23 +522,21 @@ static HRESULT WINAPI HTMLLocation_get_hash(IHTMLLocation *iface, BSTR *p)
     if(!p)
         return E_POINTER;
 
-    url.dwExtraInfoLength = 1;
-    hres = get_url_components(This, &url);
-    if(FAILED(hres))
-        return hres;
-
-    if(!url.dwExtraInfoLength){
-        *p = NULL;
-        return S_OK;
+    if(!This->window || !This->window->uri) {
+        FIXME("No current URI\n");
+        return E_NOTIMPL;
     }
 
-    hash_pos = strcspnW(url.lpszExtraInfo, hash);
-    url.dwExtraInfoLength -= hash_pos;
+    hres = IUri_GetFragment(This->window->uri, &hash);
+    if(hres == S_OK) {
+        *p = hash;
+    }else if(hres == S_FALSE) {
+        SysFreeString(hash);
+        *p = NULL;
+    }else {
+        return hres;
+    }
 
-    *p = SysAllocStringLen(url.lpszExtraInfo + hash_pos, url.dwExtraInfoLength);
-
-    if(!*p)
-        return E_OUTOFMEMORY;
     return S_OK;
 }
 
