@@ -33,6 +33,8 @@
 #include "shlguid.h"
 #include "wininet.h"
 #include "shlwapi.h"
+#include "htiface.h"
+#include "shdeprecated.h"
 
 #include "wine/debug.h"
 
@@ -42,8 +44,11 @@
 WINE_DEFAULT_DEBUG_CHANNEL(mshtml);
 
 #define CONTENT_LENGTH "Content-Length"
+#define UTF8_STR "utf-8"
 #define UTF16_STR "utf-16"
 
+static const WCHAR emptyW[] = {0};
+
 struct nsProtocolStream {
     nsIInputStream nsIInputStream_iface;
 
@@ -1041,7 +1046,7 @@ static void on_stop_nsrequest(nsChannelBSC *This, HRESULT result)
                  (nsIRequest*)&This->nschannel->nsIHttpChannel_iface, This->nscontext,
                  request_result);
         if(NS_FAILED(nsres))
-            WARN("OnStopRequet failed: %08x\n", nsres);
+            WARN("OnStopRequest failed: %08x\n", nsres);
     }
 
     if(This->nschannel->load_group) {
@@ -1086,6 +1091,11 @@ static HRESULT read_stream_data(nsChannelBSC *This, IStream *stream)
                && (BYTE)This->nsstream->buf[0] == 0xff
                && (BYTE)This->nsstream->buf[1] == 0xfe)
                 This->nschannel->charset = heap_strdupA(UTF16_STR);
+            if(This->nsstream->buf_size >= 3
+               && (BYTE)This->nsstream->buf[0] == 0xef
+               && (BYTE)This->nsstream->buf[1] == 0xbb
+               && (BYTE)This->nsstream->buf[2] == 0xbf)
+                This->nschannel->charset = heap_strdupA(UTF8_STR);
 
             if(!This->nschannel->content_type) {
                 WCHAR *mime;
@@ -1916,7 +1926,7 @@ HRESULT super_navigate(HTMLWindow *window, IUri *uri, const WCHAR *headers, BYTE
         }
     }
 
-    if(window->uri && compare_ignoring_frag(window->uri, uri)) {
+    if(window->uri && !post_data_size && compare_ignoring_frag(window->uri, uri)) {
         TRACE("fragment navigate\n");
         return navigate_fragment(window, uri);
     }
@@ -1937,8 +1947,7 @@ HRESULT super_navigate(HTMLWindow *window, IUri *uri, const WCHAR *headers, BYTE
     prepare_for_binding(&window->doc_obj->basedoc, mon, TRUE);
 
     hres = IUri_GetScheme(uri, &scheme);
-
-    if(scheme != URL_SCHEME_JAVASCRIPT) {
+    if(SUCCEEDED(hres) && scheme != URL_SCHEME_JAVASCRIPT) {
         navigate_task_t *task;
 
         task = heap_alloc(sizeof(*task));
@@ -1977,11 +1986,66 @@ HRESULT super_navigate(HTMLWindow *window, IUri *uri, const WCHAR *headers, BYTE
     return S_OK;
 }
 
+HRESULT navigate_new_window(HTMLWindow *window, IUri *uri, const WCHAR *name, IHTMLWindow2 **ret)
+{
+    IWebBrowser2 *web_browser;
+    IHTMLWindow2 *new_window;
+    IBindCtx *bind_ctx;
+    nsChannelBSC *bsc;
+    HRESULT hres;
+
+    hres = create_channelbsc(NULL, NULL, NULL, 0, &bsc);
+    if(FAILED(hres))
+        return hres;
+
+    hres = CreateAsyncBindCtx(0, &bsc->bsc.IBindStatusCallback_iface, NULL, &bind_ctx);
+    if(FAILED(hres)) {
+        IBindStatusCallback_Release(&bsc->bsc.IBindStatusCallback_iface);
+        return hres;
+    }
+
+    hres = CoCreateInstance(&CLSID_InternetExplorer, NULL, CLSCTX_LOCAL_SERVER,
+            &IID_IWebBrowser2, (void**)&web_browser);
+    if(SUCCEEDED(hres)) {
+        ITargetFramePriv2 *target_frame_priv;
+
+        hres = IWebBrowser_QueryInterface(web_browser, &IID_ITargetFramePriv2, (void**)&target_frame_priv);
+        if(SUCCEEDED(hres)) {
+            hres = ITargetFramePriv2_AggregatedNavigation2(target_frame_priv,
+                    HLNF_DISABLEWINDOWRESTRICTIONS|HLNF_OPENINNEWWINDOW, bind_ctx, &bsc->bsc.IBindStatusCallback_iface,
+                    name, uri, emptyW);
+            ITargetFramePriv2_Release(target_frame_priv);
+
+            if(SUCCEEDED(hres))
+                hres = do_query_service((IUnknown*)web_browser, &SID_SHTMLWindow, &IID_IHTMLWindow2, (void**)&new_window);
+        }
+        if(FAILED(hres)) {
+            IWebBrowser2_Quit(web_browser);
+            IWebBrowser2_Release(web_browser);
+        }
+    }else {
+        WARN("Could not create InternetExplorer instance: %08x\n", hres);
+    }
+
+    IBindStatusCallback_Release(&bsc->bsc.IBindStatusCallback_iface);
+    IBindCtx_Release(bind_ctx);
+    if(FAILED(hres))
+        return hres;
+
+    IWebBrowser2_put_Visible(web_browser, VARIANT_TRUE);
+    IWebBrowser2_Release(web_browser);
+
+    if(ret)
+        *ret = new_window;
+    else
+        IHTMLWindow2_Release(new_window);
+    return S_OK;
+}
+
 HRESULT hlink_frame_navigate(HTMLDocument *doc, LPCWSTR url, nsChannel *nschannel, DWORD hlnf, BOOL *cancel)
 {
     IHlinkFrame *hlink_frame;
     nsChannelBSC *callback;
-    IServiceProvider *sp;
     IBindCtx *bindctx;
     IMoniker *mon;
     IHlink *hlink;
@@ -1989,14 +2053,8 @@ HRESULT hlink_frame_navigate(HTMLDocument *doc, LPCWSTR url, nsChannel *nschanne
 
     *cancel = FALSE;
 
-    hres = IOleClientSite_QueryInterface(doc->doc_obj->client, &IID_IServiceProvider,
-            (void**)&sp);
-    if(FAILED(hres))
-        return S_OK;
-
-    hres = IServiceProvider_QueryService(sp, &IID_IHlinkFrame, &IID_IHlinkFrame,
+    hres = do_query_service((IUnknown*)doc->doc_obj->client, &IID_IHlinkFrame, &IID_IHlinkFrame,
             (void**)&hlink_frame);
-    IServiceProvider_Release(sp);
     if(FAILED(hres))
         return S_OK;
 
