@@ -29,7 +29,6 @@
 #include "ole2.h"
 
 #include "wine/debug.h"
-#include "wine/unicode.h"
 
 #include "mshtml_private.h"
 
@@ -479,6 +478,9 @@ static HRESULT WINAPI AboutProtocolInfo_QueryInfo(IInternetProtocolInfo *iface,
     case QUERY_USES_HISTORYFOLDER:
         FIXME("Unsupported option QUERY_USES_HISTORYFOLDER\n");
         return E_FAIL;
+    case QUERY_IS_CACHED_AND_USABLE_OFFLINE:
+        FIXME("Unsupported option QUERY_IS_CACHED_AND_USABLE_OFFLINE\n");
+        return E_NOTIMPL;
     default:
         return E_FAIL;
     }
@@ -924,10 +926,10 @@ static HRESULT WINAPI ResProtocolInfo_QueryInfo(IInternetProtocolInfo *iface, LP
         break;
 
     case QUERY_IS_SECURE:
-        FIXME("not supporte QUERY_IS_SECURE\n");
+        FIXME("QUERY_IS_SECURE not supported\n");
         return E_NOTIMPL;
     case QUERY_IS_SAFE:
-        FIXME("not supporte QUERY_IS_SAFE\n");
+        FIXME("QUERY_IS_SAFE not supported\n");
         return E_NOTIMPL;
     default:
         return INET_E_USE_DEFAULT_PROTOCOLHANDLER;
@@ -1009,7 +1011,7 @@ static HRESULT WINAPI JSProtocolInfo_QueryInfo(IInternetProtocolInfo *iface, LPC
         break;
 
     case QUERY_IS_SECURE:
-        FIXME("not supporte QUERY_IS_SECURE\n");
+        FIXME("QUERY_IS_SECURE not supported\n");
         return E_NOTIMPL;
 
     default:
