@@ -247,6 +247,17 @@ static UINT msi_create_directory( MSIPACKAGE *package, const WCHAR *dir )
     return ERROR_SUCCESS;
 }
 
+static MSIFILE *find_file( MSIPACKAGE *package, const WCHAR *filename )
+{
+    MSIFILE *file;
+
+    LIST_FOR_EACH_ENTRY( file, &package->files, MSIFILE, entry )
+    {
+        if (!strcmpiW( filename, file->File )) return file;
+    }
+    return NULL;
+}
+
 static BOOL installfiles_cb(MSIPACKAGE *package, LPCWSTR file, DWORD action,
                             LPWSTR *path, DWORD *attrs, PVOID user)
 {
@@ -255,8 +266,7 @@ static BOOL installfiles_cb(MSIPACKAGE *package, LPCWSTR file, DWORD action,
 
     if (action == MSICABEXTRACT_BEGINEXTRACT)
     {
-        f = msi_get_loaded_file(package, file);
-        if (!f)
+        if (!(f = find_file( package, file )))
         {
             TRACE("unknown file in cabinet (%s)\n", debugstr_w(file));
             return FALSE;
@@ -331,7 +341,9 @@ UINT ACTION_InstallFiles(MSIPACKAGE *package)
         if (!file->Component->Enabled) continue;
 
         if (file->state != msifs_hashmatch &&
-            (rc = ready_media( package, file->Sequence, file->IsCompressed, mi )))
+            file->state != msifs_skipped &&
+            (file->state != msifs_present || !msi_get_property_int( package->db, szInstalled, 0 )) &&
+            (rc = ready_media( package, file->IsCompressed, mi )))
         {
             ERR("Failed to ready media for %s\n", debugstr_w(file->File));
             goto done;
@@ -512,7 +524,7 @@ UINT ACTION_PatchFiles( MSIPACKAGE *package )
         {
             MSICABDATA data;
 
-            rc = ready_media( package, patch->Sequence, TRUE, mi );
+            rc = ready_media( package, TRUE, mi );
             if (rc != ERROR_SUCCESS)
             {
                 ERR("Failed to ready media for %s\n", debugstr_w(file->File));
