@@ -232,7 +232,7 @@ HRESULT WINAPI DllCanUnloadNow(void)
  */
 HRESULT WINAPI DllRegisterServer(void)
 {
-    return __wine_register_resources( msi_hInstance, NULL );
+    return __wine_register_resources( msi_hInstance );
 }
 
 /***********************************************************************
@@ -240,5 +240,5 @@ HRESULT WINAPI DllRegisterServer(void)
  */
 HRESULT WINAPI DllUnregisterServer(void)
 {
-    return __wine_unregister_resources( msi_hInstance, NULL );
+    return __wine_unregister_resources( msi_hInstance );
 }
