@@ -68,10 +68,10 @@ HRESULT WINAPI DllCanUnloadNow(void)
 
 HRESULT WINAPI DllRegisterServer(void)
 {
-    return __wine_register_resources( hInst, NULL );
+    return __wine_register_resources( hInst );
 }
 
 HRESULT WINAPI DllUnregisterServer(void)
 {
-    return __wine_unregister_resources( hInst, NULL );
+    return __wine_unregister_resources( hInst );
 }
