@@ -137,6 +137,13 @@ typedef struct {
     char fillch;
 } basic_ios_char;
 
+typedef struct {
+    ios_base child;
+    /*basic_streambuf_wchar*/void *strbuf;
+    /*basic_ostream_wchar*/void *stream;
+    char fillch;
+} basic_ios_wchar;
+
 typedef struct {
     const vtable_ptr *vtable;
     basic_ios_char child;
@@ -148,31 +155,21 @@ extern const vtable_ptr MSVCP_ios_base_vtable;
 /* ??_7?$basic_ios@DU?$char_traits@D@std@@@std@@6B@ */
 extern const vtable_ptr MSVCP_basic_ios_char_vtable;
 
+/* ??_7?$basic_ios@_WU?$char_traits@_W@std@@@std@@6B@ */
+extern const vtable_ptr MSVCP_basic_ios_wchar_vtable;
+
 /* ??_7?$basic_streambuf@DU?$char_traits@D@std@@@std@@6B@ */
 extern const vtable_ptr MSVCP_basic_streambuf_char_vtable;
 
 /* ??_7?$basic_ostream@DU?$char_traits@D@std@@@std@@6B@ */
 extern const vtable_ptr MSVCP_basic_ostream_char_vtable;
 
-static const type_info ios_base_type_info = {
-    &MSVCP_ios_base_vtable,
-    NULL,
-    ".?AVios_base@std@@"
-};
-
-static const rtti_base_descriptor ios_base_rtti_base_descriptor = {
-    &ios_base_type_info,
-    1,
-    { 0, -1, 0 },
-    64
-};
-
 static const type_info iosb_type_info = {
     &MSVCP_ios_base_vtable,
     NULL,
     ".?AV?$_Iosb@H@std@@"
 };
-
+    
 static const rtti_base_descriptor iosb_rtti_base_descriptor = {
     &iosb_type_info,
     0,
@@ -180,143 +177,22 @@ static const rtti_base_descriptor iosb_rtti_base_descriptor = {
     64
 };
 
-static const rtti_base_array ios_base_rtti_base_array = {
-    {
-        &ios_base_rtti_base_descriptor,
-        &iosb_rtti_base_descriptor,
-        NULL
-    }
-};
-
-static const rtti_object_hierarchy ios_base_type_hierarchy = {
-    0,
-    0,
-    2,
-    &ios_base_rtti_base_array
-};
-
-const rtti_object_locator ios_base_rtti = {
-    0,
-    0,
-    0,
-    &ios_base_type_info,
-    &ios_base_type_hierarchy
-};
-
-static const type_info basic_ios_char_type_info = {
-    &MSVCP_basic_ios_char_vtable,
-    NULL,
-    ".?AV?$basic_ios@DU?$char_traits@D@std@@@std@@"
-};
-
-static const rtti_base_descriptor basic_ios_char_rtti_base_descriptor = {
-    &basic_ios_char_type_info,
-    2,
-    { 0, -1, 0 },
-    64
-};
-
-static const rtti_base_array basic_ios_char_rtti_base_array = {
-    {
-        &basic_ios_char_rtti_base_descriptor,
-        &ios_base_rtti_base_descriptor,
-        &iosb_rtti_base_descriptor
-    }
-};
-
-static const rtti_object_hierarchy basic_ios_char_hierarchy = {
-    0,
-    0,
-    3,
-    &basic_ios_char_rtti_base_array
-};
-
-const rtti_object_locator basic_ios_char_rtti = {
-    0,
-    0,
-    0,
-    &basic_ios_char_type_info,
-    &basic_ios_char_hierarchy
-};
-
-static const type_info basic_streambuf_char_type_info = {
-    &MSVCP_basic_streambuf_char_vtable,
-    NULL,
-    ".?AV?$basic_streambuf@DU?$char_traits@D@std@@@std@@"
-};
-
-static const rtti_base_descriptor basic_streambuf_char_rtti_base_descriptor = {
-    &basic_streambuf_char_type_info,
-    0,
-    { 0, -1, 0},
-    64
-};
-
-static const rtti_base_array basic_streambuf_char_rtti_base_array = {
-    {
-        &basic_streambuf_char_rtti_base_descriptor,
-        NULL,
-        NULL
-    }
-};
-
-static const rtti_object_hierarchy basic_streambuf_char_hierarchy = {
-    0,
-    0,
-    1,
-    &basic_streambuf_char_rtti_base_array
-};
-
-const rtti_object_locator basic_streambuf_char_rtti = {
-    0,
-    0,
-    0,
-    &basic_streambuf_char_type_info,
-    &basic_streambuf_char_hierarchy
-};
-
-static const type_info basic_ostream_char_type_info = {
-    &MSVCP_basic_ostream_char_vtable,
-    NULL,
-    ".?AV?$basic_ostream@DU?$char_traits@D@std@@@std@@"
-};
-
-static const rtti_base_descriptor basic_ostream_char_rtti_base_descriptor = {
-    &basic_ostream_char_type_info,
-    3,
-    { 0, -1, 0},
-    64
-};
-
-static const rtti_base_array basic_ostream_char_rtti_base_array = {
-    {
-        &basic_ostream_char_rtti_base_descriptor,
-        &basic_ios_char_rtti_base_descriptor,
-        &ios_base_rtti_base_descriptor,
-        &iosb_rtti_base_descriptor
-    }
-};
-
-static const rtti_object_hierarchy basic_ostream_char_hierarchy = {
-        0,
-        0,
-        4,
-        &basic_ostream_char_rtti_base_array
-};
-
-const rtti_object_locator basic_ostream_char_rtti = {
-    0,
-    4,
-    0,
-    &basic_ostream_char_type_info,
-    &basic_ostream_char_hierarchy
-};
+DEFINE_RTTI_DATA(ios_base, 0, 1, &iosb_rtti_base_descriptor, NULL, NULL, ".?AV?$_Iosb@H@std@@");
+DEFINE_RTTI_DATA(basic_ios_char, 0, 2, &ios_base_rtti_base_descriptor, &iosb_rtti_base_descriptor,
+        NULL, ".?AV?$basic_ios@DU?$char_traits@D@std@@@std@@");
+DEFINE_RTTI_DATA(basic_ios_wchar, 0, 2, &ios_base_rtti_base_descriptor, &iosb_rtti_base_descriptor,
+        NULL, ".?AV?$basic_ios@_WU?$char_traits@_W@std@@@std@@");
+DEFINE_RTTI_DATA(basic_streambuf_char, 0, 0, NULL, NULL, NULL,
+        ".?AV?$basic_streambuf@DU?$char_traits@D@std@@@std@@");
+DEFINE_RTTI_DATA(basic_ostream_char, 4, 3, &basic_ios_char_rtti_base_descriptor, &ios_base_rtti_base_descriptor,
+        &iosb_rtti_base_descriptor, ".?AV?$basic_ostream@DU?$char_traits@D@std@@@std@@");
 
 #ifndef __GNUC__
 void __asm_dummy_vtables(void) {
 #endif
     __ASM_VTABLE(ios_base, "");
     __ASM_VTABLE(basic_ios_char, "");
+    __ASM_VTABLE(basic_ios_wchar, "");
     __ASM_VTABLE(basic_streambuf_char,
             VTABLE_ADD_FUNC(basic_streambuf_char_overflow)
             VTABLE_ADD_FUNC(basic_streambuf_char_pbackfail)
@@ -468,9 +344,9 @@ MSVCP_bool* CDECL ios_base_Sync_func(void)
 
 /* ?_Tidy@ios_base@std@@AAAXXZ */
 /* ?_Tidy@ios_base@std@@AEAAXXZ */
-void CDECL ios_base_Tidy(ios_base *this)
+void CDECL ios_base_Tidy(void)
 {
-    FIXME("(%p) stub\n", this);
+    FIXME("stub\n");
 }
 
 /* ?bad@ios_base@std@@QBE_NXZ */
@@ -578,10 +454,9 @@ IOSB_fmtflags __thiscall ios_base_flags_get(const ios_base *this)
 
 /* ?getloc@ios_base@std@@QBE?AVlocale@2@XZ */
 /* ?getloc@ios_base@std@@QEBA?AVlocale@2@XZ */
-DEFINE_THISCALL_WRAPPER(ios_base_getloc, 4)
-locale __thiscall ios_base_getloc(const ios_base *this)
+DEFINE_THISCALL_WRAPPER(ios_base_getloc, 8)
+locale* __thiscall ios_base_getloc(const ios_base *this, locale *ret)
 {
-    locale ret = { NULL };
     FIXME("(%p) stub\n", this);
     return ret;
 }
@@ -597,10 +472,9 @@ MSVCP_bool __thiscall ios_base_good(const ios_base *this)
 
 /* ?imbue@ios_base@std@@QAE?AVlocale@2@ABV32@@Z */
 /* ?imbue@ios_base@std@@QEAA?AVlocale@2@AEBV32@@Z */
-DEFINE_THISCALL_WRAPPER(ios_base_imbue, 8)
-locale __thiscall ios_base_imbue(ios_base *this, const locale *loc)
+DEFINE_THISCALL_WRAPPER(ios_base_imbue, 12)
+locale* __thiscall ios_base_imbue(ios_base *this, locale *ret, const locale *loc)
 {
-    locale ret = { NULL };
     FIXME("(%p %p) stub\n", this, loc);
     return ret;
 }
@@ -830,11 +704,10 @@ char __thiscall basic_ios_char_fill_get(basic_ios_char *this)
 
 /* ?imbue@?$basic_ios@DU?$char_traits@D@std@@@std@@QAE?AVlocale@2@ABV32@@Z */
 /* ?imbue@?$basic_ios@DU?$char_traits@D@std@@@std@@QEAA?AVlocale@2@AEBV32@@Z */
-DEFINE_THISCALL_WRAPPER(basic_ios_char_imbue, 4)
-locale __thiscall basic_ios_char_imbue(basic_ios_char *this)
+DEFINE_THISCALL_WRAPPER(basic_ios_char_imbue, 12)
+locale *__thiscall basic_ios_char_imbue(basic_ios_char *this, locale *ret, const locale *loc)
 {
-    locale ret = { NULL };
-    FIXME("(%p) stub\n", this);
+    FIXME("(%p %p %p) stub\n", this, ret, loc);
     return ret;
 }
 
@@ -916,6 +789,183 @@ char __thiscall basic_ios_char_widen(basic_ios_char *this, char ch)
     return 0;
 }
 
+
+/* ??0?$basic_ios@_WU?$char_traits@_W@std@@@std@@IAE@XZ */
+/* ??0?$basic_ios@_WU?$char_traits@_W@std@@@std@@IEAA@XZ */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_ctor, 4)
+basic_ios_wchar* __thiscall basic_ios_wchar_ctor(basic_ios_wchar *this)
+{
+    FIXME("(%p) stub\n", this);
+    return NULL;
+}
+
+/* ??0?$basic_ios@_WU?$char_traits@_W@std@@@std@@QAE@PAV?$basic_streambuf@_WU?$char_traits@_W@std@@@1@@Z */
+/* ??0?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEAA@PEAV?$basic_streambuf@_WU?$char_traits@_W@std@@@1@@Z */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_copy_ctor, 8)
+basic_ios_wchar* __thiscall basic_ios_wchar_copy_ctor(basic_ios_wchar *this, const basic_ios_wchar *copy)
+{
+    FIXME("(%p %p) stub\n", this, copy);
+    return NULL;
+}
+
+/* ??1?$basic_ios@_WU?$char_traits@_W@std@@@std@@UAE@XZ */
+/* ??1?$basic_ios@_WU?$char_traits@_W@std@@@std@@UEAA@XZ */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_dtor, 4)
+void __thiscall basic_ios_wchar_dtor(basic_ios_wchar *this)
+{
+    FIXME("(%p) stub\n", this);
+}
+
+DEFINE_THISCALL_WRAPPER(MSVCP_basic_ios_wchar_vector_dtor, 8)
+basic_ios_wchar* __thiscall MSVCP_basic_ios_wchar_vector_dtor(basic_ios_wchar *this, unsigned int flags)
+{
+    TRACE("(%p %x) stub\n", this, flags);
+    if(flags & 2) {
+        /* we have an array, with the number of elements stored before the first object */
+        int i, *ptr = (int *)this-1;
+
+        for(i=*ptr-1; i>=0; i--)
+            basic_ios_wchar_dtor(this+i);
+        MSVCRT_operator_delete(ptr);
+    } else {
+        basic_ios_wchar_dtor(this);
+        if(flags & 1)
+            MSVCRT_operator_delete(this);
+    }
+
+    return this;
+}
+
+/* ?clear@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QAEXH_N@Z */
+/* ?clear@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEAAXH_N@Z */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_clear_reraise, 12)
+void __thiscall basic_ios_wchar_clear_reraise(basic_ios_wchar *this, IOSB_iostate state, MSVCP_bool reraise)
+{
+    FIXME("(%p %x %x) stub\n", this, state, reraise);
+}
+
+/* ?clear@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QAEXI@Z */
+/* ?clear@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEAAXI@Z */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_clear, 8)
+void __thiscall basic_ios_wchar_clear(basic_ios_wchar *this, unsigned int state)
+{
+    basic_ios_wchar_clear_reraise(this, (IOSB_iostate)state, FALSE);
+}
+
+/* ?copyfmt@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QAEAAV12@ABV12@@Z */
+/* ?copyfmt@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEAAAEAV12@AEBV12@@Z */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_copyfmt, 8)
+basic_ios_wchar* __thiscall basic_ios_wchar_copyfmt(basic_ios_wchar *this, basic_ios_wchar *copy)
+{
+    FIXME("(%p %p) stub\n", this, copy);
+    return NULL;
+}
+
+/* ?fill@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QAE_W_W@Z */
+/* ?fill@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEAA_W_W@Z */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_fill_set, 8)
+wchar_t __thiscall basic_ios_wchar_fill_set(basic_ios_wchar *this, wchar_t fill)
+{
+    FIXME("(%p %c) stub\n", this, fill);
+    return 0;
+}
+
+/* ?fill@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QBE_WXZ */
+/* ?fill@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEBA_WXZ */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_fill_get, 4)
+wchar_t __thiscall basic_ios_wchar_fill_get(basic_ios_wchar *this)
+{
+    FIXME("(%p) stub\n", this);
+    return 0;
+}
+
+/* ?imbue@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QAE?AVlocale@2@ABV32@@Z */
+/* ?imbue@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEAA?AVlocale@2@AEBV32@@Z */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_imbue, 12)
+locale *__thiscall basic_ios_wchar_imbue(basic_ios_wchar *this, locale *ret, const locale *loc)
+{
+    FIXME("(%p %p %p) stub\n", this, ret, loc);
+    return ret;
+}
+
+/* ?init@?$basic_ios@_WU?$char_traits@_W@std@@@std@@IAEXPAV?$basic_streambuf@_WU?$char_traits@_W@std@@@2@_N@Z */
+/* ?init@?$basic_ios@_WU?$char_traits@_W@std@@@std@@IEAAXPEAV?$basic_streambuf@_WU?$char_traits@_W@std@@@2@_N@Z */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_init, 12)
+void __thiscall basic_ios_wchar_init(basic_ios_wchar *this, /*basic_streambuf_wchar*/void *streambuf, MSVCP_bool isstd)
+{
+    FIXME("(%p %p %x) stub\n", this, streambuf, isstd);
+}
+
+/* ?narrow@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QBED_WD@Z */
+/* ?narrow@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEBAD_WD@Z */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_narrow, 12)
+char __thiscall basic_ios_wchar_narrow(basic_ios_wchar *this, wchar_t ch, char def)
+{
+    FIXME("(%p %c %c) stub\n", this, ch, def);
+    return def;
+}
+
+/* ?rdbuf@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QAEPAV?$basic_streambuf@_WU?$char_traits@_W@std@@@2@PAV32@@Z */
+/* ?rdbuf@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEAAPEAV?$basic_streambuf@_WU?$char_traits@_W@std@@@2@PEAV32@@Z */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_rdbuf_set, 8)
+/*basic_streambuf_wchar*/void* __thiscall basic_ios_wchar_rdbuf_set(basic_ios_wchar *this, /*basic_streambuf_wchar*/void *streambuf)
+{
+    FIXME("(%p %p) stub\n", this, streambuf);
+    return NULL;
+}
+
+/* ?rdbuf@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QBEPAV?$basic_streambuf@_WU?$char_traits@_W@std@@@2@XZ */
+/* ?rdbuf@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEBAPEAV?$basic_streambuf@_WU?$char_traits@_W@std@@@2@XZ */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_rdbuf_get, 4)
+/*basic_streambuf_wchar*/void* __thiscall basic_ios_wchar_rdbuf_get(const basic_ios_wchar *this)
+{
+    FIXME("(%p) stub\n", this);
+    return NULL;
+}
+
+/* ?setstate@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QAEXH_N@Z */
+/* ?setstate@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEAAXH_N@Z */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_setstate_reraise, 12)
+void __thiscall basic_ios_wchar_setstate_reraise(basic_ios_wchar *this, IOSB_iostate state, MSVCP_bool reraise)
+{
+    FIXME("(%p %x %x) stub\n", this, state, reraise);
+}
+
+/* ?setstate@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QAEXI@Z */
+/* ?setstate@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEAAXI@Z */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_setstate, 8)
+void __thiscall basic_ios_wchar_setstate(basic_ios_wchar *this, IOSB_iostate state)
+{
+    basic_ios_wchar_setstate_reraise(this, state, FALSE);
+}
+
+/* ?tie@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QAEPAV?$basic_ostream@_WU?$char_traits@_W@std@@@2@PAV32@@Z */
+/* ?tie@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEAAPEAV?$basic_ostream@_WU?$char_traits@_W@std@@@2@PEAV32@@Z */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_tie_set, 8)
+/*basic_ostream_wchar*/void* __thiscall basic_ios_wchar_tie_set(basic_ios_wchar *this, /*basic_ostream_wchar*/void *ostream)
+{
+    FIXME("(%p %p) stub\n", this, ostream);
+    return NULL;
+}
+
+/* ?tie@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QBEPAV?$basic_ostream@_WU?$char_traits@_W@std@@@2@XZ */
+/* ?tie@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEBAPEAV?$basic_ostream@_WU?$char_traits@_W@std@@@2@XZ */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_tie_get, 4)
+/*basic_ostream_wchar*/void* __thiscall basic_ios_wchar_tie_get(const basic_ios_wchar *this)
+{
+    FIXME("(%p)\n", this);
+    return NULL;
+}
+
+/* ?widen@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QBE_WD@Z */
+/* ?widen@?$basic_ios@_WU?$char_traits@_W@std@@@std@@QEBA_WD@Z */
+DEFINE_THISCALL_WRAPPER(basic_ios_wchar_widen, 8)
+wchar_t __thiscall basic_ios_wchar_widen(basic_ios_wchar *this, char ch)
+{
+    FIXME("(%p %c)\n", this, ch);
+    return 0;
+}
+
 /* ??0?$basic_streambuf@DU?$char_traits@D@std@@@std@@IAE@W4_Uninitialized@1@@Z */
 /* ??0?$basic_streambuf@DU?$char_traits@D@std@@@std@@IEAA@W4_Uninitialized@1@@Z */
 DEFINE_THISCALL_WRAPPER(basic_streambuf_char_ctor_uninitialized, 8)
@@ -1141,10 +1191,9 @@ void __thiscall basic_streambuf_char_gbump(basic_streambuf_char *this, int off)
 
 /* ?getloc@?$basic_streambuf@DU?$char_traits@D@std@@@std@@QBE?AVlocale@2@XZ */
 /* ?getloc@?$basic_streambuf@DU?$char_traits@D@std@@@std@@QEBA?AVlocale@2@XZ */
-DEFINE_THISCALL_WRAPPER(basic_streambuf_char_getloc, 4)
-locale __thiscall basic_streambuf_char_getloc(const basic_streambuf_char *this)
+DEFINE_THISCALL_WRAPPER(basic_streambuf_char_getloc, 8)
+locale* __thiscall basic_streambuf_char_getloc(const basic_streambuf_char *this, locale *ret)
 {
-    locale ret = { 0 }; /* FIXME */
     FIXME("(%p) stub\n", this);
     return ret;
 }
@@ -1221,50 +1270,49 @@ char* __thiscall basic_streambuf_char_pptr(const basic_streambuf_char *this)
 
 /* ?pubimbue@?$basic_streambuf@DU?$char_traits@D@std@@@std@@QAE?AVlocale@2@ABV32@@Z */
 /* ?pubimbue@?$basic_streambuf@DU?$char_traits@D@std@@@std@@QEAA?AVlocale@2@AEBV32@@Z */
-DEFINE_THISCALL_WRAPPER(basic_streambuf_char_pubimbue, 8)
-locale __thiscall basic_streambuf_char_pubimbue(basic_streambuf_char *this, const locale *loc)
+DEFINE_THISCALL_WRAPPER(basic_streambuf_char_pubimbue, 12)
+locale* __thiscall basic_streambuf_char_pubimbue(basic_streambuf_char *this, locale *ret, const locale *loc)
 {
-    locale ret = { 0 }; /* FIXME */
     FIXME("(%p %p) stub\n", this, loc);
     return ret;
 }
 
 /* ?pubseekoff@?$basic_streambuf@DU?$char_traits@D@std@@@std@@QAE?AV?$fpos@H@2@JHH@Z */
 /* ?pubseekoff@?$basic_streambuf@DU?$char_traits@D@std@@@std@@QEAA?AV?$fpos@H@2@_JHH@Z */
-DEFINE_THISCALL_WRAPPER_RETPTR(basic_streambuf_char_pubseekoff, 16)
-fpos_int __thiscall basic_streambuf_char_pubseekoff(basic_streambuf_char *this, streamoff off, int way, int mode)
+DEFINE_THISCALL_WRAPPER(basic_streambuf_char_pubseekoff, 20)
+fpos_int* __thiscall basic_streambuf_char_pubseekoff(basic_streambuf_char *this,
+        fpos_int *ret, streamoff off, int way, int mode)
 {
-    fpos_int ret = { 0 }; /* FIXME */
     FIXME("(%p %lu %d %d) stub\n", this, off, way, mode);
     return ret;
 }
 
 /* ?pubseekoff@?$basic_streambuf@DU?$char_traits@D@std@@@std@@QAE?AV?$fpos@H@2@JII@Z */
 /* ?pubseekoff@?$basic_streambuf@DU?$char_traits@D@std@@@std@@QEAA?AV?$fpos@H@2@_JII@Z */
-DEFINE_THISCALL_WRAPPER_RETPTR(basic_streambuf_char_pubseekoff_old, 16)
-fpos_int __thiscall basic_streambuf_char_pubseekoff_old(basic_streambuf_char *this, streamoff off, unsigned int way, unsigned int mode)
+DEFINE_THISCALL_WRAPPER(basic_streambuf_char_pubseekoff_old, 20)
+fpos_int* __thiscall basic_streambuf_char_pubseekoff_old(basic_streambuf_char *this,
+        fpos_int *ret, streamoff off, unsigned int way, unsigned int mode)
 {
-    fpos_int ret = { 0 }; /* FIXME */
     FIXME("(%p %lu %d %d) stub\n", this, off, way, mode);
     return ret;
 }
 
 /* ?pubseekpos@?$basic_streambuf@DU?$char_traits@D@std@@@std@@QAE?AV?$fpos@H@2@V32@H@Z */
 /* ?pubseekpos@?$basic_streambuf@DU?$char_traits@D@std@@@std@@QEAA?AV?$fpos@H@2@V32@H@Z */
-DEFINE_THISCALL_WRAPPER_RETPTR(basic_streambuf_char_pubseekpos, 32)
-fpos_int __thiscall basic_streambuf_char_pubseekpos(basic_streambuf_char *this, fpos_int pos, int mode)
+DEFINE_THISCALL_WRAPPER(basic_streambuf_char_pubseekpos, 36)
+fpos_int* __thiscall basic_streambuf_char_pubseekpos(basic_streambuf_char *this,
+        fpos_int *ret, fpos_int pos, int mode)
 {
-    fpos_int ret = { 0 }; /* FIXME */
     FIXME("(%p %s %d) stub\n", this, debugstr_fpos_int(&pos), mode);
     return ret;
 }
 
 /* ?pubseekpos@?$basic_streambuf@DU?$char_traits@D@std@@@std@@QAE?AV?$fpos@H@2@V32@I@Z */
 /* ?pubseekpos@?$basic_streambuf@DU?$char_traits@D@std@@@std@@QEAA?AV?$fpos@H@2@V32@I@Z */
-DEFINE_THISCALL_WRAPPER_RETPTR(basic_streambuf_char_pubseekpos_old, 32)
-fpos_int __thiscall basic_streambuf_char_pubseekpos_old(basic_streambuf_char *this, fpos_int pos, unsigned int mode)
+DEFINE_THISCALL_WRAPPER(basic_streambuf_char_pubseekpos_old, 36)
+fpos_int* __thiscall basic_streambuf_char_pubseekpos_old(basic_streambuf_char *this,
+        fpos_int *ret, fpos_int pos, unsigned int mode)
 {
-    fpos_int ret = { 0 }; /* FIXME */
     FIXME("(%p %s %d) stub\n", this, debugstr_fpos_int(&pos), mode);
     return ret;
 }
@@ -1298,20 +1346,20 @@ int __thiscall basic_streambuf_char_sbumpc(basic_streambuf_char *this)
 
 /* ?seekoff@?$basic_streambuf@DU?$char_traits@D@std@@@std@@MAE?AV?$fpos@H@2@JHH@Z */
 /* ?seekoff@?$basic_streambuf@DU?$char_traits@D@std@@@std@@MEAA?AV?$fpos@H@2@_JHH@Z */
-DEFINE_THISCALL_WRAPPER_RETPTR(basic_streambuf_char_seekoff, 16)
-fpos_int __thiscall basic_streambuf_char_seekoff(basic_streambuf_char *this, streamoff off, int way, int mode)
+DEFINE_THISCALL_WRAPPER(basic_streambuf_char_seekoff, 20)
+fpos_int* __thiscall basic_streambuf_char_seekoff(basic_streambuf_char *this,
+        fpos_int *ret, streamoff off, int way, int mode)
 {
-    fpos_int ret = { 0 }; /* FIXME */
     FIXME("(%p %lu %d %d) stub\n", this, off, way, mode);
     return ret;
 }
 
 /* ?seekpos@?$basic_streambuf@DU?$char_traits@D@std@@@std@@MAE?AV?$fpos@H@2@V32@H@Z */
 /* ?seekpos@?$basic_streambuf@DU?$char_traits@D@std@@@std@@MEAA?AV?$fpos@H@2@V32@H@Z */
-DEFINE_THISCALL_WRAPPER_RETPTR(basic_streambuf_char_seekpos, 32)
-fpos_int __thiscall basic_streambuf_char_seekpos(basic_streambuf_char *this, fpos_int pos, int mode)
+DEFINE_THISCALL_WRAPPER(basic_streambuf_char_seekpos, 36)
+fpos_int* __thiscall basic_streambuf_char_seekpos(basic_streambuf_char *this,
+        fpos_int *ret, fpos_int pos, int mode)
 {
-    fpos_int ret = { 0 }; /* FIXME */
     FIXME("(%p %s %d) stub\n", this, debugstr_fpos_int(&pos), mode);
     return ret;
 }
@@ -1711,10 +1759,9 @@ basic_ostream_char* __thiscall basic_ostream_char_seekp_fpos(basic_ostream_char
 
 /* ?tellp@?$basic_ostream@DU?$char_traits@D@std@@@std@@QAE?AV?$fpos@H@2@XZ */
 /* ?tellp@?$basic_ostream@DU?$char_traits@D@std@@@std@@QEAA?AV?$fpos@H@2@XZ */
-DEFINE_THISCALL_WRAPPER_RETPTR(basic_ostream_char_tellp, 4)
-fpos_int __thiscall basic_ostream_char_tellp(basic_ostream_char *this)
+DEFINE_THISCALL_WRAPPER(basic_ostream_char_tellp, 8)
+fpos_int* __thiscall basic_ostream_char_tellp(basic_ostream_char *this, fpos_int *ret)
 {
-    fpos_int ret = { 0 }; /* FIXME */
     FIXME("(%p) stub\n", this);
     return ret;
 }
