@@ -140,7 +140,7 @@ typedef struct __cxx_exception_type
     const cxx_type_info_table *type_info_table;  /* list of types for this exception object */
 } cxx_exception_type;
 
-void CDECL _CxxThrowException(exception*,const cxx_exception_type*);
+void WINAPI _CxxThrowException(exception*,const cxx_exception_type*);
 int CDECL _XcptFilter(NTSTATUS, PEXCEPTION_POINTERS);
 int CDECL __CppXcptFilter(NTSTATUS, PEXCEPTION_POINTERS);
 
