@@ -1278,7 +1278,7 @@ char * CDECL _ecvt( double number, int ndigits, int *decpt, int *sign )
 {
     int prec, len;
     thread_data_t *data = msvcrt_get_thread_data();
-    /* FIXME: check better for overflow (native supports over 300 chars's) */
+    /* FIXME: check better for overflow (native supports over 300 chars) */
     ndigits = min( ndigits, 80 - 7); /* 7 : space for dec point, 1 for "e",
                                       * 4 for exponent and one for
                                       * terminating '\0' */
@@ -1351,7 +1351,7 @@ int CDECL _ecvt_s( char *buffer, MSVCRT_size_t length, double number, int ndigit
     /* handle cases with zero ndigits or less */
     prec = ndigits;
     if( prec < 1) prec = 2;
-    result = (char*)MSVCRT_malloc(prec + 7);
+    result = MSVCRT_malloc(prec + 7);
 
     if( number < 0) {
         *sign = TRUE;
