@@ -26,7 +26,7 @@
 #ifdef WIDE_SCANF
 #define _CHAR_ MSVCRT_wchar_t
 #define _EOF_ MSVCRT_WEOF
-#define _EOF_RET MSVCRT_WEOF
+#define _EOF_RET (short)MSVCRT_WEOF
 #define _ISSPACE_(c) MSVCRT_iswspace(c)
 #define _ISDIGIT_(c) MSVCRT_iswdigit(c)
 #define _WIDE2SUPPORTED_(c) c /* No conversion needed (wide to wide) */
@@ -48,6 +48,8 @@
 #ifdef CONSOLE
 #define _GETC_(file) (consumed++, _getch())
 #define _UNGETC_(nch, file) do { _ungetch(nch); consumed--; } while(0)
+#define _LOCK_FILE_(file) MSVCRT__lock_file(MSVCRT_stdin)
+#define _UNLOCK_FILE_(file) MSVCRT__unlock_file(MSVCRT_stdin)
 #ifdef WIDE_SCANF
 #ifdef SECURE
 #define _FUNCTION_ static int MSVCRT_vcwscanf_s_l(const char *format, MSVCRT__locale_t locale, __ms_va_list ap)
@@ -68,6 +70,8 @@
 #ifdef STRING_LEN
 #define _GETC_(file) (consumed==length ? '\0' : (consumed++, *file++))
 #define _UNGETC_(nch, file) do { file--; consumed--; } while(0)
+#define _LOCK_FILE_(file) do {} while(0)
+#define _UNLOCK_FILE_(file) do {} while(0)
 #ifdef WIDE_SCANF
 #ifdef SECURE
 #define _FUNCTION_ static int MSVCRT_vsnwscanf_s_l(const MSVCRT_wchar_t *file, MSVCRT_size_t length, const MSVCRT_wchar_t *format, MSVCRT__locale_t locale, __ms_va_list ap)
@@ -84,6 +88,8 @@
 #else /* STRING_LEN */
 #define _GETC_(file) (consumed++, *file++)
 #define _UNGETC_(nch, file) do { file--; consumed--; } while(0)
+#define _LOCK_FILE_(file) do {} while(0)
+#define _UNLOCK_FILE_(file) do {} while(0)
 #ifdef WIDE_SCANF
 #ifdef SECURE
 #define _FUNCTION_ static int MSVCRT_vswscanf_s_l(const MSVCRT_wchar_t *file, const MSVCRT_wchar_t *format, MSVCRT__locale_t locale, __ms_va_list ap)
@@ -102,6 +108,8 @@
 #ifdef WIDE_SCANF
 #define _GETC_(file) (consumed++, MSVCRT_fgetwc(file))
 #define _UNGETC_(nch, file) do { MSVCRT_ungetwc(nch, file); consumed--; } while(0)
+#define _LOCK_FILE_(file) MSVCRT__lock_file(file)
+#define _UNLOCK_FILE_(file) MSVCRT__unlock_file(file)
 #ifdef SECURE
 #define _FUNCTION_ static int MSVCRT_vfwscanf_s_l(MSVCRT_FILE* file, const MSVCRT_wchar_t *format, MSVCRT__locale_t locale, __ms_va_list ap)
 #else  /* SECURE */
@@ -110,6 +118,8 @@
 #else /* WIDE_SCANF */
 #define _GETC_(file) (consumed++, MSVCRT_fgetc(file))
 #define _UNGETC_(nch, file) do { MSVCRT_ungetc(nch, file); consumed--; } while(0)
+#define _LOCK_FILE_(file) MSVCRT__lock_file(file)
+#define _UNLOCK_FILE_(file) MSVCRT__unlock_file(file)
 #ifdef SECURE
 #define _FUNCTION_ static int MSVCRT_vfscanf_s_l(MSVCRT_FILE* file, const char *format, MSVCRT__locale_t locale, __ms_va_list ap)
 #else  /* SECURE */
@@ -120,6 +130,7 @@
 #endif /* CONSOLE */
 
 _FUNCTION_ {
+    MSVCRT_pthreadlocinfo locinfo;
     int rd = 0, consumed = 0;
     int nch;
     if (!*format) return 0;
@@ -134,11 +145,18 @@ _FUNCTION_ {
 #endif /* STRING */
 #endif /* CONSOLE */
 #endif /* WIDE_SCANF */
+    _LOCK_FILE_(file);
+
     nch = _GETC_(file);
-    if (nch == _EOF_) return _EOF_RET;
+    if (nch == _EOF_) {
+        _UNLOCK_FILE_(file);
+        return _EOF_RET;
+    }
 
     if(!locale)
-        locale = get_locale();
+        locinfo = get_locinfo();
+    else
+        locinfo = locale->locinfo;
 
     while (*format) {
 	/* a whitespace character in the format string causes scanf to read,
@@ -180,8 +198,14 @@ _FUNCTION_ {
 	    /* read prefix (if any) */
 	    while (!prefix_finished) {
 		switch(*format) {
-		case 'h': h_prefix = 1; break;
-		case 'l': l_prefix = 1; break;
+		case 'h': h_prefix++; break;
+		case 'l':
+                    if(*(format+1) == 'l') {
+                        I64_prefix = 1;
+                        format++;
+                    }
+                    l_prefix = 1;
+                    break;
 		case 'w': w_prefix = 1; break;
 		case 'L': L_prefix = 1; break;
 		case 'I':
@@ -276,7 +300,7 @@ _FUNCTION_ {
 #define _SET_NUMBER_(type) *va_arg(ap, type*) = negative ? -cur : cur
 			if (I64_prefix) _SET_NUMBER_(LONGLONG);
 			else if (l_prefix) _SET_NUMBER_(LONG);
-			else if (h_prefix) _SET_NUMBER_(short int);
+			else if (h_prefix == 1) _SET_NUMBER_(short int);
 			else _SET_NUMBER_(int);
 		    }
                 }
@@ -299,7 +323,7 @@ _FUNCTION_ {
                         nch = _GETC_(file);
                     }
 		    /* get first digit. */
-		    if (*locale->locinfo->lconv->decimal_point != nch) {
+		    if (*locinfo->lconv->decimal_point != nch) {
 		      if (!_ISDIGIT_(nch)) break;
 		      cur = (nch - '0');
 		      nch = _GETC_(file);
@@ -314,7 +338,7 @@ _FUNCTION_ {
 		      cur = 0; /* Fix: .8 -> 0.8 */
 		    }
 		    /* handle decimals */
-                    if (width!=0 && nch == *locale->locinfo->lconv->decimal_point) {
+                    if (width!=0 && nch == *locinfo->lconv->decimal_point) {
                         long double dec = 1;
                         nch = _GETC_(file);
 			if (width>0) width--;
@@ -400,6 +424,7 @@ _FUNCTION_ {
                             *sptr++ = _CHAR2SUPPORTED_(nch);
                             if(size>1) size--;
                             else {
+                                _UNLOCK_FILE_(file);
                                 *sptr_beg = 0;
                                 return rd;
                             }
@@ -429,6 +454,7 @@ _FUNCTION_ {
                             *sptr++ = _WIDE2SUPPORTED_(nch);
                             if(size>1) size--;
                             else {
+                                _UNLOCK_FILE_(file);
                                 *sptr_beg = 0;
                                 return rd;
                             }
@@ -474,6 +500,7 @@ _FUNCTION_ {
                             *str++ = _CHAR2SUPPORTED_(nch);
                             if(size) size--;
                             else {
+                                _UNLOCK_FILE_(file);
                                 *pstr = 0;
                                 return rd;
                             }
@@ -499,6 +526,7 @@ _FUNCTION_ {
                             *str++ = _WIDE2SUPPORTED_(nch);
                             if(size) size--;
                             else {
+                                _UNLOCK_FILE_(file);
                                 *pstr = 0;
                                 return rd;
                             }
@@ -586,6 +614,7 @@ _FUNCTION_ {
                         if (width>0) width--;
                         if(size>1) size--;
                         else {
+                            _UNLOCK_FILE_(file);
                             *str = 0;
                             return rd;
                         }
@@ -628,7 +657,9 @@ _FUNCTION_ {
     if (nch!=_EOF_) {
 	_UNGETC_(nch, file);
     }
+
     TRACE("returning %d\n", rd);
+    _UNLOCK_FILE_(file);
     return rd;
 }
 
@@ -642,5 +673,7 @@ _FUNCTION_ {
 #undef _CHAR2DIGIT_
 #undef _GETC_
 #undef _UNGETC_
+#undef _LOCK_FILE_
+#undef _UNLOCK_FILE_
 #undef _FUNCTION_
 #undef _BITMAPSIZE_
