@@ -842,7 +842,7 @@ __int64 CDECL MSVCRT_strtoi64_l(const char *nptr, char **endptr, int base, MSVCR
     BOOL negative = FALSE;
     __int64 ret = 0;
 
-    TRACE("(%s %p %d %p)\n", nptr, endptr, base, locale);
+    TRACE("(%s %p %d %p)\n", debugstr_a(nptr), endptr, base, locale);
 
     if (!MSVCRT_CHECK_PMT(nptr != NULL) || !MSVCRT_CHECK_PMT(base == 0 || base >= 2) ||
         !MSVCRT_CHECK_PMT(base <= 36)) {
@@ -922,7 +922,7 @@ unsigned __int64 CDECL MSVCRT_strtoui64_l(const char *nptr, char **endptr, int b
     BOOL negative = FALSE;
     unsigned __int64 ret = 0;
 
-    TRACE("(%s %p %d %p)\n", nptr, endptr, base, locale);
+    TRACE("(%s %p %d %p)\n", debugstr_a(nptr), endptr, base, locale);
 
     if (!MSVCRT_CHECK_PMT(nptr != NULL) || !MSVCRT_CHECK_PMT(base == 0 || base >= 2) ||
         !MSVCRT_CHECK_PMT(base <= 36)) {
@@ -1287,6 +1287,60 @@ int CDECL _ultoa_s(MSVCRT_ulong value, char *str, MSVCRT_size_t size, int radix)
     return 0;
 }
 
+/*********************************************************************
+ *  _ultow_s (MSVCRT.@)
+ */
+int CDECL _ultow_s(MSVCRT_ulong value, WCHAR *str, MSVCRT_size_t size, int radix)
+{
+    MSVCRT_ulong digit;
+    WCHAR buffer[33], *pos;
+    size_t len;
+
+    if (!str || !size || radix < 2 || radix > 36)
+    {
+        if (str && size)
+            str[0] = '\0';
+
+        *MSVCRT__errno() = MSVCRT_EINVAL;
+        return MSVCRT_EINVAL;
+    }
+
+    pos = buffer + 32;
+    *pos = '\0';
+
+    do
+    {
+        digit = value % radix;
+        value /= radix;
+
+        if (digit < 10)
+            *--pos = '0' + digit;
+        else
+            *--pos = 'a' + digit - 10;
+    }
+    while (value != 0);
+
+    len = buffer + 33 - pos;
+    if (len > size)
+    {
+        size_t i;
+        WCHAR *p = str;
+
+        /* Copy the temporary buffer backwards up to the available number of
+         * characters. */
+
+        for (pos = buffer + 31, i = 0; i < size; i++)
+            *p++ = *pos--;
+
+        str[0] = '\0';
+        *MSVCRT__errno() = MSVCRT_ERANGE;
+        return MSVCRT_ERANGE;
+    }
+
+    memcpy(str, pos, len * sizeof(WCHAR));
+    return 0;
+}
+
 /*********************************************************************
  *  _i64toa_s (MSVCRT.@)
  */
