@@ -44,6 +44,17 @@ static int (__cdecl *p__ecvt_s)(char *buffer, size_t length, double number,
 static int (__cdecl *p__fcvt_s)(char *buffer, size_t length, double number,
                                 int ndigits, int *decpt, int *sign);
 static unsigned int (__cdecl *p__get_output_format)(void);
+static int (__cdecl *p__vsprintf_p)(char*, size_t, const char*, __ms_va_list);
+static int (__cdecl *p_vswprintf)(wchar_t *str, const wchar_t *format, __ms_va_list valist);
+static int (__cdecl *p__vswprintf)(wchar_t *str, const wchar_t *format, __ms_va_list valist);
+static int (__cdecl *p__vswprintf_l)(wchar_t *str, const wchar_t *format,
+                                     void *locale, __ms_va_list valist);
+static int (__cdecl *p__vswprintf_c)(wchar_t *str, size_t size, const wchar_t *format,
+                                     __ms_va_list valist);
+static int (__cdecl *p__vswprintf_c_l)(wchar_t *str, size_t size, const wchar_t *format,
+                                       void *locale, __ms_va_list valist);
+static int (__cdecl *p__vswprintf_p_l)(wchar_t *str, size_t size, const wchar_t *format,
+                                       void *locale, __ms_va_list valist);
 
 static void init( void )
 {
@@ -55,6 +66,13 @@ static void init( void )
     p__ecvt_s = (void *)GetProcAddress(hmod, "_ecvt_s");
     p__fcvt_s = (void *)GetProcAddress(hmod, "_fcvt_s");
     p__get_output_format = (void *)GetProcAddress(hmod, "_get_output_format");
+    p__vsprintf_p = (void*)GetProcAddress(hmod, "_vsprintf_p");
+    p_vswprintf = (void*)GetProcAddress(hmod, "vswprintf");
+    p__vswprintf = (void*)GetProcAddress(hmod, "_vswprintf");
+    p__vswprintf_l = (void*)GetProcAddress(hmod, "_vswprintf_l");
+    p__vswprintf_c = (void*)GetProcAddress(hmod, "_vswprintf_c");
+    p__vswprintf_c_l = (void*)GetProcAddress(hmod, "_vswprintf_c_l");
+    p__vswprintf_p_l = (void*)GetProcAddress(hmod, "_vswprintf_p_l");
 }
 
 static void test_sprintf( void )
@@ -625,6 +643,41 @@ static void test_snprintf (void)
     };
 }
 
+static void test_fprintf(void)
+{
+    static char file_name[] = "fprintf.tst";
+    FILE *fp = fopen(file_name, "wb");
+    char buf[1024];
+    int ret;
+
+    ret = fprintf(fp, "simple test\n");
+    ok(ret == 12, "ret = %d\n", ret);
+    ret = ftell(fp);
+    ok(ret == 12, "ftell returned %d\n", ret);
+
+    ret = fprintf(fp, "contains%cnull\n", '\0');
+    ok(ret == 14, "ret = %d\n", ret);
+    ret = ftell(fp);
+    ok(ret == 26, "ftell returned %d\n", ret);
+
+    fclose(fp);
+
+    fp = fopen(file_name, "rb");
+    ret = fscanf(fp, "%[^\n] ", buf);
+    ok(ret == 1, "ret = %d\n", ret);
+    ret = ftell(fp);
+    ok(ret == 12, "ftell returned %d\n", ret);
+    ok(!strcmp(buf, "simple test"), "buf = %s\n", buf);
+
+    fgets(buf, sizeof(buf), fp);
+    ret = ftell(fp);
+    ok(ret == 26, "ret = %d\n", ret);
+    ok(!memcmp(buf, "contains\0null\n", 14), "buf = %s\n", buf);
+
+    fclose(fp);
+    unlink(file_name);
+}
+
 static void test_fcvt(void)
 {
     char *str;
@@ -906,6 +959,112 @@ static void test_vsnwprintf(void)
     ok( !strcmp(buf, "onetwothree"), "got %s expected 'onetwothree'\n", buf );
 }
 
+static int __cdecl vswprintf_wrapper(wchar_t *str, const wchar_t *format, ...)
+{
+    int ret;
+    __ms_va_list valist;
+    __ms_va_start(valist, format);
+    ret = p_vswprintf(str, format, valist);
+    __ms_va_end(valist);
+    return ret;
+}
+
+static int __cdecl _vswprintf_wrapper(wchar_t *str, const wchar_t *format, ...)
+{
+    int ret;
+    __ms_va_list valist;
+    __ms_va_start(valist, format);
+    ret = p__vswprintf(str, format, valist);
+    __ms_va_end(valist);
+    return ret;
+}
+
+static int __cdecl _vswprintf_l_wrapper(wchar_t *str, const wchar_t *format, void *locale, ...)
+{
+    int ret;
+    __ms_va_list valist;
+    __ms_va_start(valist, locale);
+    ret = p__vswprintf_l(str, format, locale, valist);
+    __ms_va_end(valist);
+    return ret;
+}
+
+static int __cdecl _vswprintf_c_wrapper(wchar_t *str, size_t size, const wchar_t *format, ...)
+{
+    int ret;
+    __ms_va_list valist;
+    __ms_va_start(valist, format);
+    ret = p__vswprintf_c(str, size, format, valist);
+    __ms_va_end(valist);
+    return ret;
+}
+
+static int __cdecl _vswprintf_c_l_wrapper(wchar_t *str, size_t size, const wchar_t *format, void *locale, ...)
+{
+    int ret;
+    __ms_va_list valist;
+    __ms_va_start(valist, locale);
+    ret = p__vswprintf_c_l(str, size, format, locale, valist);
+    __ms_va_end(valist);
+    return ret;
+}
+
+static int __cdecl _vswprintf_p_l_wrapper(wchar_t *str, size_t size, const wchar_t *format, void *locale, ...)
+{
+    int ret;
+    __ms_va_list valist;
+    __ms_va_start(valist, locale);
+    ret = p__vswprintf_p_l(str, size, format, locale, valist);
+    __ms_va_end(valist);
+    return ret;
+}
+
+static void test_vswprintf(void)
+{
+    const wchar_t format[] = {'%','s',' ','%','d',0};
+    const wchar_t number[] = {'n','u','m','b','e','r',0};
+    const wchar_t out[] = {'n','u','m','b','e','r',' ','1','2','3',0};
+    wchar_t buf[20];
+
+    int ret;
+
+    if (!p_vswprintf || !p__vswprintf || !p__vswprintf_l ||!p__vswprintf_c
+            || !p__vswprintf_c_l || !p__vswprintf_p_l)
+    {
+        win_skip("_vswprintf or vswprintf not available\n");
+        return;
+    }
+
+    ret = vswprintf_wrapper(buf, format, number, 123);
+    ok(ret == 10, "got %d, expected 10\n", ret);
+    ok(!memcmp(buf, out, sizeof(out)), "buf = %s\n", wine_dbgstr_w(buf));
+
+    memset(buf, 0, sizeof(buf));
+    ret = _vswprintf_wrapper(buf, format, number, 123);
+    ok(ret == 10, "got %d, expected 10\n", ret);
+    ok(!memcmp(buf, out, sizeof(out)), "buf = %s\n", wine_dbgstr_w(buf));
+
+    memset(buf, 0, sizeof(buf));
+    ret = _vswprintf_l_wrapper(buf, format, NULL, number, 123);
+    ok(ret == 10, "got %d, expected 10\n", ret);
+    ok(!memcmp(buf, out, sizeof(out)), "buf = %s\n", wine_dbgstr_w(buf));
+
+    memset(buf, 0, sizeof(buf));
+    ret = _vswprintf_c_wrapper(buf, 20, format, number, 123);
+    ok(ret == 10, "got %d, expected 10\n", ret);
+    ok(!memcmp(buf, out, sizeof(out)), "buf = %s\n", wine_dbgstr_w(buf));
+
+    memset(buf, 0, sizeof(buf));
+    ret = _vswprintf_c_l_wrapper(buf, 20, format, NULL, number, 123);
+    ok(ret == 10, "got %d, expected 10\n", ret);
+    ok(!memcmp(buf, out, sizeof(out)), "buf = %s\n", wine_dbgstr_w(buf));
+
+    memset(buf, 0, sizeof(buf));
+    ret = _vswprintf_p_l_wrapper(buf, 20, format, NULL, number, 123);
+    ok(ret == 10, "got %d, expected 10\n", ret);
+    ok(!memcmp(buf, out, sizeof(out)), "buf = %s\n", wine_dbgstr_w(buf));
+}
+
 static int __cdecl _vscprintf_wrapper(const char *format, ...)
 {
     int ret;
@@ -1015,6 +1174,47 @@ static void test_vsnwprintf_s(void)
     ok( !wcscmp(out1, buffer), "buffer wrong, got=%s\n", wine_dbgstr_w(buffer));
 }
 
+static int __cdecl _vsprintf_p_wrapper(char *str, size_t sizeOfBuffer,
+                                 const char *format, ...)
+{
+    int ret;
+    __ms_va_list valist;
+    __ms_va_start(valist, format);
+    ret = p__vsprintf_p(str, sizeOfBuffer, format, valist);
+    __ms_va_end(valist);
+    return ret;
+}
+
+static void test_vsprintf_p(void)
+{
+    char buf[1024];
+    int ret;
+
+    if(!p__vsprintf_p) {
+        win_skip("vsprintf_p not available\n");
+        return;
+    }
+
+    ret = _vsprintf_p_wrapper(buf, sizeof(buf), "%s %d", "test", 1234);
+    ok(ret == 9, "ret = %d\n", ret);
+    ok(!memcmp(buf, "test 1234", 10), "buf = %s\n", buf);
+
+    ret = _vsprintf_p_wrapper(buf, sizeof(buf), "%1$d", 1234, "additional param");
+    ok(ret == 4, "ret = %d\n", ret);
+    ok(!memcmp(buf, "1234", 5), "buf = %s\n", buf);
+
+    ret = _vsprintf_p_wrapper(buf, sizeof(buf), "%2$s %1$d", 1234, "test");
+    ok(ret == 9, "ret = %d\n", ret);
+    ok(!memcmp(buf, "test 1234", 10), "buf = %s\n", buf);
+
+    ret = _vsprintf_p_wrapper(buf, sizeof(buf), "%2$*3$s %2$.*1$s", 2, "test", 3);
+    ok(ret == 7, "ret = %d\n", ret);
+    ok(!memcmp(buf, "test te", 8), "buf = %s\n", buf);
+
+    /* Following test invokes invalid parameter handler */
+    /* ret = _vsprintf_p_wrapper(buf, sizeof(buf), "%d %1$d", 1234); */
+}
+
 static void test__get_output_format(void)
 {
     unsigned int ret;
@@ -1036,11 +1236,14 @@ START_TEST(printf)
     test_sprintf();
     test_swprintf();
     test_snprintf();
+    test_fprintf();
     test_fcvt();
     test_xcvt();
     test_vsnwprintf();
     test_vscprintf();
     test_vscwprintf();
+    test_vswprintf();
     test_vsnwprintf_s();
+    test_vsprintf_p();
     test__get_output_format();
 }
