@@ -36,6 +36,7 @@
 #include "winbase.h"
 #include "winnls.h"
 #include "wine/debug.h"
+#include "wine/unicode.h"
 
 WINE_DEFAULT_DEBUG_CHANNEL(msvcrt);
 
@@ -655,12 +656,12 @@ int CDECL MSVCRT__ftime32_s(struct MSVCRT___timeb32 *buf)
 #ifdef _WIN64
 void CDECL MSVCRT__ftime(struct MSVCRT___timeb64 *buf)
 {
-    return MSVCRT__ftime64( buf );
+    MSVCRT__ftime64( buf );
 }
 #else
 void CDECL MSVCRT__ftime(struct MSVCRT___timeb32 *buf)
 {
-    return MSVCRT__ftime32( buf );
+    MSVCRT__ftime32( buf );
 }
 #endif
 
@@ -902,6 +903,31 @@ char * CDECL MSVCRT_asctime(const struct MSVCRT_tm *mstm)
     return data->asctime_buffer;
 }
 
+/*********************************************************************
+ *      asctime_s (MSVCRT.@)
+ */
+int CDECL MSVCRT_asctime_s(char* time, MSVCRT_size_t size, const struct MSVCRT_tm *mstm)
+{
+    char* asc;
+    unsigned int len;
+
+    if (!MSVCRT_CHECK_PMT(time != NULL) || !MSVCRT_CHECK_PMT(mstm != NULL)) {
+        *MSVCRT__errno() = MSVCRT_EINVAL;
+        return MSVCRT_EINVAL;
+    }
+
+    asc = MSVCRT_asctime(mstm);
+    len = strlen(asc) + 1;
+
+    if(!MSVCRT_CHECK_PMT(size >= len)) {
+        *MSVCRT__errno() = MSVCRT_ERANGE;
+        return MSVCRT_ERANGE;
+    }
+
+    strcpy(time, asc);
+    return 0;
+}
+
 /*********************************************************************
  *		_wasctime (MSVCRT.@)
  */
@@ -924,6 +950,31 @@ MSVCRT_wchar_t * CDECL MSVCRT__wasctime(const struct MSVCRT_tm *mstm)
     return data->wasctime_buffer;
 }
 
+/*********************************************************************
+ *      _wasctime_s (MSVCRT.@)
+ */
+int CDECL MSVCRT__wasctime_s(MSVCRT_wchar_t* time, MSVCRT_size_t size, const struct MSVCRT_tm *mstm)
+{
+    WCHAR* asc;
+    unsigned int len;
+
+    if (!MSVCRT_CHECK_PMT(time != NULL) || !MSVCRT_CHECK_PMT(mstm != NULL)) {
+        *MSVCRT__errno() = MSVCRT_EINVAL;
+        return MSVCRT_EINVAL;
+    }
+
+    asc = MSVCRT__wasctime(mstm);
+    len = (strlenW(asc) + 1) * sizeof(WCHAR);
+
+    if(!MSVCRT_CHECK_PMT(size >= len)) {
+        *MSVCRT__errno() = MSVCRT_ERANGE;
+        return MSVCRT_ERANGE;
+    }
+
+    strcpyW(time, asc);
+    return 0;
+}
+
 /*********************************************************************
  *		_ctime64 (MSVCRT.@)
  */
