@@ -126,9 +126,10 @@ static tid_id_t tid_ids[] = {
     { &IID_IXMLDOMNamedNodeMap, LibXml2 },
     { &IID_IXMLDOMNode, LibXml2 },
     { &IID_IXMLDOMNodeList, LibXml2 },
-    { &IID_IXMLDOMParseError, LibXml2 },
+    { &IID_IXMLDOMParseError2, LibXml2 },
     { &IID_IXMLDOMProcessingInstruction, LibXml2 },
     { &IID_IXMLDOMSchemaCollection, LibXml2 },
+    { &IID_IXMLDOMSchemaCollection2, LibXml2 },
     { &IID_IXMLDOMSelection, LibXml2 },
     { &IID_IXMLDOMText, LibXml2 },
     { &IID_IXMLElement, LibXml },
@@ -552,6 +553,7 @@ static HRESULT WINAPI DispatchEx_InvokeEx(IDispatchEx *iface, DISPID id, LCID lc
 
         switch(wFlags) {
         case INVOKE_PROPERTYGET:
+            V_VT(pvarRes) = VT_EMPTY;
             return VariantCopy(pvarRes, var);
         case INVOKE_PROPERTYPUT:
             VariantClear(var);
