@@ -39,10 +39,10 @@
 
 WINE_DEFAULT_DEBUG_CHANNEL(msxml);
 
-#ifdef HAVE_LIBXML2
-
 static const WCHAR utf16W[] = {'U','T','F','-','1','6',0};
 static const WCHAR emptyW[] = {0};
+static const WCHAR spaceW[] = {' '};
+static const WCHAR quotW[]  = {'\"'};
 
 typedef enum
 {
@@ -68,6 +68,12 @@ typedef enum
     MXWriter_LastProp
 } mxwriter_prop;
 
+typedef enum
+{
+    EscapeValue,
+    EscapeText
+} escape_mode;
+
 typedef struct
 {
     char *data;
@@ -87,12 +93,14 @@ typedef struct
     DispatchEx dispex;
     IMXWriter IMXWriter_iface;
     ISAXContentHandler ISAXContentHandler_iface;
+    ISAXLexicalHandler ISAXLexicalHandler_iface;
 
     LONG ref;
     MSXML_VERSION class_version;
 
     VARIANT_BOOL props[MXWriter_LastProp];
     BOOL prop_changed;
+    BOOL cdata;
 
     BSTR version;
 
@@ -249,6 +257,15 @@ static HRESULT write_output_buffer(output_buffer *buffer, const WCHAR *data, int
     return write_output_buffer_mode(buffer, OutputBuffer_Both, data, len);
 }
 
+static HRESULT write_output_buffer_quoted(output_buffer *buffer, const WCHAR *data, int len)
+{
+    write_output_buffer(buffer, quotW, 1);
+    write_output_buffer(buffer, data, len);
+    write_output_buffer(buffer, quotW, 1);
+
+    return S_OK;
+}
+
 /* frees buffer data, reallocates with a default lengths */
 static void close_output_buffer(mxwriter *This)
 {
@@ -265,12 +282,12 @@ static void close_output_buffer(mxwriter *This)
    '"' -> "&quot;"
    '>' -> "&gt;"
 */
-static WCHAR *get_escaped_string(const WCHAR *str, int *len)
+static WCHAR *get_escaped_string(const WCHAR *str, escape_mode mode, int *len)
 {
-    static const WCHAR ltW[]   = {'&','l','t',';'};
-    static const WCHAR ampW[]  = {'&','a','m','p',';'};
-    static const WCHAR quotW[] = {'&','q','u','o','t',';'};
-    static const WCHAR gtW[]   = {'&','g','t',';'};
+    static const WCHAR ltW[]    = {'&','l','t',';'};
+    static const WCHAR ampW[]   = {'&','a','m','p',';'};
+    static const WCHAR equotW[] = {'&','q','u','o','t',';'};
+    static const WCHAR gtW[]    = {'&','g','t',';'};
 
     const int default_alloc = 100;
     const int grow_thresh = 10;
@@ -301,14 +318,18 @@ static WCHAR *get_escaped_string(const WCHAR *str, int *len)
             memcpy(ptr, ampW, sizeof(ampW));
             ptr += sizeof(ampW)/sizeof(WCHAR);
             break;
-        case '"':
-            memcpy(ptr, quotW, sizeof(quotW));
-            ptr += sizeof(quotW)/sizeof(WCHAR);
-            break;
         case '>':
             memcpy(ptr, gtW, sizeof(gtW));
             ptr += sizeof(gtW)/sizeof(WCHAR);
             break;
+        case '"':
+            if (mode == EscapeValue)
+            {
+                memcpy(ptr, equotW, sizeof(equotW));
+                ptr += sizeof(equotW)/sizeof(WCHAR);
+                break;
+            }
+            /* fallthrough for text mode */
         default:
             *ptr++ = *str;
             break;
@@ -326,18 +347,16 @@ static WCHAR *get_escaped_string(const WCHAR *str, int *len)
 
 static void write_prolog_buffer(const mxwriter *This)
 {
-    static const WCHAR versionW[] = {'<','?','x','m','l',' ','v','e','r','s','i','o','n','=','\"'};
+    static const WCHAR versionW[] = {'<','?','x','m','l',' ','v','e','r','s','i','o','n','='};
     static const WCHAR encodingW[] = {' ','e','n','c','o','d','i','n','g','=','\"'};
     static const WCHAR standaloneW[] = {' ','s','t','a','n','d','a','l','o','n','e','=','\"'};
     static const WCHAR yesW[] = {'y','e','s','\"','?','>'};
     static const WCHAR noW[] = {'n','o','\"','?','>'};
-    static const WCHAR quotW[] = {'\"'};
     static const WCHAR crlfW[] = {'\r','\n'};
 
     /* version */
     write_output_buffer(This->buffer, versionW, sizeof(versionW)/sizeof(WCHAR));
-    write_output_buffer(This->buffer, This->version, -1);
-    write_output_buffer(This->buffer, quotW, 1);
+    write_output_buffer_quoted(This->buffer, This->version, -1);
 
     /* encoding */
     write_output_buffer(This->buffer, encodingW, sizeof(encodingW)/sizeof(WCHAR));
@@ -421,6 +440,7 @@ static inline HRESULT flush_output_buffer(mxwriter *This)
 {
     close_element_starttag(This);
     set_element_name(This, NULL, 0);
+    This->cdata = FALSE;
     return write_data_to_stream(This);
 }
 
@@ -457,6 +477,11 @@ static inline mxwriter *impl_from_ISAXContentHandler(ISAXContentHandler *iface)
     return CONTAINING_RECORD(iface, mxwriter, ISAXContentHandler_iface);
 }
 
+static inline mxwriter *impl_from_ISAXLexicalHandler(ISAXLexicalHandler *iface)
+{
+    return CONTAINING_RECORD(iface, mxwriter, ISAXLexicalHandler_iface);
+}
+
 static HRESULT WINAPI mxwriter_QueryInterface(IMXWriter *iface, REFIID riid, void **obj)
 {
     mxwriter *This = impl_from_IMXWriter( iface );
@@ -475,6 +500,10 @@ static HRESULT WINAPI mxwriter_QueryInterface(IMXWriter *iface, REFIID riid, voi
     {
         *obj = &This->ISAXContentHandler_iface;
     }
+    else if ( IsEqualGUID( riid, &IID_ISAXLexicalHandler ) )
+    {
+        *obj = &This->ISAXLexicalHandler_iface;
+    }
     else if (dispex_query_interface(&This->dispex, riid, obj))
     {
         return *obj ? S_OK : E_NOINTERFACE;
@@ -813,7 +842,7 @@ static const struct IMXWriterVtbl MXWriterVtbl =
 };
 
 /*** ISAXContentHandler ***/
-static HRESULT WINAPI mxwriter_saxcontent_QueryInterface(
+static HRESULT WINAPI SAXContentHandler_QueryInterface(
     ISAXContentHandler *iface,
     REFIID riid,
     void **obj)
@@ -822,19 +851,19 @@ static HRESULT WINAPI mxwriter_saxcontent_QueryInterface(
     return IMXWriter_QueryInterface(&This->IMXWriter_iface, riid, obj);
 }
 
-static ULONG WINAPI mxwriter_saxcontent_AddRef(ISAXContentHandler *iface)
+static ULONG WINAPI SAXContentHandler_AddRef(ISAXContentHandler *iface)
 {
     mxwriter *This = impl_from_ISAXContentHandler( iface );
     return IMXWriter_AddRef(&This->IMXWriter_iface);
 }
 
-static ULONG WINAPI mxwriter_saxcontent_Release(ISAXContentHandler *iface)
+static ULONG WINAPI SAXContentHandler_Release(ISAXContentHandler *iface)
 {
     mxwriter *This = impl_from_ISAXContentHandler( iface );
     return IMXWriter_Release(&This->IMXWriter_iface);
 }
 
-static HRESULT WINAPI mxwriter_saxcontent_putDocumentLocator(
+static HRESULT WINAPI SAXContentHandler_putDocumentLocator(
     ISAXContentHandler *iface,
     ISAXLocator *locator)
 {
@@ -843,7 +872,7 @@ static HRESULT WINAPI mxwriter_saxcontent_putDocumentLocator(
     return E_NOTIMPL;
 }
 
-static HRESULT WINAPI mxwriter_saxcontent_startDocument(ISAXContentHandler *iface)
+static HRESULT WINAPI SAXContentHandler_startDocument(ISAXContentHandler *iface)
 {
     mxwriter *This = impl_from_ISAXContentHandler( iface );
 
@@ -876,7 +905,7 @@ static HRESULT WINAPI mxwriter_saxcontent_startDocument(ISAXContentHandler *ifac
     return S_OK;
 }
 
-static HRESULT WINAPI mxwriter_saxcontent_endDocument(ISAXContentHandler *iface)
+static HRESULT WINAPI SAXContentHandler_endDocument(ISAXContentHandler *iface)
 {
     mxwriter *This = impl_from_ISAXContentHandler( iface );
     TRACE("(%p)\n", This);
@@ -884,7 +913,7 @@ static HRESULT WINAPI mxwriter_saxcontent_endDocument(ISAXContentHandler *iface)
     return flush_output_buffer(This);
 }
 
-static HRESULT WINAPI mxwriter_saxcontent_startPrefixMapping(
+static HRESULT WINAPI SAXContentHandler_startPrefixMapping(
     ISAXContentHandler *iface,
     const WCHAR *prefix,
     int nprefix,
@@ -896,7 +925,7 @@ static HRESULT WINAPI mxwriter_saxcontent_startPrefixMapping(
     return E_NOTIMPL;
 }
 
-static HRESULT WINAPI mxwriter_saxcontent_endPrefixMapping(
+static HRESULT WINAPI SAXContentHandler_endPrefixMapping(
     ISAXContentHandler *iface,
     const WCHAR *prefix,
     int nprefix)
@@ -906,7 +935,7 @@ static HRESULT WINAPI mxwriter_saxcontent_endPrefixMapping(
     return E_NOTIMPL;
 }
 
-static HRESULT WINAPI mxwriter_saxcontent_startElement(
+static HRESULT WINAPI SAXContentHandler_startElement(
     ISAXContentHandler *iface,
     const WCHAR *namespaceUri,
     int nnamespaceUri,
@@ -943,9 +972,7 @@ static HRESULT WINAPI mxwriter_saxcontent_startElement(
 
         for (i = 0; i < length; i++)
         {
-            static const WCHAR spaceW[] = {' '};
-            static const WCHAR eqqW[] = {'=','\"'};
-            static const WCHAR quotW[] = {'\"'};
+            static const WCHAR eqW[] = {'='};
             const WCHAR *str;
             WCHAR *escaped;
             INT len = 0;
@@ -957,24 +984,22 @@ static HRESULT WINAPI mxwriter_saxcontent_startElement(
             write_output_buffer(This->buffer, spaceW, 1);
             write_output_buffer(This->buffer, str, len);
 
-            write_output_buffer(This->buffer, eqqW, 2);
+            write_output_buffer(This->buffer, eqW, 1);
 
             len = 0;
             hr = ISAXAttributes_getValue(attr, i, &str, &len);
             if (FAILED(hr)) return hr;
 
-            escaped = get_escaped_string(str, &len);
-            write_output_buffer(This->buffer, escaped, len);
+            escaped = get_escaped_string(str, EscapeValue, &len);
+            write_output_buffer_quoted(This->buffer, escaped, len);
             heap_free(escaped);
-
-            write_output_buffer(This->buffer, quotW, 1);
         }
     }
 
     return S_OK;
 }
 
-static HRESULT WINAPI mxwriter_saxcontent_endElement(
+static HRESULT WINAPI SAXContentHandler_endElement(
     ISAXContentHandler *iface,
     const WCHAR *namespaceUri,
     int nnamespaceUri,
@@ -1012,7 +1037,7 @@ static HRESULT WINAPI mxwriter_saxcontent_endElement(
     return S_OK;
 }
 
-static HRESULT WINAPI mxwriter_saxcontent_characters(
+static HRESULT WINAPI SAXContentHandler_characters(
     ISAXContentHandler *iface,
     const WCHAR *chars,
     int nchars)
@@ -1027,12 +1052,24 @@ static HRESULT WINAPI mxwriter_saxcontent_characters(
     set_element_name(This, NULL, 0);
 
     if (nchars)
-        write_output_buffer(This->buffer, chars, nchars);
+    {
+        if (This->cdata)
+            write_output_buffer(This->buffer, chars, nchars);
+        else
+        {
+            int len = nchars;
+            WCHAR *escaped;
+
+            escaped = get_escaped_string(chars, EscapeText, &len);
+            write_output_buffer(This->buffer, escaped, len);
+            heap_free(escaped);
+        }
+    }
 
     return S_OK;
 }
 
-static HRESULT WINAPI mxwriter_saxcontent_ignorableWhitespace(
+static HRESULT WINAPI SAXContentHandler_ignorableWhitespace(
     ISAXContentHandler *iface,
     const WCHAR *chars,
     int nchars)
@@ -1042,7 +1079,7 @@ static HRESULT WINAPI mxwriter_saxcontent_ignorableWhitespace(
     return E_NOTIMPL;
 }
 
-static HRESULT WINAPI mxwriter_saxcontent_processingInstruction(
+static HRESULT WINAPI SAXContentHandler_processingInstruction(
     ISAXContentHandler *iface,
     const WCHAR *target,
     int ntarget,
@@ -1054,7 +1091,7 @@ static HRESULT WINAPI mxwriter_saxcontent_processingInstruction(
     return E_NOTIMPL;
 }
 
-static HRESULT WINAPI mxwriter_saxcontent_skippedEntity(
+static HRESULT WINAPI SAXContentHandler_skippedEntity(
     ISAXContentHandler *iface,
     const WCHAR *name,
     int nname)
@@ -1064,22 +1101,182 @@ static HRESULT WINAPI mxwriter_saxcontent_skippedEntity(
     return E_NOTIMPL;
 }
 
-static const struct ISAXContentHandlerVtbl mxwriter_saxcontent_vtbl =
+static const struct ISAXContentHandlerVtbl SAXContentHandlerVtbl =
 {
-    mxwriter_saxcontent_QueryInterface,
-    mxwriter_saxcontent_AddRef,
-    mxwriter_saxcontent_Release,
-    mxwriter_saxcontent_putDocumentLocator,
-    mxwriter_saxcontent_startDocument,
-    mxwriter_saxcontent_endDocument,
-    mxwriter_saxcontent_startPrefixMapping,
-    mxwriter_saxcontent_endPrefixMapping,
-    mxwriter_saxcontent_startElement,
-    mxwriter_saxcontent_endElement,
-    mxwriter_saxcontent_characters,
-    mxwriter_saxcontent_ignorableWhitespace,
-    mxwriter_saxcontent_processingInstruction,
-    mxwriter_saxcontent_skippedEntity
+    SAXContentHandler_QueryInterface,
+    SAXContentHandler_AddRef,
+    SAXContentHandler_Release,
+    SAXContentHandler_putDocumentLocator,
+    SAXContentHandler_startDocument,
+    SAXContentHandler_endDocument,
+    SAXContentHandler_startPrefixMapping,
+    SAXContentHandler_endPrefixMapping,
+    SAXContentHandler_startElement,
+    SAXContentHandler_endElement,
+    SAXContentHandler_characters,
+    SAXContentHandler_ignorableWhitespace,
+    SAXContentHandler_processingInstruction,
+    SAXContentHandler_skippedEntity
+};
+
+/*** ISAXLexicalHandler ***/
+static HRESULT WINAPI SAXLexicalHandler_QueryInterface(ISAXLexicalHandler *iface,
+    REFIID riid, void **obj)
+{
+    mxwriter *This = impl_from_ISAXLexicalHandler( iface );
+    return IMXWriter_QueryInterface(&This->IMXWriter_iface, riid, obj);
+}
+
+static ULONG WINAPI SAXLexicalHandler_AddRef(ISAXLexicalHandler *iface)
+{
+    mxwriter *This = impl_from_ISAXLexicalHandler( iface );
+    return IMXWriter_AddRef(&This->IMXWriter_iface);
+}
+
+static ULONG WINAPI SAXLexicalHandler_Release(ISAXLexicalHandler *iface)
+{
+    mxwriter *This = impl_from_ISAXLexicalHandler( iface );
+    return IMXWriter_Release(&This->IMXWriter_iface);
+}
+
+static HRESULT WINAPI SAXLexicalHandler_startDTD(ISAXLexicalHandler *iface,
+    const WCHAR *name, int name_len, const WCHAR *publicId, int publicId_len,
+    const WCHAR *systemId, int systemId_len)
+{
+    static const WCHAR doctypeW[] = {'<','!','D','O','C','T','Y','P','E',' '};
+    static const WCHAR openintW[] = {'[','\r','\n'};
+
+    mxwriter *This = impl_from_ISAXLexicalHandler( iface );
+
+    TRACE("(%p)->(%s %s %s)\n", This, debugstr_wn(name, name_len), debugstr_wn(publicId, publicId_len),
+        debugstr_wn(systemId, systemId_len));
+
+    if (!name) return E_INVALIDARG;
+
+    write_output_buffer(This->buffer, doctypeW, sizeof(doctypeW)/sizeof(WCHAR));
+
+    if (*name)
+    {
+        write_output_buffer(This->buffer, name, name_len);
+        write_output_buffer(This->buffer, spaceW, 1);
+    }
+
+    if (publicId)
+    {
+        static const WCHAR publicW[] = {'P','U','B','L','I','C',' '};
+
+        write_output_buffer(This->buffer, publicW, sizeof(publicW)/sizeof(WCHAR));
+        write_output_buffer_quoted(This->buffer, publicId, publicId_len);
+
+        if (!systemId) return E_INVALIDARG;
+
+        if (*publicId)
+            write_output_buffer(This->buffer, spaceW, 1);
+
+        write_output_buffer_quoted(This->buffer, systemId, systemId_len);
+
+        if (*systemId)
+            write_output_buffer(This->buffer, spaceW, 1);
+    }
+    else if (systemId)
+    {
+        static const WCHAR systemW[] = {'S','Y','S','T','E','M',' '};
+
+        write_output_buffer(This->buffer, systemW, sizeof(systemW)/sizeof(WCHAR));
+        write_output_buffer_quoted(This->buffer, systemId, systemId_len);
+        if (*systemId)
+            write_output_buffer(This->buffer, spaceW, 1);
+    }
+
+    write_output_buffer(This->buffer, openintW, sizeof(openintW)/sizeof(WCHAR));
+
+    return S_OK;
+}
+
+static HRESULT WINAPI SAXLexicalHandler_endDTD(ISAXLexicalHandler *iface)
+{
+    mxwriter *This = impl_from_ISAXLexicalHandler( iface );
+    static const WCHAR closedtdW[] = {']','>','\r','\n'};
+
+    TRACE("(%p)\n", This);
+
+    write_output_buffer(This->buffer, closedtdW, sizeof(closedtdW)/sizeof(WCHAR));
+
+    return S_OK;
+}
+
+static HRESULT WINAPI SAXLexicalHandler_startEntity(ISAXLexicalHandler *iface, const WCHAR *name, int len)
+{
+    mxwriter *This = impl_from_ISAXLexicalHandler( iface );
+    FIXME("(%p)->(%s): stub\n", This, debugstr_wn(name, len));
+    return E_NOTIMPL;
+}
+
+static HRESULT WINAPI SAXLexicalHandler_endEntity(ISAXLexicalHandler *iface, const WCHAR *name, int len)
+{
+    mxwriter *This = impl_from_ISAXLexicalHandler( iface );
+    FIXME("(%p)->(%s): stub\n", This, debugstr_wn(name, len));
+    return E_NOTIMPL;
+}
+
+static HRESULT WINAPI SAXLexicalHandler_startCDATA(ISAXLexicalHandler *iface)
+{
+    static const WCHAR scdataW[] = {'<','!','[','C','D','A','T','A','['};
+    mxwriter *This = impl_from_ISAXLexicalHandler( iface );
+
+    TRACE("(%p)\n", This);
+
+    write_output_buffer(This->buffer, scdataW, sizeof(scdataW)/sizeof(WCHAR));
+    This->cdata = TRUE;
+
+    return S_OK;
+}
+
+static HRESULT WINAPI SAXLexicalHandler_endCDATA(ISAXLexicalHandler *iface)
+{
+    mxwriter *This = impl_from_ISAXLexicalHandler( iface );
+    static const WCHAR ecdataW[] = {']',']','>'};
+
+    TRACE("(%p)\n", This);
+
+    write_output_buffer(This->buffer, ecdataW, sizeof(ecdataW)/sizeof(WCHAR));
+    This->cdata = FALSE;
+
+    return S_OK;
+}
+
+static HRESULT WINAPI SAXLexicalHandler_comment(ISAXLexicalHandler *iface, const WCHAR *chars, int nchars)
+{
+    mxwriter *This = impl_from_ISAXLexicalHandler( iface );
+    static const WCHAR copenW[] = {'<','!','-','-'};
+    static const WCHAR ccloseW[] = {'-','-','>','\r','\n'};
+
+    TRACE("(%p)->(%s:%d)\n", This, debugstr_wn(chars, nchars), nchars);
+
+    if (!chars) return E_INVALIDARG;
+
+    close_element_starttag(This);
+
+    write_output_buffer(This->buffer, copenW, sizeof(copenW)/sizeof(WCHAR));
+    if (nchars)
+        write_output_buffer(This->buffer, chars, nchars);
+    write_output_buffer(This->buffer, ccloseW, sizeof(ccloseW)/sizeof(WCHAR));
+
+    return S_OK;
+}
+
+static const struct ISAXLexicalHandlerVtbl SAXLexicalHandlerVtbl =
+{
+    SAXLexicalHandler_QueryInterface,
+    SAXLexicalHandler_AddRef,
+    SAXLexicalHandler_Release,
+    SAXLexicalHandler_startDTD,
+    SAXLexicalHandler_endDTD,
+    SAXLexicalHandler_startEntity,
+    SAXLexicalHandler_endEntity,
+    SAXLexicalHandler_startCDATA,
+    SAXLexicalHandler_endCDATA,
+    SAXLexicalHandler_comment
 };
 
 static const tid_t mxwriter_iface_tids[] = {
@@ -1109,7 +1306,8 @@ HRESULT MXWriter_create(MSXML_VERSION version, IUnknown *outer, void **ppObj)
         return E_OUTOFMEMORY;
 
     This->IMXWriter_iface.lpVtbl = &MXWriterVtbl;
-    This->ISAXContentHandler_iface.lpVtbl = &mxwriter_saxcontent_vtbl;
+    This->ISAXContentHandler_iface.lpVtbl = &SAXContentHandlerVtbl;
+    This->ISAXLexicalHandler_iface.lpVtbl = &SAXLexicalHandlerVtbl;
     This->ref = 1;
     This->class_version = version;
 
@@ -1124,6 +1322,7 @@ HRESULT MXWriter_create(MSXML_VERSION version, IUnknown *outer, void **ppObj)
     This->xml_enc  = XmlEncoding_UTF16;
 
     This->element = NULL;
+    This->cdata = FALSE;
 
     This->dest = NULL;
     This->dest_written = 0;
@@ -1144,14 +1343,3 @@ HRESULT MXWriter_create(MSXML_VERSION version, IUnknown *outer, void **ppObj)
 
     return S_OK;
 }
-
-#else
-
-HRESULT MXWriter_create(MSXML_VERSION version, IUnknown *outer, void **obj)
-{
-    MESSAGE("This program tried to use a MXXMLWriter object, but\n"
-            "libxml2 support was not present at compile time.\n");
-    return E_NOTIMPL;
-}
-
-#endif /* HAVE_LIBXML2 */
