@@ -30,9 +30,22 @@
 #include "wine/unicode.h"
 #include "wine/debug.h"
 #include "ntdll_misc.h"
+#include "winnt.h"
 
 WINE_DEFAULT_DEBUG_CHANNEL(environ);
 
+/******************************************************************************
+ *  NtQuerySystemEnvironmentValue		[NTDLL.@]
+ */
+NTSYSAPI NTSTATUS WINAPI NtQuerySystemEnvironmentValue(PUNICODE_STRING VariableName,
+                                                       PWCHAR Value,
+                                                       ULONG ValueBufferLength,
+                                                       PULONG RequiredLength)
+{
+    FIXME("stub!\n");
+    return STATUS_NOT_IMPLEMENTED;
+}
+
 /******************************************************************************
  *  RtlCreateEnvironment		[NTDLL.@]
  */
@@ -237,7 +250,6 @@ NTSTATUS WINAPI RtlSetEnvironmentVariable(PWSTR* penv, PUNICODE_STRING name,
         RtlDestroyEnvironment(env);
         if (!penv) NtCurrentTeb()->Peb->ProcessParameters->Environment = new_env;
         else *penv = new_env;
-        env = new_env;
     }
     else
     {
