@@ -107,7 +107,6 @@ extern FARPROC SNOOP_GetProcAddress( HMODULE hmod, const IMAGE_EXPORT_DIRECTORY
                                      FARPROC origfun, DWORD ordinal, const WCHAR *user ) DECLSPEC_HIDDEN;
 extern void RELAY_SetupDLL( HMODULE hmod ) DECLSPEC_HIDDEN;
 extern void SNOOP_SetupDLL( HMODULE hmod ) DECLSPEC_HIDDEN;
-extern UNICODE_STRING windows_dir DECLSPEC_HIDDEN;
 extern UNICODE_STRING system_dir DECLSPEC_HIDDEN;
 
 typedef LONG (WINAPI *PUNHANDLED_EXCEPTION_FILTER)(PEXCEPTION_POINTERS);
@@ -225,6 +224,10 @@ struct ntdll_thread_data
     int                wait_fd[2];    /* 1ec/300 fd for sleeping server requests */
     BOOL               wow64_redir;   /* 1f4/308 Wow64 filesystem redirection flag */
     pthread_t          pthread_id;    /* 1f8/310 pthread thread id */
+#ifdef __i386__
+    WINE_VM86_TEB_INFO vm86;          /* 1fc vm86 private data */
+    void              *exit_frame;    /* 204 exit frame pointer */
+#endif
 };
 
 static inline struct ntdll_thread_data *ntdll_get_thread_data(void)
@@ -232,6 +235,8 @@ static inline struct ntdll_thread_data *ntdll_get_thread_data(void)
     return (struct ntdll_thread_data *)NtCurrentTeb()->SpareBytes1;
 }
 
+extern mode_t FILE_umask DECLSPEC_HIDDEN;
+
 /* Register functions */
 
 #ifdef __i386__
