@@ -140,7 +140,7 @@ void WINAPI RtlDeleteResource(LPRTL_RWLOCK rwl)
     {
 	RtlEnterCriticalSection( &rwl->rtlCS );
 	if( rwl->iNumberActive || rwl->uExclusiveWaiters || rwl->uSharedWaiters )
-	    MESSAGE("Deleting active MRSW lock (%p), expect failure\n", rwl );
+	    ERR("Deleting active MRSW lock (%p), expect failure\n", rwl );
 	rwl->hOwningThreadId = 0;
 	rwl->uExclusiveWaiters = rwl->uSharedWaiters = 0;
 	rwl->iNumberActive = 0;
@@ -405,37 +405,6 @@ RtlDeleteSecurityObject( PSECURITY_DESCRIPTOR *ObjectDescriptor )
     return STATUS_NOT_IMPLEMENTED;
 }
 
-/**************************************************************************
- *                 _chkstk				[NTDLL.@]
- *
- * Glorified "enter xxxx".
- */
-#ifdef __i386__
-__ASM_STDCALL_FUNC( _chkstk, 0,
-                   "negl %eax\n\t"
-                   "addl %esp,%eax\n\t"
-                   "xchgl %esp,%eax\n\t"
-                   "movl 0(%eax),%eax\n\t"  /* copy return address from old location */
-                   "movl %eax,0(%esp)\n\t"
-                   "ret" )
-#endif
-
-/**************************************************************************
- *                 _alloca_probe		        [NTDLL.@]
- *
- * Glorified "enter xxxx".
- */
-#ifdef __i386__
-__ASM_STDCALL_FUNC( _alloca_probe, 0,
-                   "negl %eax\n\t"
-                   "addl %esp,%eax\n\t"
-                   "xchgl %esp,%eax\n\t"
-                   "movl 0(%eax),%eax\n\t"  /* copy return address from old location */
-                   "movl %eax,0(%esp)\n\t"
-                   "ret" )
-#endif
-
-
 /******************************************************************************
  *  RtlInitializeGenericTable           [NTDLL.@]
  */
@@ -860,14 +829,14 @@ void WINAPI RtlCopyLuid (PLUID LuidDest, const LUID *LuidSrc)
 /*************************************************************************
  * RtlEqualLuid   [NTDLL.@]
  *
- * Compare two local unique ID's.
+ * Compare two local unique IDs.
  *
  * PARAMS
  *  Luid1 [I] First Luid to compare to Luid2
  *  Luid2 [I] Second Luid to compare to Luid1
  *
  * RETURNS
- *  TRUE: The two LUID's are equal.
+ *  TRUE: The two LUIDs are equal.
  *  FALSE: Otherwise
  */
 BOOLEAN WINAPI RtlEqualLuid (const LUID *Luid1, const LUID *Luid2)
@@ -879,7 +848,7 @@ BOOLEAN WINAPI RtlEqualLuid (const LUID *Luid1, const LUID *Luid2)
 /*************************************************************************
  * RtlCopyLuidAndAttributesArray   [NTDLL.@]
  *
- * Copy an array of local unique ID's and attributes.
+ * Copy an array of local unique IDs and attributes.
  *
  * PARAMS
  *  Count [I] Number of Luid/attributes in Src
@@ -1323,3 +1292,21 @@ DWORD WINAPI RtlGetThreadErrorMode( void )
 {
     return NtCurrentTeb()->HardErrorDisabled;
 }
+
+/******************************************************************************
+ * RtlGetCurrentTransaction [NTDLL.@]
+ */
+HANDLE WINAPI RtlGetCurrentTransaction(void)
+{
+    FIXME("() :stub\n");
+    return NULL;
+}
+
+/******************************************************************************
+ * RtlSetCurrentTransaction [NTDLL.@]
+ */
+BOOL WINAPI RtlSetCurrentTransaction(HANDLE new_transaction)
+{
+    FIXME("(%p) :stub\n", new_transaction);
+    return FALSE;
+}
