@@ -33,10 +33,15 @@ WINE_DEFAULT_DEBUG_CHANNEL(pstores);
 
 typedef struct
 {
-    const IPStoreVtbl *lpVtbl;
+    IPStore IPStore_iface;
     LONG ref;
 } PStore_impl;
 
+static inline PStore_impl *impl_from_IPStore(IPStore *iface)
+{
+    return CONTAINING_RECORD(iface, PStore_impl, IPStore_iface);
+}
+
 BOOL WINAPI DllMain(HINSTANCE hinst, DWORD fdwReason, LPVOID fImpLoad)
 {
     TRACE("%p %x %p\n", hinst, fdwReason, fImpLoad);
@@ -62,7 +67,7 @@ static HRESULT WINAPI PStore_fnQueryInterface(
         REFIID riid,
         LPVOID *ppvObj)
 {
-    PStore_impl *This = (PStore_impl *)iface;
+    PStore_impl *This = impl_from_IPStore(iface);
 
     TRACE("%p %s\n",This,debugstr_guid(riid));
 
@@ -87,7 +92,7 @@ static HRESULT WINAPI PStore_fnQueryInterface(
  */
 static ULONG WINAPI PStore_fnAddRef(IPStore* iface)
 {
-    PStore_impl *This = (PStore_impl *)iface;
+    PStore_impl *This = impl_from_IPStore(iface);
 
     TRACE("%p %u\n", This, This->ref);
 
@@ -99,7 +104,7 @@ static ULONG WINAPI PStore_fnAddRef(IPStore* iface)
  */
 static ULONG WINAPI PStore_fnRelease(IPStore* iface)
 {
-    PStore_impl *This = (PStore_impl *)iface;
+    PStore_impl *This = impl_from_IPStore(iface);
     LONG ref;
 
     TRACE("%p %u\n", This, This->ref);
@@ -264,7 +269,7 @@ static HRESULT WINAPI PStore_fnDeleteItem( IPStore* This, PST_KEY Key,
  */
 static HRESULT WINAPI PStore_fnReadItem( IPStore* This, PST_KEY Key,
     const GUID* pItemType, const GUID* pItemSubtype, LPCWSTR szItemName,
-    DWORD *cbData, BYTE** pbData, PPST_PROMPTIFO pPromptInfo, DWORD dwFlags)
+    DWORD *cbData, BYTE** pbData, PPST_PROMPTINFO pPromptInfo, DWORD dwFlags)
 {
     FIXME("%p %08x %s %s %s %p %p %p %08x\n", This, Key,
           debugstr_guid(pItemType), debugstr_guid(pItemSubtype),
@@ -277,7 +282,7 @@ static HRESULT WINAPI PStore_fnReadItem( IPStore* This, PST_KEY Key,
  */
 static HRESULT WINAPI PStore_fnWriteItem( IPStore* This, PST_KEY Key,
     const GUID* pItemType, const GUID* pItemSubtype, LPCWSTR szItemName,
-    DWORD cbData, BYTE* ppbData, PPST_PROMPTIFO pPromptInfo,
+    DWORD cbData, BYTE* ppbData, PPST_PROMPTINFO pPromptInfo,
     DWORD dwDefaultConfirmationStyle, DWORD dwFlags)
 {
     FIXME("%p %08x %s %s %s %d %p %p %08x\n", This, Key,
@@ -291,7 +296,7 @@ static HRESULT WINAPI PStore_fnWriteItem( IPStore* This, PST_KEY Key,
  */
 static HRESULT WINAPI PStore_fnOpenItem( IPStore* This, PST_KEY Key,
     const GUID* pItemType, const GUID* pItemSubtype, LPCWSTR szItemName,
-    PST_ACCESSMODE ModeFlags, PPST_PROMPTIFO pProomptInfo, DWORD dwFlags )
+    PST_ACCESSMODE ModeFlags, PPST_PROMPTINFO pProomptInfo, DWORD dwFlags )
 {
     FIXME("%p %08x %s %s %p %08x %p %08x\n", This, Key,
            debugstr_guid(pItemType), debugstr_guid(pItemSubtype),
@@ -359,7 +364,7 @@ HRESULT WINAPI PStoreCreateInstance( IPStore** ppProvider,
     if( !ips )
         return E_OUTOFMEMORY;
 
-    ips->lpVtbl = &pstores_vtbl;
+    ips->IPStore_iface.lpVtbl = &pstores_vtbl;
     ips->ref = 1;
 
     *ppProvider = (IPStore*) ips;
@@ -390,6 +395,5 @@ HRESULT WINAPI DllGetClassObject(REFCLSID rclsid, REFIID iid, LPVOID *ppv)
 
 HRESULT WINAPI DllCanUnloadNow(void)
 {
-    FIXME("\n");
     return S_OK;
 }
