@@ -28,16 +28,17 @@
 
 #include "windef.h"
 #include "winbase.h"
+#include "wingdi.h"
 #include "winerror.h"
 #include "objbase.h"
 
 #include "evcode.h"
 #include "strmif.h"
 #include "control.h"
+#include "vfwmsgs.h"
 /*
  *#include "amvideo.h"
  *#include "mmreg.h"
- *#include "vfwmsgs.h"
  *#include "dshow.h"
  *#include "ddraw.h"
  */
@@ -53,8 +54,8 @@ WINE_DEFAULT_DEBUG_CHANNEL(qcap);
 */
 typedef struct CaptureGraphImpl
 {
-    const ICaptureGraphBuilder2Vtbl * lpVtbl2;
-    const ICaptureGraphBuilderVtbl * lpVtbl;
+    ICaptureGraphBuilder2 ICaptureGraphBuilder2_iface;
+    ICaptureGraphBuilder ICaptureGraphBuilder_iface;
     LONG ref;
     IGraphBuilder *mygraph;
 
@@ -64,23 +65,16 @@ typedef struct CaptureGraphImpl
 static const ICaptureGraphBuilderVtbl builder_Vtbl;
 static const ICaptureGraphBuilder2Vtbl builder2_Vtbl;
 
-static inline CaptureGraphImpl *impl_from_ICaptureGraphBuilder( ICaptureGraphBuilder *iface )
+static inline CaptureGraphImpl *impl_from_ICaptureGraphBuilder(ICaptureGraphBuilder *iface)
 {
-    return (CaptureGraphImpl *)((char*)iface - FIELD_OFFSET(CaptureGraphImpl, lpVtbl));
+    return CONTAINING_RECORD(iface, CaptureGraphImpl, ICaptureGraphBuilder_iface);
 }
 
-static inline CaptureGraphImpl *impl_from_ICaptureGraphBuilder2( ICaptureGraphBuilder2 *iface )
+static inline CaptureGraphImpl *impl_from_ICaptureGraphBuilder2(ICaptureGraphBuilder2 *iface)
 {
-    return (CaptureGraphImpl *)((char*)iface - FIELD_OFFSET(CaptureGraphImpl, lpVtbl2));
+    return CONTAINING_RECORD(iface, CaptureGraphImpl, ICaptureGraphBuilder2_iface);
 }
 
-/*
-  converts This to an interface pointer
-*/
-#define _IUnknown_(This)                (IUnknown*)&(This->lpVtbl2)
-#define _ICaptureGraphBuilder_(This)    (ICaptureGraphBuilder*)&(This->lpVtbl)
-#define _ICaptureGraphBuilder2_(This)   (ICaptureGraphBuilder2*)&(This->lpVtbl2)
-
 
 IUnknown * CALLBACK QCAP_createCaptureGraphBuilder2(IUnknown *pUnkOuter,
                                                     HRESULT *phr)
@@ -99,8 +93,8 @@ IUnknown * CALLBACK QCAP_createCaptureGraphBuilder2(IUnknown *pUnkOuter,
     pCapture = CoTaskMemAlloc(sizeof(CaptureGraphImpl));
     if (pCapture)
     {
-        pCapture->lpVtbl2 = &builder2_Vtbl;
-        pCapture->lpVtbl = &builder_Vtbl;
+        pCapture->ICaptureGraphBuilder2_iface.lpVtbl = &builder2_Vtbl;
+        pCapture->ICaptureGraphBuilder_iface.lpVtbl = &builder_Vtbl;
         pCapture->ref = 1;
         pCapture->mygraph = NULL;
         InitializeCriticalSection(&pCapture->csFilter);
@@ -108,7 +102,7 @@ IUnknown * CALLBACK QCAP_createCaptureGraphBuilder2(IUnknown *pUnkOuter,
         *phr = S_OK;
         ObjectRefCount(TRUE);
     }
-    return (IUnknown *)pCapture;
+    return (IUnknown *)&pCapture->ICaptureGraphBuilder_iface;
 }
 
 static HRESULT WINAPI
@@ -122,11 +116,11 @@ fnCaptureGraphBuilder2_QueryInterface(ICaptureGraphBuilder2 * iface,
 
     *ppv = NULL;
     if (IsEqualIID(riid, &IID_IUnknown))
-        *ppv = _IUnknown_(This);
+        *ppv = &This->ICaptureGraphBuilder2_iface;
     else if (IsEqualIID(riid, &IID_ICaptureGraphBuilder))
-        *ppv = _ICaptureGraphBuilder_(This);
+        *ppv = &This->ICaptureGraphBuilder_iface;
     else if (IsEqualIID(riid, &IID_ICaptureGraphBuilder2))
-        *ppv = _ICaptureGraphBuilder2_(This);
+        *ppv = &This->ICaptureGraphBuilder2_iface;
 
     if (*ppv)
     {
@@ -162,10 +156,8 @@ fnCaptureGraphBuilder2_Release(ICaptureGraphBuilder2 * iface)
         FIXME("Release IGraphFilter or w/e\n");
         This->csFilter.DebugInfo->Spare[0] = 0;
         DeleteCriticalSection(&This->csFilter);
-        This->lpVtbl = NULL;
-        This->lpVtbl2 = NULL;
         if (This->mygraph != NULL)
-            IGraphBuilder_Release((IGraphBuilder *)This->mygraph);
+            IGraphBuilder_Release(This->mygraph);
         CoTaskMemFree(This);
         ObjectRefCount(FALSE);
     }
@@ -191,7 +183,7 @@ fnCaptureGraphBuilder2_SetFilterGraph(ICaptureGraphBuilder2 * iface,
         return E_POINTER;
 
     This->mygraph = pfg;
-    IGraphBuilder_AddRef((IGraphBuilder *)This->mygraph);
+    IGraphBuilder_AddRef(This->mygraph);
     if (SUCCEEDED(IUnknown_QueryInterface(This->mygraph,
                                           &IID_IMediaEvent, (LPVOID *)&pmev)))
     {
@@ -219,7 +211,7 @@ fnCaptureGraphBuilder2_GetFilterGraph(ICaptureGraphBuilder2 * iface,
         return E_UNEXPECTED;
     }
 
-    IGraphBuilder_AddRef((IGraphBuilder *)This->mygraph);
+    IGraphBuilder_AddRef(This->mygraph);
    
     TRACE("(%p) return filtergraph %p\n", iface, *pfg);
     return S_OK;
@@ -270,12 +262,38 @@ fnCaptureGraphBuilder2_RenderStream(ICaptureGraphBuilder2 * iface,
                                     IBaseFilter *pfRenderer)
 {
     CaptureGraphImpl *This = impl_from_ICaptureGraphBuilder2(iface);
+    IPin *pin_in = NULL;
+    IPin *pin_out = NULL;
+    HRESULT hr;
 
     FIXME("(%p/%p)->(%s, %s, %p, %p, %p) Stub!\n", This, iface,
           debugstr_guid(pCategory), debugstr_guid(pType),
           pSource, pfCompressor, pfRenderer);
 
-    return E_NOTIMPL;
+    if (pfCompressor)
+        FIXME("Intermediate streams not supported yet\n");
+
+    if (!This->mygraph)
+    {
+        FIXME("Need a capture graph\n");
+        return E_UNEXPECTED;
+    }
+
+    ICaptureGraphBuilder2_FindPin(iface, pSource, PINDIR_OUTPUT, pCategory, pType, TRUE, 0, &pin_in);
+    if (!pin_in)
+        return E_FAIL;
+    ICaptureGraphBuilder2_FindPin(iface, (IUnknown*)pfRenderer, PINDIR_INPUT, pCategory, pType, TRUE, 0, &pin_out);
+    if (!pin_out)
+    {
+        IPin_Release(pin_in);
+        return E_FAIL;
+    }
+
+    /* Uses 'Intelligent Connect', so Connect, not ConnectDirect here */
+    hr = IFilterGraph2_Connect(This->mygraph, pin_in, pin_out);
+    IPin_Release(pin_in);
+    IPin_Release(pin_out);
+    return hr;
 }
 
 static HRESULT WINAPI
@@ -326,6 +344,33 @@ fnCaptureGraphBuilder2_CopyCaptureFile(ICaptureGraphBuilder2 * iface,
     return E_NOTIMPL;
 }
 
+static BOOL pin_matches(IPin *pin, PIN_DIRECTION direction, const GUID *cat, const GUID *type, BOOL unconnected)
+{
+    IPin *partner;
+    PIN_DIRECTION pindir;
+
+    IPin_QueryDirection(pin, &pindir);
+    if (pindir != direction)
+    {
+        TRACE("No match, wrong direction\n");
+        return FALSE;
+    }
+
+    if (unconnected && IPin_ConnectedTo(pin, &partner) == S_OK)
+    {
+        IPin_Release(partner);
+        TRACE("No match, %p already connected to %p\n", pin, partner);
+        return FALSE;
+    }
+
+    if (cat || type)
+        FIXME("Ignoring category/type\n");
+
+    TRACE("Match made in heaven\n");
+
+    return TRUE;
+}
+
 static HRESULT WINAPI
 fnCaptureGraphBuilder2_FindPin(ICaptureGraphBuilder2 * iface,
                                IUnknown *pSource,
@@ -333,16 +378,77 @@ fnCaptureGraphBuilder2_FindPin(ICaptureGraphBuilder2 * iface,
                                const GUID *pCategory,
                                const GUID *pType,
                                BOOL fUnconnected,
-                               int num,
+                               INT num,
                                IPin **ppPin)
 {
+    HRESULT hr;
+    IEnumPins *enumpins = NULL;
+    IPin *pin;
     CaptureGraphImpl *This = impl_from_ICaptureGraphBuilder2(iface);
 
-    FIXME("(%p/%p)->(%p, %x, %s, %s, %d, %i, %p) Stub!\n", This, iface,
+    TRACE("(%p/%p)->(%p, %x, %s, %s, %d, %i, %p)\n", This, iface,
           pSource, pindir, debugstr_guid(pCategory), debugstr_guid(pType),
           fUnconnected, num, ppPin);
 
-    return E_NOTIMPL;
+    pin = NULL;
+
+    hr = IUnknown_QueryInterface(pSource, &IID_IPin, (void**)&pin);
+    if (hr == E_NOINTERFACE)
+    {
+        IBaseFilter *filter = NULL;
+        int numcurrent = 0;
+
+        hr = IUnknown_QueryInterface(pSource, &IID_IBaseFilter, (void**)&filter);
+        if (hr == E_NOINTERFACE)
+        {
+            WARN("Input not filter or pin?!\n");
+            return E_FAIL;
+        }
+
+        hr = IBaseFilter_EnumPins(filter, &enumpins);
+        if (FAILED(hr))
+        {
+            WARN("Could not enumerate\n");
+            return hr;
+        }
+
+        IEnumPins_Reset(enumpins);
+
+        while (1)
+        {
+            hr = IEnumPins_Next(enumpins, 1, &pin, NULL);
+            if (hr == VFW_E_ENUM_OUT_OF_SYNC)
+            {
+                numcurrent = 0;
+                IEnumPins_Reset(enumpins);
+                pin = NULL;
+                continue;
+            }
+
+            if (hr != S_OK)
+                break;
+            TRACE("Testing match\n");
+            if (pin_matches(pin, pindir, pCategory, pType, fUnconnected) && numcurrent++ == num)
+                break;
+            IPin_Release(pin);
+            pin = NULL;
+        }
+        IEnumPins_Release(enumpins);
+
+        if (hr != S_OK)
+        {
+            WARN("Could not find %s pin # %d\n", (pindir == PINDIR_OUTPUT ? "output" : "input"), numcurrent);
+            return E_FAIL;
+        }
+    }
+    else if (!pin_matches(pin, pindir, pCategory, pType, fUnconnected))
+    {
+        IPin_Release(pin);
+        return E_FAIL;
+    }
+
+    *ppPin = pin;
+    return S_OK;
 }
 
 static const ICaptureGraphBuilder2Vtbl builder2_Vtbl =
@@ -368,7 +474,7 @@ fnCaptureGraphBuilder_QueryInterface(ICaptureGraphBuilder * iface,
 {
     CaptureGraphImpl *This = impl_from_ICaptureGraphBuilder(iface);
     TRACE("%p --> Forwarding to v2 (%p)\n", iface, This);
-    return IUnknown_QueryInterface(_ICaptureGraphBuilder2_(This), riid, ppv);
+    return IUnknown_QueryInterface(&This->ICaptureGraphBuilder2_iface, riid, ppv);
 }
 
 static ULONG WINAPI
@@ -376,7 +482,7 @@ fnCaptureGraphBuilder_AddRef(ICaptureGraphBuilder * iface)
 {
     CaptureGraphImpl *This = impl_from_ICaptureGraphBuilder(iface);
     TRACE("%p --> Forwarding to v2 (%p)\n", iface, This);
-    return IUnknown_AddRef(_ICaptureGraphBuilder2_(This));
+    return IUnknown_AddRef(&This->ICaptureGraphBuilder2_iface);
 }
 
 static ULONG WINAPI
@@ -384,7 +490,7 @@ fnCaptureGraphBuilder_Release(ICaptureGraphBuilder * iface)
 {
     CaptureGraphImpl *This = impl_from_ICaptureGraphBuilder(iface);
     TRACE("%p --> Forwarding to v2 (%p)\n", iface, This);
-    return IUnknown_Release(_ICaptureGraphBuilder2_(This));
+    return IUnknown_Release(&This->ICaptureGraphBuilder2_iface);
 }
 
 static HRESULT WINAPI
@@ -393,7 +499,7 @@ fnCaptureGraphBuilder_SetFiltergraph(ICaptureGraphBuilder * iface,
 {
     CaptureGraphImpl *This = impl_from_ICaptureGraphBuilder(iface);
     TRACE("%p --> Forwarding to v2 (%p)\n", iface, This);
-    return ICaptureGraphBuilder2_SetFiltergraph(_ICaptureGraphBuilder2_(This), pfg);
+    return ICaptureGraphBuilder2_SetFiltergraph(&This->ICaptureGraphBuilder2_iface, pfg);
 }
 
 static HRESULT WINAPI
@@ -402,7 +508,7 @@ fnCaptureGraphBuilder_GetFiltergraph(ICaptureGraphBuilder * iface,
 {
     CaptureGraphImpl *This = impl_from_ICaptureGraphBuilder(iface);
     TRACE("%p --> Forwarding to v2 (%p)\n", iface, This);
-    return ICaptureGraphBuilder2_GetFiltergraph(_ICaptureGraphBuilder2_(This), pfg);
+    return ICaptureGraphBuilder2_GetFiltergraph(&This->ICaptureGraphBuilder2_iface, pfg);
 }
 
 static HRESULT WINAPI
@@ -412,8 +518,8 @@ fnCaptureGraphBuilder_SetOutputFileName(ICaptureGraphBuilder * iface,
 {
     CaptureGraphImpl *This = impl_from_ICaptureGraphBuilder(iface);
     TRACE("%p --> Forwarding to v2 (%p)\n", iface, This);
-    return ICaptureGraphBuilder2_SetOutputFileName(_ICaptureGraphBuilder2_(This),
-                                                   pType, lpstrFile, ppf, ppSink);
+    return ICaptureGraphBuilder2_SetOutputFileName(&This->ICaptureGraphBuilder2_iface, pType,
+                                                   lpstrFile, ppf, ppSink);
 }
 
 static HRESULT WINAPI
@@ -423,8 +529,8 @@ fnCaptureGraphBuilder_FindInterface(ICaptureGraphBuilder * iface,
 {
     CaptureGraphImpl *This = impl_from_ICaptureGraphBuilder(iface);
     TRACE("%p --> Forwarding to v2 (%p)\n", iface, This);
-    return ICaptureGraphBuilder2_FindInterface(_ICaptureGraphBuilder2_(This),
-                                               pCategory, NULL, pf, riid, ppint);
+    return ICaptureGraphBuilder2_FindInterface(&This->ICaptureGraphBuilder2_iface, pCategory, NULL,
+                                               pf, riid, ppint);
 }
 
 static HRESULT WINAPI
@@ -434,9 +540,8 @@ fnCaptureGraphBuilder_RenderStream(ICaptureGraphBuilder * iface,
 {
     CaptureGraphImpl *This = impl_from_ICaptureGraphBuilder(iface);
     TRACE("%p --> Forwarding to v2 (%p)\n", iface, This);
-    return ICaptureGraphBuilder2_RenderStream(_ICaptureGraphBuilder2_(This),
-                                              pCategory, NULL, pSource,
-                                              pfCompressor, pfRenderer);
+    return ICaptureGraphBuilder2_RenderStream(&This->ICaptureGraphBuilder2_iface, pCategory, NULL,
+                                              pSource, pfCompressor, pfRenderer);
 }
 
 static HRESULT WINAPI
@@ -447,9 +552,8 @@ fnCaptureGraphBuilder_ControlStream(ICaptureGraphBuilder * iface,
 {
     CaptureGraphImpl *This = impl_from_ICaptureGraphBuilder(iface);
     TRACE("%p --> Forwarding to v2 (%p)\n", iface, This);
-    return ICaptureGraphBuilder2_ControlStream(_ICaptureGraphBuilder2_(This),
-                                               pCategory, NULL, pFilter, pstart, 
-                                               pstop, wStartCookie, wStopCookie);
+    return ICaptureGraphBuilder2_ControlStream(&This->ICaptureGraphBuilder2_iface, pCategory, NULL,
+                                               pFilter, pstart, pstop, wStartCookie, wStopCookie);
 }
 
 static HRESULT WINAPI
@@ -458,8 +562,7 @@ fnCaptureGraphBuilder_AllocCapFile(ICaptureGraphBuilder * iface,
 {
     CaptureGraphImpl *This = impl_from_ICaptureGraphBuilder(iface);
     TRACE("%p --> Forwarding to v2 (%p)\n", iface, This);
-    return ICaptureGraphBuilder2_AllocCapFile(_ICaptureGraphBuilder2_(This),
-                                              lpstr, dwlSize);
+    return ICaptureGraphBuilder2_AllocCapFile(&This->ICaptureGraphBuilder2_iface, lpstr, dwlSize);
 }
 
 static HRESULT WINAPI
@@ -470,9 +573,8 @@ fnCaptureGraphBuilder_CopyCaptureFile(ICaptureGraphBuilder * iface,
 {
     CaptureGraphImpl *This = impl_from_ICaptureGraphBuilder(iface);
     TRACE("%p --> Forwarding to v2 (%p)\n", iface, This);
-    return ICaptureGraphBuilder2_CopyCaptureFile(_ICaptureGraphBuilder2_(This),
-                                                 lpwstrOld, lpwstrNew,
-                                                 fAllowEscAbort, pCallback);
+    return ICaptureGraphBuilder2_CopyCaptureFile(&This->ICaptureGraphBuilder2_iface, lpwstrOld,
+                                                 lpwstrNew, fAllowEscAbort, pCallback);
 }
 
 static const ICaptureGraphBuilderVtbl builder_Vtbl =
