@@ -137,7 +137,7 @@ static void DSoundRender_UpdatePositions(DSoundRenderImpl *This, DWORD *seqwrite
     if (!writepos_set || old_writepos < writepos) {
         if (writepos_set) {
             This->writepos = This->buf_size;
-            FIXME("Underrun of data occured!\n");
+            FIXME("Underrun of data occurred!\n");
         }
         *seqwritepos = writepos;
     } else
@@ -226,6 +226,42 @@ end:
     return S_OK;
 }
 
+static HRESULT DSoundRender_HandleEndOfStream(DSoundRenderImpl *This)
+{
+    HRESULT hr;
+    IMediaEventSink *pEventSink;
+
+    while (1)
+    {
+        DWORD pos1, pos2;
+        DSoundRender_UpdatePositions(This, &pos1, &pos2);
+        if (pos1 == pos2)
+            break;
+
+        This->in_loop = 1;
+        LeaveCriticalSection(&This->filter.csFilter);
+        WaitForSingleObject(This->blocked, 10);
+        EnterCriticalSection(&This->filter.csFilter);
+        This->in_loop = 0;
+        if (This->pInputPin->flushing ||
+            This->filter.state != State_Running) {
+            SetEvent(This->state_change);
+            return S_FALSE;
+        }
+    }
+
+    if (!This->filter.filterInfo.pGraph)
+        return S_OK;
+
+    hr = IFilterGraph_QueryInterface(This->filter.filterInfo.pGraph, &IID_IMediaEventSink, (LPVOID*)&pEventSink);
+    if (SUCCEEDED(hr))
+    {
+        hr = IMediaEventSink_Notify(pEventSink, EC_COMPLETE, S_OK, (LONG_PTR)This);
+        IMediaEventSink_Release(pEventSink);
+    }
+    return hr;
+}
+
 static HRESULT DSoundRender_SendSampleData(DSoundRenderImpl* This, REFERENCE_TIME tStart, REFERENCE_TIME tStop, const BYTE *data, DWORD size)
 {
     HRESULT hr;
@@ -875,7 +911,6 @@ static HRESULT WINAPI DSoundRender_InputPin_EndOfStream(IPin * iface)
 {
     BaseInputPin* This = (BaseInputPin*)iface;
     DSoundRenderImpl *me = (DSoundRenderImpl*)This->pin.pinInfo.pFilter;
-    IMediaEventSink* pEventSink;
     HRESULT hr;
 
     EnterCriticalSection(This->pin.pCritSec);
@@ -889,15 +924,7 @@ static HRESULT WINAPI DSoundRender_InputPin_EndOfStream(IPin * iface)
         return hr;
     }
 
-    if (me->filter.filterInfo.pGraph)
-    {
-        hr = IFilterGraph_QueryInterface(me->filter.filterInfo.pGraph, &IID_IMediaEventSink, (LPVOID*)&pEventSink);
-        if (SUCCEEDED(hr))
-        {
-            hr = IMediaEventSink_Notify(pEventSink, EC_COMPLETE, S_OK, (LONG_PTR)me);
-            IMediaEventSink_Release(pEventSink);
-        }
-    }
+    hr = DSoundRender_HandleEndOfStream(me);
     MediaSeekingPassThru_EOS(me->seekthru_unk);
     SetEvent(me->state_change);
     LeaveCriticalSection(This->pin.pCritSec);
@@ -1166,7 +1193,7 @@ static DWORD WINAPI DSoundAdviseThread(LPVOID lpParam) {
             FIXME("Could not get time: %08x\n", hr);
             continue;
         }
-        TRACE("Time: %Li\n", curtime);
+        TRACE("Time: %s\n", wine_dbgstr_longlong(curtime));
         while (prev->next) {
             cur = prev->next;
             if (cur->start > curtime) {
@@ -1180,7 +1207,7 @@ static DWORD WINAPI DSoundAdviseThread(LPVOID lpParam) {
                 prev = cur;
             } else {
                 struct dsoundrender_timer *next = cur->next;
-                TRACE("Firing %p %Li < %Li\n", cur, cur->start, curtime);
+                TRACE("Firing %p %s < %s\n", cur, wine_dbgstr_longlong(cur->start), wine_dbgstr_longlong(curtime));
                 SetEvent(cur->handle);
                 HeapFree(GetProcessHeap(), 0, cur);
                 prev->next = next;
@@ -1507,7 +1534,7 @@ static DSoundRenderImpl *from_IAMFilterMiscFlags(IAMFilterMiscFlags *iface) {
     return (DSoundRenderImpl*)((char*)iface - offsetof(DSoundRenderImpl, IAMFilterMiscFlags_vtbl));
 }
 
-static HRESULT WINAPI AMFilterMiscFlags_QueryInterface(IAMFilterMiscFlags *iface, const REFIID riid, void **ppv) {
+static HRESULT WINAPI AMFilterMiscFlags_QueryInterface(IAMFilterMiscFlags *iface, REFIID riid, void **ppv) {
     DSoundRenderImpl *This = from_IAMFilterMiscFlags(iface);
     return IUnknown_QueryInterface((IUnknown*)This, riid, ppv);
 }
