@@ -128,12 +128,14 @@ static HRESULT parse_header(BYTE *header, LONGLONG *plen, LONGLONG *pduration)
     LONGLONG duration;
 
     int bitrate_index, freq_index, lsf = 1, mpeg1, layer, padding, bitrate, length;
+    if (header[0] != 0xff)
+        return E_INVALIDARG;
 
-    if (!(header[0] == 0xff && ((header[1]>>5)&0x7) == 0x7 &&
+    if (!(((header[1]>>5)&0x7) == 0x7 &&
        ((header[1]>>1)&0x3) != 0 && ((header[2]>>4)&0xf) != 0xf &&
        ((header[2]>>2)&0x3) != 0x3))
     {
-        FIXME("Not a valid header: %02x:%02x\n", header[0], header[1]);
+        FIXME("Not a valid header: %02x:%02x\n", header[1], header[2]);
         return E_INVALIDARG;
     }
 
@@ -147,7 +149,7 @@ static HRESULT parse_header(BYTE *header, LONGLONG *plen, LONGLONG *pduration)
     padding = ((header[2]>>1)&0x1);
 
     bitrate = tabsel_123[lsf][layer-1][bitrate_index] * 1000;
-    if (!bitrate || layer != 3)
+    if (!bitrate)
     {
         FIXME("Not a valid header: %02x:%02x:%02x:%02x\n", header[0], header[1], header[2], header[3]);
         return E_INVALIDARG;
@@ -180,7 +182,8 @@ static HRESULT FillBuffer(MPEGSplitterImpl *This, IMediaSample *pCurrentSample)
     IMediaSample_GetPointer(pCurrentSample, &fbuf);
 
     /* Find the next valid header.. it <SHOULD> be right here */
-    assert(parse_header(fbuf, &length, &This->position) == S_OK);
+    hr = parse_header(fbuf, &length, &This->position);
+    assert(hr == S_OK);
     IMediaSample_SetActualDataLength(pCurrentSample, length);
 
     /* Queue the next sample */
@@ -217,9 +220,14 @@ static HRESULT FillBuffer(MPEGSplitterImpl *This, IMediaSample *pCurrentSample)
                 IMediaSample_SetPreroll(sample, 0);
                 IMediaSample_SetDiscontinuity(sample, 0);
                 IMediaSample_SetSyncPoint(sample, 1);
-                pin->rtCurrent = rtSampleStart;
-                pin->rtNext = rtSampleStop;
                 hr = IAsyncReader_Request(pin->pReader, sample, 0);
+                if (SUCCEEDED(hr))
+                {
+                    pin->rtCurrent = rtSampleStart;
+                    pin->rtNext = rtSampleStop;
+                }
+                else
+                    IMediaSample_Release(sample);
             }
             if (FAILED(hr))
                 FIXME("o_Ox%08x\n", hr);
@@ -348,6 +356,7 @@ static HRESULT MPEGSplitter_query_accept(LPVOID iface, const AM_MEDIA_TYPE *pmt)
         FIXME("MPEG-1 system streams not yet supported.\n");
     else if (IsEqualIID(&pmt->subtype, &MEDIASUBTYPE_MPEG1VideoCD))
         FIXME("MPEG-1 VideoCD streams not yet supported.\n");
+    else FIXME("%s\n", debugstr_guid(&pmt->subtype));
 
     return S_FALSE;
 }
@@ -731,7 +740,9 @@ static HRESULT MPEGSplitter_first_request(LPVOID iface)
     IMediaSample *sample;
 
     TRACE("Seeking? %d\n", This->seek);
-    assert(parse_header(This->header, &length, NULL) == S_OK);
+
+    hr = parse_header(This->header, &length, NULL);
+    assert(hr == S_OK);
 
     if (pin->rtCurrent >= pin->rtStop)
     {
@@ -754,15 +765,19 @@ static HRESULT MPEGSplitter_first_request(LPVOID iface)
 
         hr = IMediaSample_SetTime(sample, &rtSampleStart, &rtSampleStop);
 
-        pin->rtCurrent = pin->rtNext;
-        pin->rtNext = rtSampleStop;
-
         IMediaSample_SetPreroll(sample, FALSE);
         IMediaSample_SetDiscontinuity(sample, TRUE);
         IMediaSample_SetSyncPoint(sample, 1);
         This->seek = 0;
 
         hr = IAsyncReader_Request(pin->pReader, sample, 0);
+        if (SUCCEEDED(hr))
+        {
+            pin->rtCurrent = pin->rtNext;
+            pin->rtNext = rtSampleStop;
+        }
+        else
+            IMediaSample_Release(sample);
     }
     if (FAILED(hr))
         ERR("Horsemen of the apocalypse came to bring error 0x%08x\n", hr);
