@@ -62,23 +62,6 @@ struct schan_context
     ULONG req_ctx_attr;
 };
 
-struct schan_buffers
-{
-    SIZE_T offset;
-    SIZE_T limit;
-    const SecBufferDesc *desc;
-    int current_buffer_idx;
-    BOOL allow_buffer_resize;
-    int (*get_next_buffer)(const struct schan_transport *, struct schan_buffers *);
-};
-
-struct schan_transport
-{
-    struct schan_context *ctx;
-    struct schan_buffers in;
-    struct schan_buffers out;
-};
-
 static struct schan_handle *schan_handle_table;
 static struct schan_handle *schan_free_handles;
 static SIZE_T schan_handle_table_size;
@@ -450,7 +433,7 @@ static void init_schan_buffers(struct schan_buffers *s, const PSecBufferDesc des
         int (*get_next_buffer)(const struct schan_transport *, struct schan_buffers *))
 {
     s->offset = 0;
-    s->limit = 0;
+    s->limit = ~0UL;
     s->desc = desc;
     s->current_buffer_idx = -1;
     s->allow_buffer_resize = FALSE;
@@ -496,7 +479,7 @@ static void schan_resize_current_buffer(const struct schan_buffers *s, SIZE_T mi
     b->pvBuffer = new_data;
 }
 
-static char *schan_get_buffer(const struct schan_transport *t, struct schan_buffers *s, size_t *count)
+char *schan_get_buffer(const struct schan_transport *t, struct schan_buffers *s, SIZE_T *count)
 {
     SIZE_T max_count;
     PSecBuffer buffer;
@@ -524,6 +507,8 @@ static char *schan_get_buffer(const struct schan_transport *t, struct schan_buff
 
     schan_resize_current_buffer(s, s->offset + *count);
     max_count = buffer->cbBuffer - s->offset;
+    if (s->limit != ~0UL && s->limit < max_count)
+        max_count = s->limit;
     if (!max_count)
     {
         int buffer_idx;
@@ -540,7 +525,11 @@ static char *schan_get_buffer(const struct schan_transport *t, struct schan_buff
         return schan_get_buffer(t, s, count);
     }
 
-    if (*count > max_count) *count = max_count;
+    if (*count > max_count)
+        *count = max_count;
+    if (s->limit != ~0UL)
+        s->limit -= *count;
+
     return (char *)buffer->pvBuffer + s->offset;
 }
 
@@ -566,9 +555,9 @@ static char *schan_get_buffer(const struct schan_transport *t, struct schan_buff
 int schan_pull(struct schan_transport *t, void *buff, size_t *buff_len)
 {
     char *b;
-    size_t local_len = *buff_len;
+    SIZE_T local_len = *buff_len;
 
-    TRACE("Pull %zu bytes\n", local_len);
+    TRACE("Pull %lu bytes\n", local_len);
 
     *buff_len = 0;
 
@@ -576,17 +565,10 @@ int schan_pull(struct schan_transport *t, void *buff, size_t *buff_len)
     if (!b)
         return EAGAIN;
 
-    if (t->in.limit != 0 && t->in.offset + local_len >= t->in.limit)
-    {
-        local_len = t->in.limit - t->in.offset;
-        if (local_len == 0)
-            return EAGAIN;
-    }
-
     memcpy(buff, b, local_len);
     t->in.offset += local_len;
 
-    TRACE("Read %zu bytes\n", local_len);
+    TRACE("Read %lu bytes\n", local_len);
 
     *buff_len = local_len;
     return 0;
@@ -612,9 +594,9 @@ int schan_pull(struct schan_transport *t, void *buff, size_t *buff_len)
 int schan_push(struct schan_transport *t, const void *buff, size_t *buff_len)
 {
     char *b;
-    size_t local_len = *buff_len;
+    SIZE_T local_len = *buff_len;
 
-    TRACE("Push %zu bytes\n", local_len);
+    TRACE("Push %lu bytes\n", local_len);
 
     *buff_len = 0;
 
@@ -625,7 +607,7 @@ int schan_push(struct schan_transport *t, const void *buff, size_t *buff_len)
     memcpy(b, buff, local_len);
     t->out.offset += local_len;
 
-    TRACE("Wrote %zu bytes\n", local_len);
+    TRACE("Wrote %lu bytes\n", local_len);
 
     *buff_len = local_len;
     return 0;
@@ -819,15 +801,17 @@ static SECURITY_STATUS SEC_ENTRY schan_QueryContextAttributesW(
             if (status == SEC_E_OK)
             {
                 SecPkgContext_StreamSizes *stream_sizes = buffer;
-                size_t mac_size = info.dwHashStrength;
+                SIZE_T mac_size = info.dwHashStrength;
                 unsigned int block_size = schan_imp_get_session_cipher_block_size(ctx->session);
+                unsigned int message_size = schan_imp_get_max_message_size(ctx->session);
 
-                TRACE("Using %zu mac bytes, block size %u\n", mac_size, block_size);
+                TRACE("Using %lu mac bytes, message size %u, block size %u\n",
+                        mac_size, message_size, block_size);
 
                 /* These are defined by the TLS RFC */
                 stream_sizes->cbHeader = 5;
                 stream_sizes->cbTrailer = mac_size + 256; /* Max 255 bytes padding + 1 for padding size */
-                stream_sizes->cbMaximumMessage = 1 << 14;
+                stream_sizes->cbMaximumMessage = message_size;
                 stream_sizes->cbBuffers = 4;
                 stream_sizes->cbBlockSize = block_size;
             }
@@ -923,10 +907,11 @@ static SECURITY_STATUS SEC_ENTRY schan_EncryptMessage(PCtxtHandle context_handle
     struct schan_transport transport;
     struct schan_context *ctx;
     struct schan_buffers *b;
+    SECURITY_STATUS status;
     SecBuffer *buffer;
     SIZE_T data_size;
+    SIZE_T length;
     char *data;
-    ssize_t sent = 0;
     int idx;
 
     TRACE("context_handle %p, quality %d, message %p, message_seq_no %d\n",
@@ -957,29 +942,21 @@ static SECURITY_STATUS SEC_ENTRY schan_EncryptMessage(PCtxtHandle context_handle
         init_schan_buffers(&transport.out, message, schan_encrypt_message_get_next_buffer_token);
     schan_imp_set_session_transport(ctx->session, &transport);
 
-    while (sent < data_size)
-    {
-        size_t length = data_size - sent;
-        SECURITY_STATUS status = schan_imp_send(ctx->session, data + sent, &length);
-        if (status == SEC_I_CONTINUE_NEEDED)
-            break;
-        else if (status != SEC_E_OK)
-        {
-            HeapFree(GetProcessHeap(), 0, data);
-            ERR("Returning %d\n", status);
-            return status;
-        }
+    length = data_size;
+    status = schan_imp_send(ctx->session, data, &length);
 
-        sent += length;
-    }
+    TRACE("Sent %ld bytes.\n", length);
 
-    TRACE("Sent %zd bytes\n", sent);
+    if (length != data_size)
+        status = SEC_E_INTERNAL_ERROR;
 
     b = &transport.out;
     b->desc->pBuffers[b->current_buffer_idx].cbBuffer = b->offset;
     HeapFree(GetProcessHeap(), 0, data);
 
-    return SEC_E_OK;
+    TRACE("Returning %#x.\n", status);
+
+    return status;
 }
 
 static int schan_decrypt_message_get_next_buffer(const struct schan_transport *t, struct schan_buffers *s)
@@ -1055,7 +1032,7 @@ static SECURITY_STATUS SEC_ENTRY schan_DecryptMessage(PCtxtHandle context_handle
     SIZE_T data_size;
     char *data;
     unsigned expected_size;
-    ssize_t received = 0;
+    SSIZE_T received = 0;
     int idx;
     unsigned char *buf_ptr;
 
@@ -1101,7 +1078,7 @@ static SECURITY_STATUS SEC_ENTRY schan_DecryptMessage(PCtxtHandle context_handle
 
     while (received < data_size)
     {
-        size_t length = data_size - received;
+        SIZE_T length = data_size - received;
         SECURITY_STATUS status = schan_imp_recv(ctx->session, data + received, &length);
         if (status == SEC_I_CONTINUE_NEEDED)
         {
@@ -1125,7 +1102,7 @@ static SECURITY_STATUS SEC_ENTRY schan_DecryptMessage(PCtxtHandle context_handle
         received += length;
     }
 
-    TRACE("Received %zd bytes\n", received);
+    TRACE("Received %ld bytes\n", received);
 
     memcpy(buf_ptr + 5, data, received);
     HeapFree(GetProcessHeap(), 0, data);
