@@ -62,8 +62,10 @@ MAKE_FUNCPTR(gnutls_mac_get_key_size);
 MAKE_FUNCPTR(gnutls_perror);
 MAKE_FUNCPTR(gnutls_protocol_get_version);
 MAKE_FUNCPTR(gnutls_set_default_priority);
+MAKE_FUNCPTR(gnutls_record_get_max_size);
 MAKE_FUNCPTR(gnutls_record_recv);
 MAKE_FUNCPTR(gnutls_record_send);
+MAKE_FUNCPTR(gnutls_transport_get_ptr);
 MAKE_FUNCPTR(gnutls_transport_set_errno);
 MAKE_FUNCPTR(gnutls_transport_set_ptr);
 MAKE_FUNCPTR(gnutls_transport_set_pull_function);
@@ -289,6 +291,11 @@ unsigned int schan_imp_get_session_cipher_block_size(schan_imp_session session)
     return schannel_get_cipher_block_size(cipher);
 }
 
+unsigned int schan_imp_get_max_message_size(schan_imp_session session)
+{
+    return pgnutls_record_get_max_size((gnutls_session_t)session);
+}
+
 SECURITY_STATUS schan_imp_get_connection_info(schan_imp_session session,
                                               SecPkgContext_ConnectionInfo *info)
 {
@@ -331,14 +338,26 @@ SECURITY_STATUS schan_imp_get_session_peer_certificate(schan_imp_session session
 }
 
 SECURITY_STATUS schan_imp_send(schan_imp_session session, const void *buffer,
-                               size_t *length)
+                               SIZE_T *length)
 {
     gnutls_session_t s = (gnutls_session_t)session;
-    ssize_t ret = pgnutls_record_send(s, buffer, *length);
+    ssize_t ret;
+
+again:
+    ret = pgnutls_record_send(s, buffer, *length);
+
     if (ret >= 0)
         *length = ret;
     else if (ret == GNUTLS_E_AGAIN)
+    {
+        struct schan_transport *t = (struct schan_transport *)pgnutls_transport_get_ptr(s);
+        SIZE_T count = 0;
+
+        if (schan_get_buffer(t, &t->out, &count))
+            goto again;
+
         return SEC_I_CONTINUE_NEEDED;
+    }
     else
     {
         pgnutls_perror(ret);
@@ -349,14 +368,26 @@ SECURITY_STATUS schan_imp_send(schan_imp_session session, const void *buffer,
 }
 
 SECURITY_STATUS schan_imp_recv(schan_imp_session session, void *buffer,
-                               size_t *length)
+                               SIZE_T *length)
 {
     gnutls_session_t s = (gnutls_session_t)session;
-    ssize_t ret = pgnutls_record_recv(s, buffer, *length);
+    ssize_t ret;
+
+again:
+    ret = pgnutls_record_recv(s, buffer, *length);
+
     if (ret >= 0)
         *length = ret;
     else if (ret == GNUTLS_E_AGAIN)
+    {
+        struct schan_transport *t = (struct schan_transport *)pgnutls_transport_get_ptr(s);
+        SIZE_T count = 0;
+
+        if (schan_get_buffer(t, &t->in, &count))
+            goto again;
+
         return SEC_I_CONTINUE_NEEDED;
+    }
     else
     {
         pgnutls_perror(ret);
@@ -423,8 +454,10 @@ BOOL schan_imp_init(void)
     LOAD_FUNCPTR(gnutls_perror)
     LOAD_FUNCPTR(gnutls_protocol_get_version)
     LOAD_FUNCPTR(gnutls_set_default_priority)
+    LOAD_FUNCPTR(gnutls_record_get_max_size);
     LOAD_FUNCPTR(gnutls_record_recv);
     LOAD_FUNCPTR(gnutls_record_send);
+    LOAD_FUNCPTR(gnutls_transport_get_ptr)
     LOAD_FUNCPTR(gnutls_transport_set_errno)
     LOAD_FUNCPTR(gnutls_transport_set_ptr)
     LOAD_FUNCPTR(gnutls_transport_set_pull_function)
