@@ -28,6 +28,7 @@
 #include "objbase.h"
 #include "shlguid.h"
 #include "shlwapi.h"
+#include "shobjidl.h"
 #include "shell32_main.h"
 #include "ver.h"
 #include "wine/unicode.h"
@@ -36,7 +37,7 @@
 WINE_DEFAULT_DEBUG_CHANNEL(shell);
 
 /**************************************************************************
- *  IQueryAssociations {SHELL32}
+ *  IQueryAssociations
  *
  * DESCRIPTION
  *  This object provides a layer of abstraction over the system registry in
@@ -65,13 +66,20 @@ typedef struct
   HKEY hkeyProgID;
 } IQueryAssociationsImpl;
 
+typedef struct
+{
+  IApplicationAssociationRegistration IApplicationAssociationRegistration_iface;
+  LONG ref;
+} IApplicationAssociationRegistrationImpl;
+
+
 static inline IQueryAssociationsImpl *impl_from_IQueryAssociations(IQueryAssociations *iface)
 {
   return CONTAINING_RECORD(iface, IQueryAssociationsImpl, IQueryAssociations_iface);
 }
 
 /**************************************************************************
- *  IQueryAssociations_QueryInterface {SHLWAPI}
+ *  IQueryAssociations_QueryInterface
  *
  * See IUnknown_QueryInterface.
  */
@@ -84,6 +92,9 @@ static HRESULT WINAPI IQueryAssociations_fnQueryInterface(
 
   TRACE("(%p,%s,%p)\n",This, debugstr_guid(riid), ppvObj);
 
+  if (ppvObj == NULL)
+      return E_POINTER;
+
   *ppvObj = NULL;
 
   if (IsEqualIID(riid, &IID_IUnknown) ||
@@ -100,7 +111,7 @@ static HRESULT WINAPI IQueryAssociations_fnQueryInterface(
 }
 
 /**************************************************************************
- *  IQueryAssociations_AddRef {SHLWAPI}
+ *  IQueryAssociations_AddRef
  *
  * See IUnknown_AddRef.
  */
@@ -115,7 +126,7 @@ static ULONG WINAPI IQueryAssociations_fnAddRef(IQueryAssociations *iface)
 }
 
 /**************************************************************************
- *  IQueryAssociations_Release {SHLWAPI}
+ *  IQueryAssociations_Release
  *
  * See IUnknown_Release.
  */
@@ -131,14 +142,14 @@ static ULONG WINAPI IQueryAssociations_fnRelease(IQueryAssociations *iface)
     TRACE("Destroying IQueryAssociations (%p)\n", This);
     RegCloseKey(This->hkeySource);
     RegCloseKey(This->hkeyProgID);
-    HeapFree(GetProcessHeap(), 0, This);
+    SHFree(This);
   }
 
   return refCount;
 }
 
 /**************************************************************************
- *  IQueryAssociations_Init {SHLWAPI}
+ *  IQueryAssociations_Init
  *
  * Initialise an IQueryAssociations object.
  *
@@ -204,27 +215,28 @@ static HRESULT WINAPI IQueryAssociations_fnInit(
         return E_INVALIDARG;
 }
 
-static HRESULT ASSOC_GetValue(HKEY hkey, WCHAR ** pszText)
+static HRESULT ASSOC_GetValue(HKEY hkey, const WCHAR *name, void **data, DWORD *data_size)
 {
-  DWORD len;
+  DWORD size;
   LONG ret;
 
-  assert(pszText);
-  ret = RegQueryValueExW(hkey, NULL, 0, NULL, NULL, &len);
+  assert(data);
+  ret = RegQueryValueExW(hkey, name, 0, NULL, NULL, &size);
   if (ret != ERROR_SUCCESS)
     return HRESULT_FROM_WIN32(ret);
-  if (!len)
+  if (!size)
     return E_FAIL;
-  *pszText = HeapAlloc(GetProcessHeap(), 0, len);
-  if (!*pszText)
+  *data = HeapAlloc(GetProcessHeap(), 0, size);
+  if (!*data)
     return E_OUTOFMEMORY;
-  ret = RegQueryValueExW(hkey, NULL, 0, NULL, (LPBYTE)*pszText,
-                         &len);
+  ret = RegQueryValueExW(hkey, name, 0, NULL, (LPBYTE)*data, &size);
   if (ret != ERROR_SUCCESS)
   {
-    HeapFree(GetProcessHeap(), 0, *pszText);
+    HeapFree(GetProcessHeap(), 0, *data);
     return HRESULT_FROM_WIN32(ret);
   }
+  if(data_size)
+      *data_size = size;
   return S_OK;
 }
 
@@ -242,7 +254,7 @@ static HRESULT ASSOC_GetCommand(IQueryAssociationsImpl *This,
   static const WCHAR commandW[] = { 'c','o','m','m','a','n','d',0 };
   static const WCHAR shellW[] = { 's','h','e','l','l',0 };
 
-  hr = ASSOC_GetValue(This->hkeySource, &pszFileType);
+  hr = ASSOC_GetValue(This->hkeySource, NULL, (void**)&pszFileType, NULL);
   if (FAILED(hr))
     return hr;
   ret = RegOpenKeyExW(HKEY_CLASSES_ROOT, pszFileType, 0, KEY_READ, &hkeyFile);
@@ -257,7 +269,7 @@ static HRESULT ASSOC_GetCommand(IQueryAssociationsImpl *This,
 
   if (!pszExtra)
   {
-    hr = ASSOC_GetValue(hkeyShell, &pszExtraFromReg);
+    hr = ASSOC_GetValue(hkeyShell, NULL, (void**)&pszExtraFromReg, NULL);
     /* if no default action */
     if (hr == E_FAIL || hr == HRESULT_FROM_WIN32(ERROR_FILE_NOT_FOUND))
     {
@@ -300,7 +312,7 @@ static HRESULT ASSOC_GetCommand(IQueryAssociationsImpl *This,
   RegCloseKey(hkeyVerb);
   if (ret != ERROR_SUCCESS)
     return HRESULT_FROM_WIN32(ret);
-  hr = ASSOC_GetValue(hkeyCommand, ppszCommand);
+  hr = ASSOC_GetValue(hkeyCommand, NULL, (void**)ppszCommand, NULL);
   RegCloseKey(hkeyCommand);
   return hr;
 }
@@ -350,7 +362,7 @@ static HRESULT ASSOC_GetExecutable(IQueryAssociationsImpl *This,
   return S_OK;
 }
 
-static HRESULT ASSOC_ReturnData(LPWSTR out, DWORD *outlen, LPCWSTR data,
+static HRESULT ASSOC_ReturnData(void *out, DWORD *outlen, const void *data,
                                 DWORD datalen)
 {
   assert(outlen);
@@ -363,7 +375,7 @@ static HRESULT ASSOC_ReturnData(LPWSTR out, DWORD *outlen, LPCWSTR data,
       return E_POINTER;
     }
     *outlen = datalen;
-    lstrcpynW(out, data, datalen);
+    memcpy(out, data, datalen);
     return S_OK;
   }
   else
@@ -373,8 +385,21 @@ static HRESULT ASSOC_ReturnData(LPWSTR out, DWORD *outlen, LPCWSTR data,
   }
 }
 
+static HRESULT ASSOC_ReturnString(LPWSTR out, DWORD *outlen, LPCWSTR data,
+        DWORD datalen)
+{
+    HRESULT hres;
+
+    assert(outlen);
+
+    *outlen *= sizeof(WCHAR);
+    hres = ASSOC_ReturnData(out, outlen, data, datalen*sizeof(WCHAR));
+    *outlen /= sizeof(WCHAR);
+    return hres;
+}
+
 /**************************************************************************
- *  IQueryAssociations_GetString {SHLWAPI}
+ *  IQueryAssociations_GetString
  *
  * Get a file association string from the registry.
  *
@@ -421,7 +446,7 @@ static HRESULT WINAPI IQueryAssociations_fnGetString(
       hr = ASSOC_GetCommand(This, pszExtra, &command);
       if (SUCCEEDED(hr))
       {
-        hr = ASSOC_ReturnData(pszOut, pcchOut, command, strlenW(command) + 1);
+        hr = ASSOC_ReturnString(pszOut, pcchOut, command, strlenW(command) + 1);
         HeapFree(GetProcessHeap(), 0, command);
       }
       return hr;
@@ -433,7 +458,7 @@ static HRESULT WINAPI IQueryAssociations_fnGetString(
       if (FAILED(hr))
         return hr;
       len++;
-      return ASSOC_ReturnData(pszOut, pcchOut, path, len);
+      return ASSOC_ReturnString(pszOut, pcchOut, path, len);
     }
 
     case ASSOCSTR_FRIENDLYDOCNAME:
@@ -442,7 +467,7 @@ static HRESULT WINAPI IQueryAssociations_fnGetString(
       DWORD ret;
       DWORD size;
 
-      hr = ASSOC_GetValue(This->hkeySource, &pszFileType);
+      hr = ASSOC_GetValue(This->hkeySource, NULL, (void**)&pszFileType, NULL);
       if (FAILED(hr))
         return hr;
       size = 0;
@@ -454,7 +479,7 @@ static HRESULT WINAPI IQueryAssociations_fnGetString(
         {
           ret = RegGetValueW(HKEY_CLASSES_ROOT, pszFileType, NULL, RRF_RT_REG_SZ, NULL, docName, &size);
           if (ret == ERROR_SUCCESS)
-            hr = ASSOC_ReturnData(pszOut, pcchOut, docName, strlenW(docName) + 1);
+            hr = ASSOC_ReturnString(pszOut, pcchOut, docName, strlenW(docName) + 1);
           else
             hr = HRESULT_FROM_WIN32(ret);
           HeapFree(GetProcessHeap(), 0, docName);
@@ -510,7 +535,7 @@ static HRESULT WINAPI IQueryAssociations_fnGetString(
             /* Does strlenW(bufW) == 0 mean we use the filename? */
             len = strlenW(bufW) + 1;
             TRACE("found FileDescription: %s\n", debugstr_w(bufW));
-            hr = ASSOC_ReturnData(pszOut, pcchOut, bufW, len);
+            hr = ASSOC_ReturnString(pszOut, pcchOut, bufW, len);
             HeapFree(GetProcessHeap(), 0, verinfoW);
             return hr;
           }
@@ -520,7 +545,7 @@ get_friendly_name_fail:
       PathRemoveExtensionW(path);
       PathStripPathW(path);
       TRACE("using filename: %s\n", debugstr_w(path));
-      hr = ASSOC_ReturnData(pszOut, pcchOut, path, strlenW(path) + 1);
+      hr = ASSOC_ReturnString(pszOut, pcchOut, path, strlenW(path) + 1);
       HeapFree(GetProcessHeap(), 0, verinfoW);
       return hr;
     }
@@ -541,7 +566,7 @@ get_friendly_name_fail:
       {
         ret = RegGetValueW(This->hkeySource, NULL, Content_TypeW, RRF_RT_REG_SZ, NULL, contentType, &size);
         if (ret == ERROR_SUCCESS)
-          hr = ASSOC_ReturnData(pszOut, pcchOut, contentType, strlenW(contentType) + 1);
+          hr = ASSOC_ReturnString(pszOut, pcchOut, contentType, strlenW(contentType) + 1);
         else
           hr = HRESULT_FROM_WIN32(ret);
         HeapFree(GetProcessHeap(), 0, contentType);
@@ -559,7 +584,7 @@ get_friendly_name_fail:
       DWORD size;
       HKEY hkeyFile;
 
-      hr = ASSOC_GetValue(This->hkeySource, &pszFileType);
+      hr = ASSOC_GetValue(This->hkeySource, NULL, (void**)&pszFileType, NULL);
       if (FAILED(hr))
         return hr;
       ret = RegOpenKeyExW(HKEY_CLASSES_ROOT, pszFileType, 0, KEY_READ, &hkeyFile);
@@ -574,7 +599,7 @@ get_friendly_name_fail:
           {
             ret = RegGetValueW(hkeyFile, DefaultIconW, NULL, RRF_RT_REG_SZ, NULL, icon, &size);
             if (ret == ERROR_SUCCESS)
-              hr = ASSOC_ReturnData(pszOut, pcchOut, icon, strlenW(icon) + 1);
+              hr = ASSOC_ReturnString(pszOut, pcchOut, icon, strlenW(icon) + 1);
             else
               hr = HRESULT_FROM_WIN32(ret);
             HeapFree(GetProcessHeap(), 0, icon);
@@ -599,7 +624,7 @@ get_friendly_name_fail:
 }
 
 /**************************************************************************
- *  IQueryAssociations_GetKey {SHLWAPI}
+ *  IQueryAssociations_GetKey
  *
  * Get a file association key from the registry.
  *
@@ -629,7 +654,7 @@ static HRESULT WINAPI IQueryAssociations_fnGetKey(
 }
 
 /**************************************************************************
- *  IQueryAssociations_GetData {SHLWAPI}
+ *  IQueryAssociations_GetData
  *
  * Get the data for a file association key from the registry.
  *
@@ -645,23 +670,43 @@ static HRESULT WINAPI IQueryAssociations_fnGetKey(
  *  Success: S_OK. pszOut contains the data, pcbOut contains its length.
  *  Failure: An HRESULT error code indicating the error.
  */
-static HRESULT WINAPI IQueryAssociations_fnGetData(
-  IQueryAssociations *iface,
-  ASSOCF cfFlags,
-  ASSOCDATA assocdata,
-  LPCWSTR pszExtra,
-  LPVOID pvOut,
-  DWORD *pcbOut)
+static HRESULT WINAPI IQueryAssociations_fnGetData(IQueryAssociations *iface,
+        ASSOCF cfFlags, ASSOCDATA assocdata, LPCWSTR pszExtra, LPVOID pvOut,
+        DWORD *pcbOut)
 {
-  IQueryAssociationsImpl *This = impl_from_IQueryAssociations(iface);
+    static const WCHAR edit_flags[] = {'E','d','i','t','F','l','a','g','s',0};
 
-  FIXME("(%p,0x%8x,0x%8x,%s,%p,%p)-stub!\n", This, cfFlags, assocdata,
-        debugstr_w(pszExtra), pvOut, pcbOut);
-  return E_NOTIMPL;
+    IQueryAssociationsImpl *This = impl_from_IQueryAssociations(iface);
+    void *data;
+    DWORD size;
+    HRESULT hres;
+
+    TRACE("(%p,0x%8x,0x%8x,%s,%p,%p)\n", This, cfFlags, assocdata,
+            debugstr_w(pszExtra), pvOut, pcbOut);
+
+    if(cfFlags)
+        FIXME("Unsupported flags: %x\n", cfFlags);
+
+    switch(assocdata) {
+    case ASSOCDATA_EDITFLAGS:
+        if(!This->hkeyProgID)
+            return HRESULT_FROM_WIN32(ERROR_NO_ASSOCIATION);
+
+        hres = ASSOC_GetValue(This->hkeyProgID, edit_flags, &data, &size);
+        if(FAILED(hres) || !pcbOut)
+            return hres;
+
+        hres = ASSOC_ReturnData(pvOut, pcbOut, data, size);
+        HeapFree(GetProcessHeap(), 0, data);
+        return hres;
+    default:
+        FIXME("Unsupported ASSOCDATA value: %d\n", assocdata);
+        return E_NOTIMPL;
+    }
 }
 
 /**************************************************************************
- *  IQueryAssociations_GetEnum {SHLWAPI}
+ *  IQueryAssociations_GetEnum
  *
  * Not yet implemented in native Win32.
  *
@@ -707,6 +752,114 @@ static const IQueryAssociationsVtbl IQueryAssociations_vtbl =
   IQueryAssociations_fnGetEnum
 };
 
+/**************************************************************************
+ * IApplicationAssociationRegistration implementation
+ */
+static inline IApplicationAssociationRegistrationImpl *impl_from_IApplicationAssociationRegistration(IApplicationAssociationRegistration *iface)
+{
+  return CONTAINING_RECORD(iface, IApplicationAssociationRegistrationImpl, IApplicationAssociationRegistration_iface);
+}
+
+static HRESULT WINAPI ApplicationAssociationRegistration_QueryInterface(
+                        IApplicationAssociationRegistration* iface, REFIID riid, LPVOID *ppv)
+{
+    IApplicationAssociationRegistrationImpl *This = impl_from_IApplicationAssociationRegistration(iface);
+
+    TRACE("(%p, %s, %p)\n",This, debugstr_guid(riid), ppv);
+
+    if (ppv == NULL)
+        return E_POINTER;
+
+    if (IsEqualGUID(&IID_IUnknown, riid) ||
+        IsEqualGUID(&IID_IApplicationAssociationRegistration, riid)) {
+        *ppv = &This->IApplicationAssociationRegistration_iface;
+        IUnknown_AddRef((IUnknown*)*ppv);
+        TRACE("returning IApplicationAssociationRegistration: %p\n", *ppv);
+        return S_OK;
+    }
+
+    *ppv = NULL;
+    FIXME("(%p)->(%s %p) interface not supported\n", This, debugstr_guid(riid), ppv);
+    return E_NOINTERFACE;
+}
+
+static ULONG WINAPI ApplicationAssociationRegistration_AddRef(IApplicationAssociationRegistration *iface)
+{
+    IApplicationAssociationRegistrationImpl *This = impl_from_IApplicationAssociationRegistration(iface);
+    ULONG ref = InterlockedIncrement(&This->ref);
+
+    TRACE("(%p) ref=%d\n", This, ref);
+    return ref;
+}
+
+static ULONG WINAPI ApplicationAssociationRegistration_Release(IApplicationAssociationRegistration *iface)
+{
+    IApplicationAssociationRegistrationImpl *This = impl_from_IApplicationAssociationRegistration(iface);
+    ULONG ref = InterlockedDecrement(&This->ref);
+
+    TRACE("(%p) ref=%d\n", This, ref);
+
+    if (!ref) {
+        SHFree(This);
+    }
+    return ref;
+}
+
+static HRESULT WINAPI ApplicationAssociationRegistration_QueryCurrentDefault(IApplicationAssociationRegistration* This, LPCWSTR query,
+                                                                             ASSOCIATIONTYPE type, ASSOCIATIONLEVEL level, LPWSTR *association)
+{
+    FIXME("(%p)->(%s, %d, %d, %p)\n", This, debugstr_w(query), type, level, association);
+    return E_NOTIMPL;
+}
+
+static HRESULT WINAPI ApplicationAssociationRegistration_QueryAppIsDefault(IApplicationAssociationRegistration* This, LPCWSTR query,
+                                                                           ASSOCIATIONTYPE type, ASSOCIATIONLEVEL level, LPCWSTR appname, BOOL *is_default)
+{
+    FIXME("(%p)->(%s, %d, %d, %s, %p)\n", This, debugstr_w(query), type, level, debugstr_w(appname), is_default);
+    return E_NOTIMPL;
+}
+
+static HRESULT WINAPI ApplicationAssociationRegistration_QueryAppIsDefaultAll(IApplicationAssociationRegistration* This, ASSOCIATIONLEVEL level,
+                                                                              LPCWSTR appname, BOOL *is_default)
+{
+    FIXME("(%p)->(%d, %s, %p)\n", This, level, debugstr_w(appname), is_default);
+    return E_NOTIMPL;
+}
+
+static HRESULT WINAPI ApplicationAssociationRegistration_SetAppAsDefault(IApplicationAssociationRegistration* This, LPCWSTR appname,
+                                                                         LPCWSTR set, ASSOCIATIONTYPE set_type)
+{
+    FIXME("(%p)->(%s, %s, %d)\n", This, debugstr_w(appname), debugstr_w(set), set_type);
+    return E_NOTIMPL;
+}
+
+static HRESULT WINAPI ApplicationAssociationRegistration_SetAppAsDefaultAll(IApplicationAssociationRegistration* This, LPCWSTR appname)
+{
+    FIXME("(%p)->(%s)\n", This, debugstr_w(appname));
+    return E_NOTIMPL;
+}
+
+
+static HRESULT WINAPI ApplicationAssociationRegistration_ClearUserAssociations(IApplicationAssociationRegistration* This)
+{
+    FIXME("(%p)\n", This);
+    return E_NOTIMPL;
+}
+
+
+static const IApplicationAssociationRegistrationVtbl IApplicationAssociationRegistration_vtbl =
+{
+    ApplicationAssociationRegistration_QueryInterface,
+    ApplicationAssociationRegistration_AddRef,
+    ApplicationAssociationRegistration_Release,
+    ApplicationAssociationRegistration_QueryCurrentDefault,
+    ApplicationAssociationRegistration_QueryAppIsDefault,
+    ApplicationAssociationRegistration_QueryAppIsDefaultAll,
+    ApplicationAssociationRegistration_SetAppAsDefault,
+    ApplicationAssociationRegistration_SetAppAsDefaultAll,
+    ApplicationAssociationRegistration_ClearUserAssociations
+};
+
 /**************************************************************************
  *  IQueryAssociations_Constructor [internal]
  *
@@ -728,3 +881,30 @@ HRESULT WINAPI QueryAssociations_Constructor(IUnknown *pUnkOuter, REFIID riid, L
     TRACE("returning %p\n", *ppOutput);
     return ret;
 }
+
+/**************************************************************************
+ * ApplicationAssociationRegistration_Constructor [internal]
+ *
+ * Construct a IApplicationAssociationRegistration object.
+ */
+HRESULT WINAPI ApplicationAssociationRegistration_Constructor(IUnknown *outer, REFIID riid, LPVOID *ppv)
+{
+    IApplicationAssociationRegistrationImpl *This;
+    HRESULT hr;
+
+    if (outer)
+        return CLASS_E_NOAGGREGATION;
+
+    if (!(This = SHAlloc(sizeof(*This))))
+        return E_OUTOFMEMORY;
+
+    This->IApplicationAssociationRegistration_iface.lpVtbl = &IApplicationAssociationRegistration_vtbl;
+    This->ref = 0;
+
+    hr = IUnknown_QueryInterface(&This->IApplicationAssociationRegistration_iface, riid, ppv);
+    if (FAILED(hr))
+        SHFree(This);
+
+    TRACE("returning 0x%x with %p\n", hr, *ppv);
+    return hr;
+}
