@@ -932,7 +932,7 @@ HRESULT WINAPI SHLoadInProc (REFCLSID rclsid)
     {
         IUnknown * pUnk = ptr;
         IUnknown_Release(pUnk);
-        return NOERROR;
+        return S_OK;
     }
     return DISP_E_MEMBERNOTFOUND;
 }
@@ -1183,7 +1183,7 @@ HIMAGELIST   ShellBigIconList = 0;
  * SHELL32 DllMain
  *
  * NOTES
- *  calling oleinitialize here breaks sone apps.
+ *  calling oleinitialize here breaks some apps.
  */
 BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID fImpLoad)
 {
