@@ -155,7 +155,7 @@ static inline IShellViewImpl *impl_from_IShellFolderView(IShellFolderView *iface
     return CONTAINING_RECORD(iface, IShellViewImpl, IShellFolderView_iface);
 }
 
-/* ListView Header ID's */
+/* ListView Header IDs */
 #define LISTVIEW_COLUMN_NAME 0
 #define LISTVIEW_COLUMN_SIZE 1
 #define LISTVIEW_COLUMN_TYPE 2
@@ -731,7 +731,7 @@ static LRESULT ShellView_OnCreate(IShellViewImpl *This)
         LPITEMIDLIST raw_pidl;
         SHChangeNotifyEntry ntreg;
 
-        hr = IPersistFolder2_GetCurFolder(ppf2, (LPITEMIDLIST*)&raw_pidl);
+        hr = IPersistFolder2_GetCurFolder(ppf2, &raw_pidl);
         if(SUCCEEDED(hr))
         {
             LPITEMIDLIST computer_pidl;
@@ -752,6 +752,7 @@ static LRESULT ShellView_OnCreate(IShellViewImpl *This)
             This->hNotify = SHChangeNotifyRegister(This->hWnd, SHCNRF_InterruptLevel, SHCNE_ALLEVENTS,
                                                    SHV_CHANGE_NOTIFY, 1, &ntreg);
             SHFree((LPITEMIDLIST)ntreg.pidl);
+            SHFree(computer_pidl);
         }
         IPersistFolder2_Release(ppf2);
     }
@@ -1017,7 +1018,6 @@ static void ShellView_DoContextMenu(IShellViewImpl * This, WORD x, WORD y, BOOL
 	BOOL	fExplore = FALSE;
 	HWND	hwndTree = 0;
 	LPCONTEXTMENU	pContextMenu = NULL;
-	IContextMenu2 *pCM = NULL;
 	CMINVOKECOMMANDINFO	cmi;
 
 	TRACE("(%p)->(0x%08x 0x%08x 0x%08x) stub\n",This, x, y, bDefault);
@@ -1092,9 +1092,11 @@ static void ShellView_DoContextMenu(IShellViewImpl * This, WORD x, WORD y, BOOL
 	}
 	else	/* background context menu */
 	{
+	  IContextMenu2 *pCM;
+
 	  hMenu = CreatePopupMenu();
 
-	  pCM = ISvBgCm_Constructor(This->pSFParent, FALSE);
+	  BackgroundMenu_Constructor(This->pSFParent, FALSE, &IID_IContextMenu2, (void**)&pCM);
 	  IContextMenu2_QueryContextMenu(pCM, hMenu, 0, FCIDM_SHVIEWFIRST, FCIDM_SHVIEWLAST, 0);
 
 	  uCommand = TrackPopupMenu( hMenu, TPM_LEFTALIGN | TPM_RETURNCMD,x,y,0,This->hWnd,NULL);
@@ -1272,7 +1274,7 @@ static LRESULT ShellView_OnKillFocus(IShellViewImpl * This)
 * ShellView_OnCommand()
 *
 * NOTES
-*	the CmdID's are the ones from the context menu
+*	the CmdIDs are the ones from the context menu
 */
 static LRESULT ShellView_OnCommand(IShellViewImpl * This,DWORD dwCmdID, DWORD dwCmd, HWND hwndCmd)
 {
@@ -1304,7 +1306,7 @@ static LRESULT ShellView_OnCommand(IShellViewImpl * This,DWORD dwCmdID, DWORD dw
 	    CheckToolbar(This);
 	    break;
 
-	  /* the menu-ID's for sorting are 0x30... see shell32.rc */
+	  /* the menu IDs for sorting are 0x30... see shell32.rc */
 	  case 0x30:
 	  case 0x31:
 	  case 0x32:
@@ -1997,7 +1999,7 @@ static HRESULT WINAPI IShellView_fnGetCurrentInfo(IShellView2 *iface, LPFOLDERSE
 	if (!lpfs) return E_INVALIDARG;
 
 	*lpfs = This->FolderSettings;
-	return NOERROR;
+	return S_OK;
 }
 
 static HRESULT WINAPI IShellView_fnAddPropertySheetPages(IShellView2 *iface, DWORD dwReserved,
@@ -2048,10 +2050,7 @@ static HRESULT WINAPI IShellView_fnGetItemObject(IShellView2 *iface, UINT uItem,
     case SVGIO_BACKGROUND:
 
         if (IsEqualIID(&IID_IContextMenu, riid))
-        {
-            *ppvOut = ISvBgCm_Constructor(This->pSFParent, FALSE);
-            hr = S_OK;
-        }
+            return BackgroundMenu_Constructor(This->pSFParent, FALSE, riid, ppvOut);
         else
             FIXME("unsupported interface requested %s\n", debugstr_guid(riid));
 
@@ -2094,9 +2093,7 @@ static HRESULT WINAPI IShellView2_fnCreateViewWindow2(IShellView2 *iface,
 
     TRACE("-- psvPrev %p, pfs %p, psbOwner %p, prcView %p\n",
             view_params->psvPrev, view_params->pfs, view_params->psbOwner, view_params->prcView);
-    TRACE("-- vmode %#x, flags %#x, left %d, top %d, right %d, bottom %d\n",
-            view_params->pfs->ViewMode, view_params->pfs->fFlags, view_params->prcView->left,
-            view_params->prcView->top, view_params->prcView->right, view_params->prcView->bottom);
+    TRACE("-- vmode %#x, flags %#x, view %s\n", view_params->pfs->ViewMode, view_params->pfs->fFlags, wine_dbgstr_rect(view_params->prcView));
 
     if (!view_params->psbOwner) return E_UNEXPECTED;
 
@@ -2560,7 +2557,7 @@ static HRESULT WINAPI ISVDropSource_QueryContinueDrag(
 	else if (!(grfKeyState & MK_LBUTTON) && !(grfKeyState & MK_RBUTTON))
 	  return DRAGDROP_S_DROP;
 	else
-	  return NOERROR;
+	  return S_OK;
 }
 
 static HRESULT WINAPI ISVDropSource_GiveFeedback(
