@@ -27,6 +27,7 @@
 #define NO_SHLWAPI_REG
 #include "shlwapi.h"
 #include "advpub.h"
+#include "initguid.h"
 
 #include "wine/debug.h"
 
@@ -34,6 +35,8 @@
 
 WINE_DEFAULT_DEBUG_CHANNEL(urlmon);
 
+DEFINE_GUID(CLSID_CUri, 0xDF2FCE13, 0x25EC, 0x45BB, 0x9D,0x4C, 0xCE,0xCD,0x47,0xC2,0x43,0x0C);
+
 LONG URLMON_refCount = 0;
 
 static HMODULE hCabinet = NULL;
@@ -292,6 +295,8 @@ static ClassFactory StdURLMonikerCF =
     { { &ClassFactoryVtbl }, StdURLMoniker_Construct};
 static ClassFactory MimeFilterCF =
     { { &ClassFactoryVtbl }, MimeFilter_Construct};
+static ClassFactory CUriCF =
+    { { &ClassFactoryVtbl }, Uri_Construct};
 
 struct object_creation_info
 {
@@ -318,7 +323,8 @@ static const struct object_creation_info object_creation[] =
     { &CLSID_InternetSecurityManager, &SecurityManagerCF.IClassFactory_iface, NULL    },
     { &CLSID_InternetZoneManager,     &ZoneManagerCF.IClassFactory_iface,     NULL    },
     { &CLSID_StdURLMoniker,           &StdURLMonikerCF.IClassFactory_iface,   NULL    },
-    { &CLSID_DeCompMimeFilter,        &MimeFilterCF.IClassFactory_iface,      NULL    }
+    { &CLSID_DeCompMimeFilter,        &MimeFilterCF.IClassFactory_iface,      NULL    },
+    { &CLSID_CUri,                    &CUriCF.IClassFactory_iface,            NULL    }
 };
 
 static void init_session(BOOL init)
@@ -538,6 +544,21 @@ HRESULT WINAPI CopyStgMedium(const STGMEDIUM *src, STGMEDIUM *dst)
         if(dst->u.pstg)
             IStorage_AddRef(dst->u.pstg);
         break;
+    case TYMED_HGLOBAL:
+        if(dst->u.hGlobal) {
+            SIZE_T size = GlobalSize(src->u.hGlobal);
+            char *src_ptr, *dst_ptr;
+
+            dst->u.hGlobal = GlobalAlloc(GMEM_FIXED, size);
+            if(!dst->u.hGlobal)
+                return E_OUTOFMEMORY;
+            dst_ptr = GlobalLock(dst->u.hGlobal);
+            src_ptr = GlobalLock(src->u.hGlobal);
+            memcpy(dst_ptr, src_ptr, size);
+            GlobalUnlock(src_ptr);
+            GlobalUnlock(dst_ptr);
+        }
+        break;
     default:
         FIXME("Unimplemented tymed %d\n", src->tymed);
     }
@@ -560,13 +581,19 @@ static BOOL text_html_filter(const BYTE *b, DWORD size)
     if(size < 5)
         return FALSE;
 
-    for(i=0; i < size-5; i++) {
-        if(b[i] == '<'
-           && (b[i+1] == 'h' || b[i+1] == 'H')
-           && (b[i+2] == 't' || b[i+2] == 'T')
-           && (b[i+3] == 'm' || b[i+3] == 'M')
-           && (b[i+4] == 'l' || b[i+4] == 'L'))
-            return TRUE;
+    for(i = 0; i < size-5; i++) {
+        if((b[i] == '<'
+            && (b[i+1] == 'h' || b[i+1] == 'H')
+            && (b[i+2] == 't' || b[i+2] == 'T')
+            && (b[i+3] == 'm' || b[i+3] == 'M')
+            && (b[i+4] == 'l' || b[i+4] == 'L')) ||
+           ((size - i >= 6)
+            &&  b[i]   == '<'
+            && (b[i+1] == 'h' || b[i+1] == 'H')
+            && (b[i+2] == 'e' || b[i+2] == 'E')
+            && (b[i+3] == 'a' || b[i+3] == 'A')
+            && (b[i+4] == 'd' || b[i+4] == 'D')
+            &&  b[i+5] == '>')) return TRUE;
     }
 
     return FALSE;
