@@ -376,7 +376,7 @@ HWND WINAPI ChildWindowFromPoint( HWND hwndParent, POINT pt )
  */
 HWND WINAPI RealChildWindowFromPoint( HWND hwndParent, POINT pt )
 {
-    return ChildWindowFromPointEx( hwndParent, pt, CWP_SKIPTRANSPARENT );
+    return ChildWindowFromPointEx( hwndParent, pt, CWP_SKIPTRANSPARENT | CWP_SKIPINVISIBLE );
 }
 
 /*******************************************************************
@@ -955,6 +955,7 @@ UINT WINPOS_MinMaximize( HWND hwnd, UINT cmd, LPRECT rect )
         /* fall through */
     case SW_SHOWNORMAL:
     case SW_RESTORE:
+    case SW_SHOWDEFAULT: /* FIXME: should have its own handler */
         old_style = WIN_SetStyle( hwnd, 0, WS_MINIMIZE | WS_MAXIMIZE );
         if (old_style & WS_MINIMIZE)
         {
@@ -1848,6 +1849,7 @@ static BOOL fixup_flags( WINDOWPOS *winpos )
 {
     HWND parent;
     RECT window_rect;
+    POINT pt;
     WND *wndPtr = WIN_GetPtr( winpos->hwnd );
     BOOL ret = TRUE;
 
@@ -1879,12 +1881,15 @@ static BOOL fixup_flags( WINDOWPOS *winpos )
         if (!(winpos->flags & SWP_SHOWWINDOW)) winpos->flags |= SWP_NOREDRAW;
     }
 
-    WIN_GetRectangles( winpos->hwnd, COORDS_PARENT, &window_rect, NULL );
+    WIN_GetRectangles( winpos->hwnd, COORDS_SCREEN, &window_rect, NULL );
     if ((window_rect.right - window_rect.left == winpos->cx) &&
         (window_rect.bottom - window_rect.top == winpos->cy))
         winpos->flags |= SWP_NOSIZE;    /* Already the right size */
 
-    if ((window_rect.left == winpos->x) && (window_rect.top == winpos->y))
+    pt.x = winpos->x;
+    pt.y = winpos->y;
+    ClientToScreen( parent, &pt );
+    if ((window_rect.left == pt.x) && (window_rect.top == pt.y))
         winpos->flags |= SWP_NOMOVE;    /* Already the right position */
 
     if ((wndPtr->dwStyle & (WS_POPUP | WS_CHILD)) != WS_CHILD)
@@ -1901,11 +1906,6 @@ static BOOL fixup_flags( WINDOWPOS *winpos )
     /* Check hwndInsertAfter */
     if (winpos->flags & SWP_NOZORDER) goto done;
 
-    /* fix sign extension */
-    if (winpos->hwndInsertAfter == (HWND)0xffff) winpos->hwndInsertAfter = HWND_TOPMOST;
-    else if (winpos->hwndInsertAfter == (HWND)0xfffe) winpos->hwndInsertAfter = HWND_NOTOPMOST;
-
-    /* hwndInsertAfter must be a sibling of the window */
     if (winpos->hwndInsertAfter == HWND_TOP)
     {
         if (GetWindow(winpos->hwnd, GW_HWNDFIRST) == winpos->hwnd)
@@ -1928,16 +1928,9 @@ static BOOL fixup_flags( WINDOWPOS *winpos )
     }
     else
     {
-        if (GetAncestor( winpos->hwndInsertAfter, GA_PARENT ) != parent) ret = FALSE;
-        else
-        {
-            /* don't need to change the Zorder of hwnd if it's already inserted
-             * after hwndInsertAfter or when inserting hwnd after itself.
-             */
-            if ((winpos->hwnd == winpos->hwndInsertAfter) ||
-                (winpos->hwnd == GetWindow( winpos->hwndInsertAfter, GW_HWNDNEXT )))
-                winpos->flags |= SWP_NOZORDER;
-        }
+        if ((winpos->hwnd == winpos->hwndInsertAfter) ||
+            (winpos->hwnd == GetWindow( winpos->hwndInsertAfter, GW_HWNDNEXT )))
+            winpos->flags |= SWP_NOZORDER;
     }
  done:
     WIN_ReleasePtr( wndPtr );
@@ -2032,8 +2025,29 @@ BOOL USER_SetWindowPos( WINDOWPOS * winpos )
     UINT orig_flags;
     
     orig_flags = winpos->flags;
-    
-    /* First make sure that coordinates are valid for WM_WINDOWPOSCHANGING */
+
+    /* First, check z-order arguments.  */
+    if (!(winpos->flags & SWP_NOZORDER))
+    {
+        /* fix sign extension */
+        if (winpos->hwndInsertAfter == (HWND)0xffff) winpos->hwndInsertAfter = HWND_TOPMOST;
+        else if (winpos->hwndInsertAfter == (HWND)0xfffe) winpos->hwndInsertAfter = HWND_NOTOPMOST;
+
+        if (!(winpos->hwndInsertAfter == HWND_TOP ||
+              winpos->hwndInsertAfter == HWND_BOTTOM ||
+              winpos->hwndInsertAfter == HWND_TOPMOST ||
+              winpos->hwndInsertAfter == HWND_NOTOPMOST))
+        {
+            HWND parent = GetAncestor( winpos->hwnd, GA_PARENT );
+            HWND insertafter_parent = GetAncestor( winpos->hwndInsertAfter, GA_PARENT );
+
+            /* hwndInsertAfter must be a sibling of the window */
+            if (!insertafter_parent) return FALSE;
+            if (insertafter_parent != parent) return TRUE;
+        }
+    }
+
+    /* Make sure that coordinates are valid for WM_WINDOWPOSCHANGING */
     if (!(winpos->flags & SWP_NOMOVE))
     {
         if (winpos->x < -32768) winpos->x = -32768;
@@ -2490,6 +2504,7 @@ void WINPOS_SysCommandSizeMove( HWND hwnd, WPARAM wParam )
     pt.x = (short)LOWORD(dwPoint);
     pt.y = (short)HIWORD(dwPoint);
     capturePoint = pt;
+    ClipCursor( NULL );
 
     TRACE("hwnd %p command %04lx, hittest %d, pos %d,%d\n",
           hwnd, syscommand, hittest, pt.x, pt.y);
