@@ -260,7 +260,7 @@ static HRESULT stack_push(exec_ctx_t *ctx, VARIANT *v)
     if(ctx->stack_size == ctx->top) {
         VARIANT *new_stack;
 
-        new_stack = heap_realloc(ctx->stack, ctx->stack_size*2);
+        new_stack = heap_realloc(ctx->stack, ctx->stack_size*2*sizeof(*ctx->stack));
         if(!new_stack) {
             VariantClear(v);
             return E_OUTOFMEMORY;
@@ -318,6 +318,34 @@ static inline void release_val(variant_val_t *v)
         VariantClear(v->v);
 }
 
+static int stack_pop_bool(exec_ctx_t *ctx, BOOL *b)
+{
+    variant_val_t val;
+    HRESULT hres;
+
+    hres = stack_pop_val(ctx, &val);
+    if(FAILED(hres))
+        return hres;
+
+    switch (V_VT(val.v))
+    {
+    case VT_BOOL:
+        *b = V_BOOL(val.v);
+        break;
+    case VT_I2:
+        *b = V_I2(val.v);
+        break;
+    case VT_I4:
+        *b = V_I4(val.v);
+        break;
+    default:
+        FIXME("unsupported for %s\n", debugstr_variant(val.v));
+        release_val(&val);
+        return E_NOTIMPL;
+    }
+    return S_OK;
+}
+
 static HRESULT stack_pop_disp(exec_ctx_t *ctx, IDispatch **ret)
 {
     VARIANT *v = stack_pop(ctx);
@@ -562,11 +590,17 @@ static HRESULT assign_ident(exec_ctx_t *ctx, BSTR name, VARIANT *val, BOOL own_v
 static HRESULT interp_assign_ident(exec_ctx_t *ctx)
 {
     const BSTR arg = ctx->instr->arg1.bstr;
+    const unsigned arg_cnt = ctx->instr->arg2.uint;
     variant_val_t v;
     HRESULT hres;
 
     TRACE("%s\n", debugstr_w(arg));
 
+    if(arg_cnt) {
+        FIXME("arguments not supported\n");
+        return E_NOTIMPL;
+    }
+
     hres = stack_pop_val(ctx, &v);
     if(FAILED(hres))
         return hres;
@@ -577,12 +611,18 @@ static HRESULT interp_assign_ident(exec_ctx_t *ctx)
 static HRESULT interp_set_ident(exec_ctx_t *ctx)
 {
     const BSTR arg = ctx->instr->arg1.bstr;
+    const unsigned arg_cnt = ctx->instr->arg2.uint;
     IDispatch *disp;
     VARIANT v;
     HRESULT hres;
 
     TRACE("%s\n", debugstr_w(arg));
 
+    if(arg_cnt) {
+        FIXME("arguments not supported\n");
+        return E_NOTIMPL;
+    }
+
     hres = stack_pop_disp(ctx, &disp);
     if(FAILED(hres))
         return hres;
@@ -595,6 +635,7 @@ static HRESULT interp_set_ident(exec_ctx_t *ctx)
 static HRESULT interp_assign_member(exec_ctx_t *ctx)
 {
     BSTR identifier = ctx->instr->arg1.bstr;
+    const unsigned arg_cnt = ctx->instr->arg2.uint;
     variant_val_t val;
     IDispatch *obj;
     DISPID id;
@@ -602,6 +643,11 @@ static HRESULT interp_assign_member(exec_ctx_t *ctx)
 
     TRACE("%s\n", debugstr_w(identifier));
 
+    if(arg_cnt) {
+        FIXME("arguments not supported\n");
+        return E_NOTIMPL;
+    }
+
     hres = stack_pop_disp(ctx, &obj);
     if(FAILED(hres))
         return hres;
@@ -629,12 +675,18 @@ static HRESULT interp_assign_member(exec_ctx_t *ctx)
 static HRESULT interp_set_member(exec_ctx_t *ctx)
 {
     BSTR identifier = ctx->instr->arg1.bstr;
+    const unsigned arg_cnt = ctx->instr->arg2.uint;
     IDispatch *obj, *val;
     DISPID id;
     HRESULT hres;
 
     TRACE("%s\n", debugstr_w(identifier));
 
+    if(arg_cnt) {
+        FIXME("arguments not supported\n");
+        return E_NOTIMPL;
+    }
+
     hres = stack_pop_disp(ctx, &obj);
     if(FAILED(hres))
         return hres;
@@ -803,22 +855,16 @@ static HRESULT interp_jmp(exec_ctx_t *ctx)
 static HRESULT interp_jmp_false(exec_ctx_t *ctx)
 {
     const unsigned arg = ctx->instr->arg1.uint;
-    variant_val_t val;
     HRESULT hres;
+    BOOL b;
 
     TRACE("%u\n", arg);
 
-    hres = stack_pop_val(ctx, &val);
+    hres = stack_pop_bool(ctx, &b);
     if(FAILED(hres))
         return hres;
 
-    if(V_VT(val.v) != VT_BOOL) {
-        FIXME("unsupported for %s\n", debugstr_variant(val.v));
-        release_val(&val);
-        return E_NOTIMPL;
-    }
-
-    if(V_BOOL(val.v))
+    if(b)
         ctx->instr++;
     else
         instr_jmp(ctx, ctx->instr->arg1.uint);
@@ -828,22 +874,16 @@ static HRESULT interp_jmp_false(exec_ctx_t *ctx)
 static HRESULT interp_jmp_true(exec_ctx_t *ctx)
 {
     const unsigned arg = ctx->instr->arg1.uint;
-    variant_val_t val;
     HRESULT hres;
+    BOOL b;
 
     TRACE("%u\n", arg);
 
-    hres = stack_pop_val(ctx, &val);
+    hres = stack_pop_bool(ctx, &b);
     if(FAILED(hres))
         return hres;
 
-    if(V_VT(val.v) != VT_BOOL) {
-        FIXME("unsupported for %s\n", debugstr_variant(val.v));
-        release_val(&val);
-        return E_NOTIMPL;
-    }
-
-    if(V_BOOL(val.v))
+    if(b)
         instr_jmp(ctx, ctx->instr->arg1.uint);
     else
         ctx->instr++;
