@@ -107,6 +107,7 @@ typedef enum {
     STAT_EXITFUNC,
     STAT_EXITPROP,
     STAT_EXITSUB,
+    STAT_FOREACH,
     STAT_FORTO,
     STAT_FUNC,
     STAT_IF,
@@ -207,6 +208,13 @@ typedef struct {
     statement_t *body;
 } forto_statement_t;
 
+typedef struct {
+    statement_t stat;
+    const WCHAR *identifier;
+    expression_t *group_expr;
+    statement_t *body;
+} foreach_statement_t;
+
 typedef struct {
     statement_t stat;
     BOOL resume_next;
