@@ -178,9 +178,9 @@ static void WINE_GLAPI wine_glFogi(GLenum pname, GLint param) {
         }
     } else {
         if(pname == GL_FOG_START) {
-            ctx->fogstart = param;
+            ctx->fogstart = (float) param;
         } else if(pname == GL_FOG_END) {
-            ctx->fogend = param;
+            ctx->fogend = (float) param;
         }
         old_fogcoord_glFogi(pname, param);
     }
@@ -199,9 +199,9 @@ static void WINE_GLAPI wine_glFogiv(GLenum pname, const GLint *param) {
         }
     } else {
         if(pname == GL_FOG_START) {
-            ctx->fogstart = *param;
+            ctx->fogstart = (float) *param;
         } else if(pname == GL_FOG_END) {
-            ctx->fogend = *param;
+            ctx->fogend = (float) *param;
         }
         old_fogcoord_glFogiv(pname, param);
     }
@@ -331,21 +331,21 @@ static void WINE_GLAPI wine_glFogCoordfEXT(GLfloat f) {
     ctx->fog_coord_value = f;
 }
 static void WINE_GLAPI wine_glFogCoorddEXT(GLdouble f) {
-    wine_glFogCoordfEXT(f);
+    wine_glFogCoordfEXT((GLfloat) f);
 }
 static void WINE_GLAPI wine_glFogCoordfvEXT(const GLfloat *f) {
     wine_glFogCoordfEXT(*f);
 }
 static void WINE_GLAPI wine_glFogCoorddvEXT(const GLdouble *f) {
-    wine_glFogCoordfEXT(*f);
+    wine_glFogCoordfEXT((GLfloat) *f);
 }
 
 /* End GL_EXT_fog_coord emulation */
 
-#define GLINFO_LOCATION (*gl_info)
 void add_gl_compat_wrappers(struct wined3d_gl_info *gl_info)
 {
-    if(!GL_SUPPORT(ARB_MULTITEXTURE)) {
+    if (!gl_info->supported[ARB_MULTITEXTURE])
+    {
         TRACE("Applying GL_ARB_multitexture emulation hooks\n");
         gl_info->glActiveTextureARB         = wine_glActiveTextureARB;
         gl_info->glClientActiveTextureARB   = wine_glClientActiveTextureARB;
@@ -380,7 +380,8 @@ void add_gl_compat_wrappers(struct wined3d_gl_info *gl_info)
         gl_info->supported[ARB_MULTITEXTURE] = TRUE;
     }
 
-    if(!GL_SUPPORT(EXT_FOG_COORD)) {
+    if (!gl_info->supported[EXT_FOG_COORD])
+    {
         /* This emulation isn't perfect. There are a number of potential problems, but they should
          * not matter in practise:
          *
@@ -390,7 +391,7 @@ void add_gl_compat_wrappers(struct wined3d_gl_info *gl_info)
          * too, which would allow fog coord emulation in a fixed function vertex pipeline replacement.
          *
          * Fog vs texture: We apply the fog in the vertex color. An app could set up texturing settings which
-         * ignore the vertex color, thus effectively disabing our fog. However, in D3D this type of fog is
+         * ignore the vertex color, thus effectively disabling our fog. However, in D3D this type of fog is
          * a per-vertex fog too, so the apps shouldn't do that.
          *
          * Fog vs lighting: The app could in theory use D3DFOG_NONE table and D3DFOG_NONE vertex fog with
@@ -405,10 +406,13 @@ void add_gl_compat_wrappers(struct wined3d_gl_info *gl_info)
          * it via the GL core version, or someone messed around in the extension table in directx.c. Add version-
          * dependent loading for this extension if we ever hit this situation
          */
-        if(GL_SUPPORT(ARB_FRAGMENT_PROGRAM)) {
+        if (gl_info->supported[ARB_FRAGMENT_PROGRAM])
+        {
             FIXME("GL implementation supports GL_ARB_fragment_program but not GL_EXT_fog_coord\n");
             FIXME("The fog coord emulation will most likely fail\n");
-        } else if(GL_SUPPORT(ARB_FRAGMENT_SHADER)) {
+        }
+        else if (gl_info->supported[ARB_FRAGMENT_SHADER])
+        {
             FIXME("GL implementation supports GL_ARB_fragment_shader but not GL_EXT_fog_coord\n");
             FIXME("The fog coord emulation will most likely fail\n");
         }
@@ -533,4 +537,3 @@ void add_gl_compat_wrappers(struct wined3d_gl_info *gl_info)
         gl_info->supported[EXT_FOG_COORD] = TRUE;
     }
 }
-#undef GLINFO_LOCATION
