@@ -41,20 +41,20 @@ struct private_data
     DWORD size;
 };
 
-static DWORD resource_access_from_pool(WINED3DPOOL pool)
+static DWORD resource_access_from_pool(enum wined3d_pool pool)
 {
     switch (pool)
     {
-        case WINED3DPOOL_DEFAULT:
+        case WINED3D_POOL_DEFAULT:
             return WINED3D_RESOURCE_ACCESS_GPU;
 
-        case WINED3DPOOL_MANAGED:
+        case WINED3D_POOL_MANAGED:
             return WINED3D_RESOURCE_ACCESS_GPU | WINED3D_RESOURCE_ACCESS_CPU;
 
-        case WINED3DPOOL_SYSTEMMEM:
+        case WINED3D_POOL_SYSTEM_MEM:
             return WINED3D_RESOURCE_ACCESS_CPU;
 
-        case WINED3DPOOL_SCRATCH:
+        case WINED3D_POOL_SCRATCH:
             return WINED3D_RESOURCE_ACCESS_SCRATCH;
 
         default:
@@ -77,15 +77,15 @@ static void resource_check_usage(DWORD usage)
 }
 
 HRESULT resource_init(struct wined3d_resource *resource, struct wined3d_device *device,
-        WINED3DRESOURCETYPE resource_type, const struct wined3d_format *format,
-        WINED3DMULTISAMPLE_TYPE multisample_type, UINT multisample_quality,
-        DWORD usage, WINED3DPOOL pool, UINT width, UINT height, UINT depth, UINT size,
+        enum wined3d_resource_type type, const struct wined3d_format *format,
+        enum wined3d_multisample_type multisample_type, UINT multisample_quality,
+        DWORD usage, enum wined3d_pool pool, UINT width, UINT height, UINT depth, UINT size,
         void *parent, const struct wined3d_parent_ops *parent_ops,
         const struct wined3d_resource_ops *resource_ops)
 {
     resource->ref = 1;
     resource->device = device;
-    resource->resourceType = resource_type;
+    resource->type = type;
     resource->format = format;
     resource->multisample_type = multisample_type;
     resource->multisample_quality = multisample_quality;
@@ -123,7 +123,7 @@ HRESULT resource_init(struct wined3d_resource *resource, struct wined3d_device *
             + (RESOURCE_ALIGNMENT - 1)) & ~(RESOURCE_ALIGNMENT - 1));
 
     /* Check that we have enough video ram left */
-    if (pool == WINED3DPOOL_DEFAULT)
+    if (pool == WINED3D_POOL_DEFAULT)
     {
         if (size > wined3d_device_get_available_texture_mem(device))
         {
@@ -131,7 +131,7 @@ HRESULT resource_init(struct wined3d_resource *resource, struct wined3d_device *
             HeapFree(GetProcessHeap(), 0, resource->heapMemory);
             return WINED3DERR_OUTOFVIDEOMEMORY;
         }
-        WineD3DAdapterChangeGLRam(device, size);
+        adapter_adjust_memory(device->adapter, size);
     }
 
     device_resource_add(device, resource);
@@ -147,10 +147,10 @@ void resource_cleanup(struct wined3d_resource *resource)
 
     TRACE("Cleaning up resource %p.\n", resource);
 
-    if (resource->pool == WINED3DPOOL_DEFAULT)
+    if (resource->pool == WINED3D_POOL_DEFAULT)
     {
         TRACE("Decrementing device memory pool by %u.\n", resource->size);
-        WineD3DAdapterChangeGLRam(resource->device,  0 - resource->size);
+        adapter_adjust_memory(resource->device->adapter, 0 - resource->size);
     }
 
     LIST_FOR_EACH_SAFE(e1, e2, &resource->privateData)
@@ -172,7 +172,7 @@ void resource_cleanup(struct wined3d_resource *resource)
 void resource_unload(struct wined3d_resource *resource)
 {
     context_resource_unloaded(resource->device,
-            resource, resource->resourceType);
+            resource, resource->type);
 }
 
 static struct private_data *resource_find_private_data(const struct wined3d_resource *resource, REFGUID tag)
@@ -318,7 +318,7 @@ void * CDECL wined3d_resource_get_parent(const struct wined3d_resource *resource
 
 void CDECL wined3d_resource_get_desc(const struct wined3d_resource *resource, struct wined3d_resource_desc *desc)
 {
-    desc->resource_type = resource->resourceType;
+    desc->resource_type = resource->type;
     desc->format = resource->format->id;
     desc->multisample_type = resource->multisample_type;
     desc->multisample_quality = resource->multisample_quality;
