@@ -146,23 +146,23 @@ static const char * const shader_opcode_names[] =
 
 static const char * const semantic_names[] =
 {
-    /* WINED3DDECLUSAGE_POSITION        */ "SV_POSITION",
-    /* WINED3DDECLUSAGE_BLENDWEIGHT     */ "BLENDWEIGHT",
-    /* WINED3DDECLUSAGE_BLENDINDICES    */ "BLENDINDICES",
-    /* WINED3DDECLUSAGE_NORMAL          */ "NORMAL",
-    /* WINED3DDECLUSAGE_PSIZE           */ "PSIZE",
-    /* WINED3DDECLUSAGE_TEXCOORD        */ "TEXCOORD",
-    /* WINED3DDECLUSAGE_TANGENT         */ "TANGENT",
-    /* WINED3DDECLUSAGE_BINORMAL        */ "BINORMAL",
-    /* WINED3DDECLUSAGE_TESSFACTOR      */ "TESSFACTOR",
-    /* WINED3DDECLUSAGE_POSITIONT       */ "POSITIONT",
-    /* WINED3DDECLUSAGE_COLOR           */ "COLOR",
-    /* WINED3DDECLUSAGE_FOG             */ "FOG",
-    /* WINED3DDECLUSAGE_DEPTH           */ "DEPTH",
-    /* WINED3DDECLUSAGE_SAMPLE          */ "SAMPLE",
+    /* WINED3D_DECL_USAGE_POSITION      */ "SV_POSITION",
+    /* WINED3D_DECL_USAGE_BLEND_WEIGHT  */ "BLENDWEIGHT",
+    /* WINED3D_DECL_USAGE_BLEND_INDICES */ "BLENDINDICES",
+    /* WINED3D_DECL_USAGE_NORMAL        */ "NORMAL",
+    /* WINED3D_DECL_USAGE_PSIZE         */ "PSIZE",
+    /* WINED3D_DECL_USAGE_TEXCOORD      */ "TEXCOORD",
+    /* WINED3D_DECL_USAGE_TANGENT       */ "TANGENT",
+    /* WINED3D_DECL_USAGE_BINORMAL      */ "BINORMAL",
+    /* WINED3D_DECL_USAGE_TESS_FACTOR   */ "TESSFACTOR",
+    /* WINED3D_DECL_USAGE_POSITIONT     */ "POSITIONT",
+    /* WINED3D_DECL_USAGE_COLOR         */ "COLOR",
+    /* WINED3D_DECL_USAGE_FOG           */ "FOG",
+    /* WINED3D_DECL_USAGE_DEPTH         */ "DEPTH",
+    /* WINED3D_DECL_USAGE_SAMPLE        */ "SAMPLE",
 };
 
-static const char *shader_semantic_name_from_usage(WINED3DDECLUSAGE usage)
+static const char *shader_semantic_name_from_usage(enum wined3d_decl_usage usage)
 {
     if (usage >= sizeof(semantic_names) / sizeof(*semantic_names))
     {
@@ -173,7 +173,7 @@ static const char *shader_semantic_name_from_usage(WINED3DDECLUSAGE usage)
     return semantic_names[usage];
 }
 
-static WINED3DDECLUSAGE shader_usage_from_semantic_name(const char *name)
+static enum wined3d_decl_usage shader_usage_from_semantic_name(const char *name)
 {
     unsigned int i;
 
@@ -185,7 +185,7 @@ static WINED3DDECLUSAGE shader_usage_from_semantic_name(const char *name)
     return ~0U;
 }
 
-BOOL shader_match_semantic(const char *semantic_name, WINED3DDECLUSAGE usage)
+BOOL shader_match_semantic(const char *semantic_name, enum wined3d_decl_usage usage)
 {
     return !strcmp(semantic_name, shader_semantic_name_from_usage(usage));
 }
@@ -202,7 +202,7 @@ static void shader_signature_from_semantic(struct wined3d_shader_signature_eleme
 }
 
 static void shader_signature_from_usage(struct wined3d_shader_signature_element *e,
-        WINED3DDECLUSAGE usage, UINT usage_idx, UINT reg_idx, DWORD write_mask)
+        enum wined3d_decl_usage usage, UINT usage_idx, UINT reg_idx, DWORD write_mask)
 {
     e->semantic_name = shader_semantic_name_from_usage(usage);
     e->semantic_idx = usage_idx;
@@ -518,7 +518,8 @@ static HRESULT shader_get_registers_used(struct wined3d_shader *shader, const st
                 case WINED3DSPR_OUTPUT:
                     reg_maps->output_registers |= 1 << semantic.reg.reg.idx;
                     shader_signature_from_semantic(&output_signature[semantic.reg.reg.idx], &semantic);
-                    if (semantic.usage == WINED3DDECLUSAGE_FOG) reg_maps->fog = 1;
+                    if (semantic.usage == WINED3D_DECL_USAGE_FOG)
+                        reg_maps->fog = 1;
                     break;
 
                 /* Save sampler usage token. */
@@ -639,19 +640,19 @@ static HRESULT shader_get_registers_used(struct wined3d_shader *shader, const st
                                 case 0: /* oPos */
                                     reg_maps->output_registers |= 1 << 10;
                                     shader_signature_from_usage(&output_signature[10],
-                                            WINED3DDECLUSAGE_POSITION, 0, 10, WINED3DSP_WRITEMASK_ALL);
+                                            WINED3D_DECL_USAGE_POSITION, 0, 10, WINED3DSP_WRITEMASK_ALL);
                                     break;
 
                                 case 1: /* oFog */
                                     reg_maps->output_registers |= 1 << 11;
                                     shader_signature_from_usage(&output_signature[11],
-                                            WINED3DDECLUSAGE_FOG, 0, 11, WINED3DSP_WRITEMASK_0);
+                                            WINED3D_DECL_USAGE_FOG, 0, 11, WINED3DSP_WRITEMASK_0);
                                     break;
 
                                 case 2: /* oPts */
                                     reg_maps->output_registers |= 1 << 11;
                                     shader_signature_from_usage(&output_signature[11],
-                                            WINED3DDECLUSAGE_PSIZE, 0, 11, WINED3DSP_WRITEMASK_1);
+                                            WINED3D_DECL_USAGE_PSIZE, 0, 11, WINED3DSP_WRITEMASK_1);
                                     break;
                             }
                             break;
@@ -668,7 +669,7 @@ static HRESULT shader_get_registers_used(struct wined3d_shader *shader, const st
                                 {
                                     reg_maps->output_registers |= 1 << idx;
                                     shader_signature_from_usage(&output_signature[idx],
-                                            WINED3DDECLUSAGE_COLOR, idx - 8, idx, dst_param.write_mask);
+                                            WINED3D_DECL_USAGE_COLOR, idx - 8, idx, dst_param.write_mask);
                                 }
                             }
                             break;
@@ -684,7 +685,7 @@ static HRESULT shader_get_registers_used(struct wined3d_shader *shader, const st
                             {
                                 reg_maps->output_registers |= 1 << idx;
                                 shader_signature_from_usage(&output_signature[idx],
-                                        WINED3DDECLUSAGE_TEXCOORD, idx, idx, dst_param.write_mask);
+                                        WINED3D_DECL_USAGE_TEXCOORD, idx, idx, dst_param.write_mask);
                             }
                             break;
 
@@ -852,60 +853,60 @@ static void shader_dump_decl_usage(const struct wined3d_shader_semantic *semanti
 
         switch (semantic->usage)
         {
-            case WINED3DDECLUSAGE_POSITION:
+            case WINED3D_DECL_USAGE_POSITION:
                 TRACE("position%u", semantic->usage_idx);
                 break;
 
-            case WINED3DDECLUSAGE_BLENDINDICES:
+            case WINED3D_DECL_USAGE_BLEND_INDICES:
                 TRACE("blend");
                 break;
 
-            case WINED3DDECLUSAGE_BLENDWEIGHT:
+            case WINED3D_DECL_USAGE_BLEND_WEIGHT:
                 TRACE("weight");
                 break;
 
-            case WINED3DDECLUSAGE_NORMAL:
+            case WINED3D_DECL_USAGE_NORMAL:
                 TRACE("normal%u", semantic->usage_idx);
                 break;
 
-            case WINED3DDECLUSAGE_PSIZE:
+            case WINED3D_DECL_USAGE_PSIZE:
                 TRACE("psize");
                 break;
 
-            case WINED3DDECLUSAGE_COLOR:
+            case WINED3D_DECL_USAGE_COLOR:
                 if (!semantic->usage_idx) TRACE("color");
                 else TRACE("specular%u", (semantic->usage_idx - 1));
                 break;
 
-            case WINED3DDECLUSAGE_TEXCOORD:
+            case WINED3D_DECL_USAGE_TEXCOORD:
                 TRACE("texture%u", semantic->usage_idx);
                 break;
 
-            case WINED3DDECLUSAGE_TANGENT:
+            case WINED3D_DECL_USAGE_TANGENT:
                 TRACE("tangent");
                 break;
 
-            case WINED3DDECLUSAGE_BINORMAL:
+            case WINED3D_DECL_USAGE_BINORMAL:
                 TRACE("binormal");
                 break;
 
-            case WINED3DDECLUSAGE_TESSFACTOR:
+            case WINED3D_DECL_USAGE_TESS_FACTOR:
                 TRACE("tessfactor");
                 break;
 
-            case WINED3DDECLUSAGE_POSITIONT:
+            case WINED3D_DECL_USAGE_POSITIONT:
                 TRACE("positionT%u", semantic->usage_idx);
                 break;
 
-            case WINED3DDECLUSAGE_FOG:
+            case WINED3D_DECL_USAGE_FOG:
                 TRACE("fog");
                 break;
 
-            case WINED3DDECLUSAGE_DEPTH:
+            case WINED3D_DECL_USAGE_DEPTH:
                 TRACE("depth");
                 break;
 
-            case WINED3DDECLUSAGE_SAMPLE:
+            case WINED3D_DECL_USAGE_SAMPLE:
                 TRACE("sample");
                 break;
 
@@ -1709,19 +1710,23 @@ HRESULT CDECL wined3d_shader_set_local_constants_float(struct wined3d_shader *sh
 void find_vs_compile_args(const struct wined3d_state *state,
         const struct wined3d_shader *shader, struct vs_compile_args *args)
 {
-    args->fog_src = state->render_states[WINED3DRS_FOGTABLEMODE]
-            == WINED3DFOG_NONE ? VS_FOG_COORD : VS_FOG_Z;
-    args->clip_enabled = state->render_states[WINED3DRS_CLIPPING]
-            && state->render_states[WINED3DRS_CLIPPLANEENABLE];
+    args->fog_src = state->render_states[WINED3D_RS_FOGTABLEMODE]
+            == WINED3D_FOG_NONE ? VS_FOG_COORD : VS_FOG_Z;
+    args->clip_enabled = state->render_states[WINED3D_RS_CLIPPING]
+            && state->render_states[WINED3D_RS_CLIPPLANEENABLE];
     args->swizzle_map = shader->device->strided_streams.swizzle_map;
 }
 
 static BOOL match_usage(BYTE usage1, BYTE usage_idx1, BYTE usage2, BYTE usage_idx2)
 {
-    if (usage_idx1 != usage_idx2) return FALSE;
-    if (usage1 == usage2) return TRUE;
-    if (usage1 == WINED3DDECLUSAGE_POSITION && usage2 == WINED3DDECLUSAGE_POSITIONT) return TRUE;
-    if (usage2 == WINED3DDECLUSAGE_POSITION && usage1 == WINED3DDECLUSAGE_POSITIONT) return TRUE;
+    if (usage_idx1 != usage_idx2)
+        return FALSE;
+    if (usage1 == usage2)
+        return TRUE;
+    if (usage1 == WINED3D_DECL_USAGE_POSITION && usage2 == WINED3D_DECL_USAGE_POSITIONT)
+        return TRUE;
+    if (usage2 == WINED3D_DECL_USAGE_POSITION && usage1 == WINED3D_DECL_USAGE_POSITIONT)
+        return TRUE;
 
     return FALSE;
 }
@@ -1899,7 +1904,7 @@ void find_ps_compile_args(const struct wined3d_state *state,
     UINT i;
 
     memset(args, 0, sizeof(*args)); /* FIXME: Make sure all bits are set. */
-    if (state->render_states[WINED3DRS_SRGBWRITEENABLE])
+    if (state->render_states[WINED3D_RS_SRGBWRITEENABLE])
     {
         const struct wined3d_surface *rt = state->fb->render_targets[0];
         if (rt->resource.format->flags & WINED3DFMT_FLAG_SRGB_WRITE) args->srgb_correction = 1;
@@ -1910,30 +1915,53 @@ void find_ps_compile_args(const struct wined3d_state *state,
     {
         for (i = 0; i < 4; ++i)
         {
-            DWORD flags = state->texture_states[i][WINED3DTSS_TEXTURETRANSFORMFLAGS];
-            DWORD count, tex_transform;
+            DWORD flags = state->texture_states[i][WINED3D_TSS_TEXTURE_TRANSFORM_FLAGS];
 
-            /* Filter some invalid flags */
-            count = flags & ~WINED3DTTFF_PROJECTED;
-            if (count > WINED3DTTFF_COUNT4)
+            if (flags & WINED3D_TTFF_PROJECTED)
             {
-                WARN("The application set an invalid TEXTURETRANSFORMFLAGS value.\n");
-                flags = count = 0;
-            }
+                DWORD tex_transform = flags & ~WINED3D_TTFF_PROJECTED;
 
-            tex_transform = count;
-            if (flags & WINED3DTTFF_PROJECTED)
-            {
-                enum wined3d_sampler_texture_type sampler_type = shader->reg_maps.sampler_type[i];
+                if (!state->vertex_shader)
+                {
+                    unsigned int j;
+                    unsigned int index = state->texture_states[i][WINED3D_TSS_TEXCOORD_INDEX];
+                    DWORD max_valid = WINED3D_TTFF_COUNT4;
+                    enum wined3d_sampler_texture_type sampler_type = shader->reg_maps.sampler_type[i];
 
-                if ((sampler_type == WINED3DSTT_1D && tex_transform > WINED3DTTFF_COUNT1)
-                        || (sampler_type == WINED3DSTT_2D && tex_transform > WINED3DTTFF_COUNT2)
-                        || (sampler_type == WINED3DSTT_VOLUME && tex_transform > WINED3DTTFF_COUNT3))
-                    tex_transform |= WINED3D_PSARGS_PROJECTED;
+                    for (j = 0; j < state->vertex_declaration->element_count; ++j)
+                    {
+                        struct wined3d_vertex_declaration_element *element =
+                                &state->vertex_declaration->elements[j];
+
+                        if (element->usage == WINED3D_DECL_USAGE_TEXCOORD
+                                && element->usage_idx == index)
+                        {
+                            max_valid = element->format->component_count;
+                            break;
+                        }
+                    }
+                    if (!tex_transform || tex_transform > max_valid)
+                    {
+                        WARN("Fixing up projected texture transform flags from %#x to %#x.\n",
+                                tex_transform, max_valid);
+                        tex_transform = max_valid;
+                    }
+                    if ((sampler_type == WINED3DSTT_1D && tex_transform > WINED3D_TTFF_COUNT1)
+                            || (sampler_type == WINED3DSTT_2D && tex_transform > WINED3D_TTFF_COUNT2)
+                            || (sampler_type == WINED3DSTT_VOLUME && tex_transform > WINED3D_TTFF_COUNT3))
+                        tex_transform |= WINED3D_PSARGS_PROJECTED;
+                    else
+                    {
+                        WARN("Application requested projected texture with unsuitable texture coordinates.\n");
+                        WARN("(texture unit %u, transform flags %#x, sampler type %u).\n",
+                                i, tex_transform, sampler_type);
+                    }
+                }
                 else
-                    WARN("Application requested projected texture with unsuitable texture coordinates.\n");
+                    tex_transform = WINED3D_TTFF_COUNT4 | WINED3D_PSARGS_PROJECTED;
+
+                args->tex_transform |= tex_transform << i * WINED3D_PSARGS_TEXTRANSFORM_SHIFT;
             }
-            args->tex_transform |= tex_transform << i * WINED3D_PSARGS_TEXTRANSFORM_SHIFT;
         }
     }
 
@@ -1976,29 +2004,29 @@ void find_ps_compile_args(const struct wined3d_state *state,
     else
     {
         args->vp_mode = vertexshader;
-        if (state->render_states[WINED3DRS_FOGENABLE])
+        if (state->render_states[WINED3D_RS_FOGENABLE])
         {
-            switch (state->render_states[WINED3DRS_FOGTABLEMODE])
+            switch (state->render_states[WINED3D_RS_FOGTABLEMODE])
             {
-                case WINED3DFOG_NONE:
+                case WINED3D_FOG_NONE:
                     if (device->strided_streams.position_transformed || use_vs(state))
                     {
                         args->fog = FOG_LINEAR;
                         break;
                     }
 
-                    switch (state->render_states[WINED3DRS_FOGVERTEXMODE])
+                    switch (state->render_states[WINED3D_RS_FOGVERTEXMODE])
                     {
-                        case WINED3DFOG_NONE: /* Fall through. */
-                        case WINED3DFOG_LINEAR: args->fog = FOG_LINEAR; break;
-                        case WINED3DFOG_EXP:    args->fog = FOG_EXP;    break;
-                        case WINED3DFOG_EXP2:   args->fog = FOG_EXP2;   break;
+                        case WINED3D_FOG_NONE: /* Fall through. */
+                        case WINED3D_FOG_LINEAR: args->fog = FOG_LINEAR; break;
+                        case WINED3D_FOG_EXP:    args->fog = FOG_EXP;    break;
+                        case WINED3D_FOG_EXP2:   args->fog = FOG_EXP2;   break;
                     }
                     break;
 
-                case WINED3DFOG_LINEAR: args->fog = FOG_LINEAR; break;
-                case WINED3DFOG_EXP:    args->fog = FOG_EXP;    break;
-                case WINED3DFOG_EXP2:   args->fog = FOG_EXP2;   break;
+                case WINED3D_FOG_LINEAR: args->fog = FOG_LINEAR; break;
+                case WINED3D_FOG_EXP:    args->fog = FOG_EXP;    break;
+                case WINED3D_FOG_EXP2:   args->fog = FOG_EXP2;   break;
             }
         }
         else
