@@ -163,15 +163,31 @@ typedef struct QTSplitter {
 
     DWORD outputSize;
     FILTER_STATE state;
+    CRITICAL_SECTION csReceive;
+
+    SourceSeeking sourceSeeking;
+    TimeValue movie_time;
+    TimeValue movie_start;
+    TimeScale movie_scale;
 } QTSplitter;
 
 static const IPinVtbl QT_OutputPin_Vtbl;
 static const IPinVtbl QT_InputPin_Vtbl;
 static const IBaseFilterVtbl QT_Vtbl;
+static const IMediaSeekingVtbl QT_Seeking_Vtbl;
 
 static HRESULT QT_AddPin(QTSplitter *This, const PIN_INFO *piOutput, const AM_MEDIA_TYPE *amt, BOOL video);
 static HRESULT QT_RemoveOutputPins(QTSplitter *This);
 
+static HRESULT WINAPI QTSplitter_ChangeStart(IMediaSeeking *iface);
+static HRESULT WINAPI QTSplitter_ChangeStop(IMediaSeeking *iface);
+static HRESULT WINAPI QTSplitter_ChangeRate(IMediaSeeking *iface);
+
+static inline QTSplitter *impl_from_IMediaSeeking( IMediaSeeking *iface )
+{
+    return (QTSplitter *)((char*)iface - FIELD_OFFSET(QTSplitter, sourceSeeking.lpVtbl));
+}
+
 /*
  * Base Filter
  */
@@ -233,9 +249,13 @@ IUnknown * CALLBACK QTSplitter_create(IUnknown *punkout, HRESULT *phr)
         *phr = E_OUTOFMEMORY;
         return NULL;
     }
+    ZeroMemory(This,sizeof(*This));
 
     BaseFilter_Init(&This->filter, &QT_Vtbl, &CLSID_QTSplitter, (DWORD_PTR)(__FILE__ ": QTSplitter.csFilter"), &BaseFuncTable);
 
+    InitializeCriticalSection(&This->csReceive);
+    This->csReceive.DebugInfo->Spare[0] = (DWORD_PTR)(__FILE__": QTSplitter.csReceive");
+
     This->pVideo_Pin = NULL;
     This->pAudio_Pin = NULL;
     This->state = State_Stopped;
@@ -250,7 +270,9 @@ IUnknown * CALLBACK QTSplitter_create(IUnknown *punkout, HRESULT *phr)
     This->pInputPin.pin.refCount = 1;
     This->pInputPin.pin.pConnectedTo = NULL;
     This->pInputPin.pin.pCritSec = &This->filter.csFilter;
-    ZeroMemory(&This->pInputPin.pin.mtCurrent, sizeof(AM_MEDIA_TYPE));
+
+    SourceSeeking_Init(&This->sourceSeeking, &QT_Seeking_Vtbl, QTSplitter_ChangeStop, QTSplitter_ChangeStart, QTSplitter_ChangeRate,  &This->filter.csFilter);
+
     *phr = S_OK;
     return obj;
 }
@@ -288,6 +310,10 @@ static void QT_Destroy(QTSplitter *This)
     CloseHandle(This->runEvent);
 
     ExitMovies();
+
+    This->csReceive.DebugInfo->Spare[0] = 0;
+    DeleteCriticalSection(&This->csReceive);
+
     CoTaskMemFree(This);
 }
 
@@ -306,6 +332,8 @@ static HRESULT WINAPI QT_QueryInterface(IBaseFilter *iface, REFIID riid, LPVOID
         *ppv = This;
     else if (IsEqualIID(riid, &IID_IBaseFilter))
         *ppv = This;
+    else if (IsEqualIID(riid, &IID_IMediaSeeking))
+        *ppv = &This->sourceSeeking;
 
     if (*ppv)
     {
@@ -338,8 +366,10 @@ static HRESULT WINAPI QT_Stop(IBaseFilter *iface)
 
     TRACE("()\n");
 
+    EnterCriticalSection(&This->csReceive);
     IAsyncReader_BeginFlush(This->pInputPin.pReader);
     IAsyncReader_EndFlush(This->pInputPin.pReader);
+    LeaveCriticalSection(&This->csReceive);
 
     return S_OK;
 }
@@ -441,7 +471,7 @@ static DWORD WINAPI QTSplitter_thread(LPVOID data)
 {
     QTSplitter *This = (QTSplitter *)data;
     HRESULT hr = S_OK;
-    TimeValue movie_time=0, next_time;
+    TimeValue next_time;
     CVPixelBufferRef pixelBuffer = NULL;
     OSStatus err;
     TimeRecord tr;
@@ -459,21 +489,26 @@ static DWORD WINAPI QTSplitter_thread(LPVOID data)
 
     WaitForSingleObject(This->runEvent, -1);
 
+    EnterCriticalSection(&This->csReceive);
     This->state = State_Running;
     /* Prime the pump:  Needed for MPEG streams */
-    GetMovieNextInterestingTime(This->pQTMovie, nextTimeEdgeOK | nextTimeStep, 0, NULL, movie_time, 1, &next_time, NULL);
+    GetMovieNextInterestingTime(This->pQTMovie, nextTimeEdgeOK | nextTimeStep, 0, NULL, This->movie_time, 1, &next_time, NULL);
 
     GetMovieTime(This->pQTMovie, &tr);
+    LeaveCriticalSection(&This->csReceive);
     do
     {
         LONGLONG tStart=0, tStop=0;
+        LONGLONG mStart=0, mStop=0;
         float time;
 
-        GetMovieNextInterestingTime(This->pQTMovie, nextTimeStep, 0, NULL, movie_time, 1, &next_time, NULL);
+        EnterCriticalSection(&This->csReceive);
+        GetMovieNextInterestingTime(This->pQTMovie, nextTimeStep, 0, NULL, This->movie_time, 1, &next_time, NULL);
 
         if (next_time == -1)
         {
             TRACE("No next time\n");
+            LeaveCriticalSection(&This->csReceive);
             break;
         }
 
@@ -482,12 +517,15 @@ static DWORD WINAPI QTSplitter_thread(LPVOID data)
         MoviesTask(This->pQTMovie,0);
         QTVisualContextTask(This->vContext);
 
-        TRACE("In loop at time %ld\n",movie_time);
+        TRACE("In loop at time %ld\n",This->movie_time);
         TRACE("In Next time %ld\n",next_time);
 
-        time = (float)movie_time / tr.scale;
+        mStart = This->movie_time;
+        mStop = next_time;
+
+        time = (float)(This->movie_time - This->movie_start) / This->movie_scale;
         tStart = time * 10000000;
-        time = (float)next_time / tr.scale;
+        time = (float)(next_time - This->movie_start) / This->movie_scale;
         tStop = time * 10000000;
 
         /* Deliver Audio */
@@ -519,8 +557,8 @@ static DWORD WINAPI QTSplitter_thread(LPVOID data)
                 goto audio_error;
             }
 
-            duration = (float)next_time / tr.scale;
-            time = (float)movie_time / tr.scale;
+            duration = (float)next_time / This->movie_scale;
+            time = (float)This->movie_time / This->movie_scale;
             duration -= time;
             frames = pvi->nSamplesPerSec * duration;
             TRACE("Need audio for %f seconds (%li frames)\n",duration,frames);
@@ -539,11 +577,8 @@ static DWORD WINAPI QTSplitter_thread(LPVOID data)
 
             IMediaSample_SetActualDataLength(sample, frames * pvi->nBlockAlign);
 
-            IMediaSample_SetMediaTime(sample, &tStart, &tStop);
-            if (tStart)
-                IMediaSample_SetTime(sample, &tStart, &tStop);
-            else
-                IMediaSample_SetTime(sample, NULL, NULL);
+            IMediaSample_SetMediaTime(sample, &mStart, &mStop);
+            IMediaSample_SetTime(sample, &tStart, &tStop);
 
             hr = OutputQueue_Receive(This->pAudio_Pin->queue, sample);
             TRACE("Audio Delivered (%x)\n",hr);
@@ -597,11 +632,8 @@ audio_error:
 
                 IMediaSample_SetActualDataLength(sample, This->outputSize);
 
-                IMediaSample_SetMediaTime(sample, &tStart, &tStop);
-                if (tStart)
-                    IMediaSample_SetTime(sample, &tStart, &tStop);
-                else
-                    IMediaSample_SetTime(sample, NULL, NULL);
+                IMediaSample_SetMediaTime(sample, &mStart, &mStop);
+                IMediaSample_SetTime(sample, &tStart, &tStop);
 
                 hr = OutputQueue_Receive(This->pVideo_Pin->queue, sample);
                 TRACE("Video Delivered (%x)\n",hr);
@@ -616,7 +648,8 @@ audio_error:
         else
             TRACE("No video to deliver\n");
 
-        movie_time = next_time;
+        This->movie_time = next_time;
+        LeaveCriticalSection(&This->csReceive);
     } while (hr == S_OK);
 
     This->state = State_Stopped;
@@ -636,7 +669,7 @@ static HRESULT WINAPI QT_Run(IBaseFilter *iface, REFERENCE_TIME tStart)
 
     TRACE("(%s)\n", wine_dbgstr_longlong(tStart));
 
-    EnterCriticalSection(&This->filter.csFilter);
+    EnterCriticalSection(&This->csReceive);
     This->filter.rtStreamStart = tStart;
 
     if (This->pVideo_Pin)
@@ -649,9 +682,9 @@ static HRESULT WINAPI QT_Run(IBaseFilter *iface, REFERENCE_TIME tStart)
         hr_any = hr;
 
     hr = hr_any;
-    LeaveCriticalSection(&This->filter.csFilter);
 
     SetEvent(This->runEvent);
+    LeaveCriticalSection(&This->csReceive);
 
     return hr;
 }
@@ -769,12 +802,13 @@ static HRESULT QT_Process_Video_Track(QTSplitter* filter, Track trk)
     pvi = (VIDEOINFOHEADER *)amt.pbFormat;
     pvi->bmiHeader.biSize = sizeof (BITMAPINFOHEADER);
     pvi->bmiHeader.biWidth = outputWidth;
-    pvi->bmiHeader.biHeight = -outputHeight;
+    pvi->bmiHeader.biHeight = outputHeight;
     pvi->bmiHeader.biPlanes = 1;
     pvi->bmiHeader.biBitCount = 24;
     pvi->bmiHeader.biCompression = BI_RGB;
+    pvi->bmiHeader.biSizeImage = outputWidth * outputHeight * outputDepth;
 
-    filter->outputSize = outputWidth * outputHeight * outputDepth;
+    filter->outputSize = pvi->bmiHeader.biSizeImage;
     amt.lSampleSize = 0;
 
     pixelBufferOptions = CFDictionaryCreateMutable(NULL, 0, &kCFTypeDictionaryKeyCallBacks, &kCFTypeDictionaryValueCallBacks);
@@ -892,6 +926,8 @@ static HRESULT QT_Process_Movie(QTSplitter* filter)
     Track trk;
     short id = 0;
     DWORD tid;
+    HANDLE thread;
+    LONGLONG time;
 
     TRACE("Trying movie connect\n");
 
@@ -930,8 +966,21 @@ static HRESULT QT_Process_Movie(QTSplitter* filter)
     if (trk)
         hr = QT_Process_Audio_Track(filter, trk);
 
-    CreateThread(NULL, 0, QTSplitter_thread, filter, 0, &tid);
-    TRACE("Created thread 0x%08x\n",tid);
+    time = GetMovieDuration(filter->pQTMovie);
+    filter->movie_scale = GetMovieTimeScale(filter->pQTMovie);
+    filter->sourceSeeking.llDuration = ((double)time / filter->movie_scale) * 10000000;
+    filter->sourceSeeking.llStop = filter->sourceSeeking.llDuration;
+
+    TRACE("Movie duration is %s\n",wine_dbgstr_longlong(filter->sourceSeeking.llDuration));
+
+    thread = CreateThread(NULL, 0, QTSplitter_thread, filter, 0, &tid);
+    if (thread)
+    {
+        TRACE("Created thread 0x%08x\n", tid);
+        CloseHandle(thread);
+    }
+    else
+        hr = HRESULT_FROM_WIN32(GetLastError());
 
     return hr;
 }
@@ -1106,9 +1155,7 @@ static HRESULT WINAPI QTInPin_QueryInterface(IPin * iface, REFIID riid, LPVOID *
     else if (IsEqualIID(riid, &IID_IPin))
         *ppv = iface;
     else if (IsEqualIID(riid, &IID_IMediaSeeking))
-    {
         return IBaseFilter_QueryInterface(This->pin.pinInfo.pFilter, &IID_IMediaSeeking, ppv);
-    }
 
     if (*ppv)
     {
@@ -1318,3 +1365,71 @@ static HRESULT QT_AddPin(QTSplitter *This, const PIN_INFO *piOutput, const AM_ME
         ERR("Failed with error %x\n", hr);
     return hr;
 }
+
+static HRESULT WINAPI QTSplitter_ChangeStart(IMediaSeeking *iface)
+{
+    QTSplitter *This = impl_from_IMediaSeeking(iface);
+    TRACE("(%p)\n", iface);
+    EnterCriticalSection(&This->csReceive);
+    This->movie_time = (This->sourceSeeking.llCurrent * This->movie_scale)/10000000;
+    This->movie_start = This->movie_time;
+    LeaveCriticalSection(&This->csReceive);
+    return S_OK;
+}
+
+static HRESULT WINAPI QTSplitter_ChangeStop(IMediaSeeking *iface)
+{
+    FIXME("(%p) filter hasn't implemented stop position change!\n", iface);
+    return S_OK;
+}
+
+static HRESULT WINAPI QTSplitter_ChangeRate(IMediaSeeking *iface)
+{
+    FIXME("(%p) filter hasn't implemented rate change!\n", iface);
+    return S_OK;
+}
+
+static HRESULT WINAPI QT_Seeking_QueryInterface(IMediaSeeking * iface, REFIID riid, LPVOID * ppv)
+{
+    QTSplitter *This = impl_from_IMediaSeeking(iface);
+
+    return IUnknown_QueryInterface((IUnknown *)This, riid, ppv);
+}
+
+static ULONG WINAPI QT_Seeking_AddRef(IMediaSeeking * iface)
+{
+    QTSplitter *This = impl_from_IMediaSeeking(iface);
+
+    return IUnknown_AddRef((IUnknown *)This);
+}
+
+static ULONG WINAPI QT_Seeking_Release(IMediaSeeking * iface)
+{
+    QTSplitter *This = impl_from_IMediaSeeking(iface);
+
+    return IUnknown_Release((IUnknown *)This);
+}
+
+static const IMediaSeekingVtbl QT_Seeking_Vtbl =
+{
+    QT_Seeking_QueryInterface,
+    QT_Seeking_AddRef,
+    QT_Seeking_Release,
+    SourceSeekingImpl_GetCapabilities,
+    SourceSeekingImpl_CheckCapabilities,
+    SourceSeekingImpl_IsFormatSupported,
+    SourceSeekingImpl_QueryPreferredFormat,
+    SourceSeekingImpl_GetTimeFormat,
+    SourceSeekingImpl_IsUsingTimeFormat,
+    SourceSeekingImpl_SetTimeFormat,
+    SourceSeekingImpl_GetDuration,
+    SourceSeekingImpl_GetStopPosition,
+    SourceSeekingImpl_GetCurrentPosition,
+    SourceSeekingImpl_ConvertTimeFormat,
+    SourceSeekingImpl_SetPositions,
+    SourceSeekingImpl_GetPositions,
+    SourceSeekingImpl_GetAvailable,
+    SourceSeekingImpl_SetRate,
+    SourceSeekingImpl_GetRate,
+    SourceSeekingImpl_GetPreroll
+};
