@@ -179,7 +179,7 @@ static void trackingCallback(
         return;
     }
 
-    EnterCriticalSection(&This->tf.filter.csFilter);
+    EnterCriticalSection(&This->tf.csReceive);
     hr = BaseOutputPinImpl_GetDeliveryBuffer((BaseOutputPin*)This->tf.ppPins[1], &pOutSample, NULL, NULL, 0);
     if (FAILED(hr)) {
         ERR("Unable to get delivery buffer (%x)\n", hr);
@@ -230,12 +230,14 @@ static void trackingCallback(
         IMediaSample_SetTime(pOutSample, &tStart, &tStop);
     }
 
-    LeaveCriticalSection(&This->tf.filter.csFilter);
+    LeaveCriticalSection(&This->tf.csReceive);
     hr = BaseOutputPinImpl_Deliver((BaseOutputPin*)This->tf.ppPins[1], pOutSample);
+    EnterCriticalSection(&This->tf.csReceive);
     if (hr != S_OK && hr != VFW_E_NOT_CONNECTED)
         ERR("Error sending sample (%x)\n", hr);
 
 error:
+    LeaveCriticalSection(&This->tf.csReceive);
     if (pOutSample)
         IMediaSample_Release(pOutSample);
 
@@ -278,7 +280,6 @@ static HRESULT WINAPI QTVDecoder_Receive(TransformFilter *tf, IMediaSample *pSam
     OSStatus err = noErr;
     LONGLONG tStart, tStop;
 
-    EnterCriticalSection(&This->tf.filter.csFilter);
     hr = IMediaSample_GetPointer(pSample, &pbSrcStream);
     if (FAILED(hr))
     {
@@ -316,7 +317,6 @@ static HRESULT WINAPI QTVDecoder_Receive(TransformFilter *tf, IMediaSample *pSam
     hr = This->decodeHR;
 
 error:
-    LeaveCriticalSection(&This->tf.filter.csFilter);
     return hr;
 }
 
@@ -442,8 +442,6 @@ static HRESULT WINAPI QTVDecoder_SetMediaType(TransformFilter *tf, PIN_DIRECTION
         bmi->biCompression =  BI_RGB;
         bmi->biBitCount =  24;
         outpmt->subtype = MEDIASUBTYPE_RGB24;
-        if (bmi->biHeight > 0)
-            bmi->biHeight = -bmi->biHeight;
 
         return S_OK;
     }
@@ -492,7 +490,7 @@ static HRESULT WINAPI QTVDecoder_DecideBufferSize(TransformFilter *tf, IMemAlloc
         ppropInputRequest->cbAlign = 1;
 
     if (ppropInputRequest->cbBuffer < This->outputSize)
-            ppropInputRequest->cbBuffer = This->outputSize;
+            ppropInputRequest->cbBuffer = This->outputSize + ppropInputRequest->cbAlign;
 
     if (!ppropInputRequest->cBuffers)
         ppropInputRequest->cBuffers = 1;
