@@ -161,13 +161,24 @@ RGNDATA *X11DRV_GetRegionData( HRGN hrgn, HDC hdc_lptodp )
     {
         int j;
         /* need to start from the end */
+        xrect += data->rdh.nCount;
         for (j = data->rdh.nCount-1; j >= 0; j--)
         {
             tmp = rect[j];
-            xrect[j].x      = max( min( tmp.left, SHRT_MAX), SHRT_MIN);
-            xrect[j].y      = max( min( tmp.top, SHRT_MAX), SHRT_MIN);
-            xrect[j].width  = max( min( tmp.right - xrect[j].x, USHRT_MAX), 0);
-            xrect[j].height = max( min( tmp.bottom - xrect[j].y, USHRT_MAX), 0);
+            if (tmp.left > SHRT_MAX) continue;
+            if (tmp.top > SHRT_MAX) continue;
+            if (tmp.right < SHRT_MIN) continue;
+            if (tmp.bottom < SHRT_MIN) continue;
+            xrect--;
+            xrect->x      = max( min( tmp.left, SHRT_MAX), SHRT_MIN);
+            xrect->y      = max( min( tmp.top, SHRT_MAX), SHRT_MIN);
+            xrect->width  = max( min( tmp.right, SHRT_MAX ) - xrect->x, 0);
+            xrect->height = max( min( tmp.bottom, SHRT_MAX ) - xrect->y, 0);
+        }
+        if (xrect > (XRectangle *)data->Buffer)
+        {
+            data->rdh.nCount -= xrect - (XRectangle *)data->Buffer;
+            memmove( (XRectangle *)data->Buffer, xrect, data->rdh.nCount * sizeof(*xrect) );
         }
     }
     else
@@ -175,11 +186,17 @@ RGNDATA *X11DRV_GetRegionData( HRGN hrgn, HDC hdc_lptodp )
         for (i = 0; i < data->rdh.nCount; i++)
         {
             tmp = rect[i];
-            xrect[i].x      = max( min( tmp.left, SHRT_MAX), SHRT_MIN);
-            xrect[i].y      = max( min( tmp.top, SHRT_MAX), SHRT_MIN);
-            xrect[i].width  = max( min( tmp.right - xrect[i].x, USHRT_MAX), 0);
-            xrect[i].height = max( min( tmp.bottom - xrect[i].y, USHRT_MAX), 0);
+            if (tmp.left > SHRT_MAX) continue;
+            if (tmp.top > SHRT_MAX) continue;
+            if (tmp.right < SHRT_MIN) continue;
+            if (tmp.bottom < SHRT_MIN) continue;
+            xrect->x      = max( min( tmp.left, SHRT_MAX), SHRT_MIN);
+            xrect->y      = max( min( tmp.top, SHRT_MAX), SHRT_MIN);
+            xrect->width  = max( min( tmp.right, SHRT_MAX ) - xrect->x, 0);
+            xrect->height = max( min( tmp.bottom, SHRT_MAX ) - xrect->y, 0);
+            xrect++;
         }
+        data->rdh.nCount = xrect - (XRectangle *)data->Buffer;
     }
     return data;
 }
@@ -274,13 +291,13 @@ BOOL X11DRV_SetupGCForPatBlt( X11DRV_PDEVICE *physDev, GC gc, BOOL fMapColors )
 	 * We need to swap foreground and background because
 	 * Windows does it the wrong way...
 	 */
-	val.foreground = physDev->backgroundPixel;
-	val.background = physDev->textPixel;
+	val.foreground = X11DRV_PALETTE_ToPhysical( physDev, GetBkColor(physDev->dev.hdc) );
+	val.background = X11DRV_PALETTE_ToPhysical( physDev, GetTextColor(physDev->dev.hdc) );
     }
     else
     {
 	val.foreground = physDev->brush.pixel;
-	val.background = physDev->backgroundPixel;
+	val.background = X11DRV_PALETTE_ToPhysical( physDev, GetBkColor(physDev->dev.hdc) );
     }
     if (fMapColors && X11DRV_PALETTE_XPixelToPalette)
     {
@@ -399,7 +416,7 @@ static BOOL X11DRV_SetupGCForPen( X11DRV_PDEVICE *physDev )
 	val.foreground = physDev->pen.pixel;
 	val.function   = X11DRV_XROPfunction[rop2-1];
     }
-    val.background = physDev->backgroundPixel;
+    val.background = X11DRV_PALETTE_ToPhysical( physDev, GetBkColor(physDev->dev.hdc) );
     val.fill_style = FillSolid;
     val.line_width = physDev->pen.width;
     if (val.line_width <= 1) {
@@ -463,8 +480,8 @@ BOOL X11DRV_SetupGCForText( X11DRV_PDEVICE *physDev )
 	XGCValues val;
 
 	val.function   = GXcopy;  /* Text is always GXcopy */
-	val.foreground = physDev->textPixel;
-	val.background = physDev->backgroundPixel;
+	val.foreground = X11DRV_PALETTE_ToPhysical( physDev, GetTextColor(physDev->dev.hdc) );
+	val.background = X11DRV_PALETTE_ToPhysical( physDev, GetBkColor(physDev->dev.hdc) );
 	val.fill_style = FillSolid;
 	val.font       = xfs->fid;
 
@@ -522,9 +539,6 @@ BOOL X11DRV_LineTo( PHYSDEV dev, INT x, INT y )
     POINT pt[2];
 
     if (X11DRV_SetupGCForPen( physDev )) {
-	/* Update the pixmap from the DIB section */
-	X11DRV_LockDIBSection(physDev, DIB_Status_GdiMod);
-
         GetCurrentPositionEx( dev->hdc, &pt[0] );
         pt[1].x = x;
         pt[1].y = y;
@@ -535,9 +549,6 @@ BOOL X11DRV_LineTo( PHYSDEV dev, INT x, INT y )
                   physDev->dc_rect.left + pt[0].x, physDev->dc_rect.top + pt[0].y,
                   physDev->dc_rect.left + pt[1].x, physDev->dc_rect.top + pt[1].y );
         wine_tsx11_unlock();
-
-	/* Update the DIBSection from the pixmap */
-	X11DRV_UnlockDIBSection(physDev, TRUE);
     }
     return TRUE;
 }
@@ -559,7 +570,6 @@ static BOOL X11DRV_DrawArc( PHYSDEV dev, INT left, INT top, INT right, INT botto
     INT width, oldwidth;
     double start_angle, end_angle;
     XPoint points[4];
-    BOOL update = FALSE;
     POINT start, end;
     RECT rc = get_device_rect( dev->hdc, left, top, right, bottom );
 
@@ -613,9 +623,6 @@ static BOOL X11DRV_DrawArc( PHYSDEV dev, INT left, INT top, INT right, INT botto
     idiff_angle  = (INT)((end_angle - start_angle) * 180 * 64 / PI + 0.5);
     if (idiff_angle <= 0) idiff_angle += 360 * 64;
 
-    /* Update the pixmap from the DIB section */
-    X11DRV_LockDIBSection(physDev, DIB_Status_GdiMod);
-
       /* Fill arc with brush if Chord() or Pie() */
 
     if ((lines > 0) && X11DRV_SetupGCForBrush( physDev )) {
@@ -625,7 +632,6 @@ static BOOL X11DRV_DrawArc( PHYSDEV dev, INT left, INT top, INT right, INT botto
                   physDev->dc_rect.left + rc.left, physDev->dc_rect.top + rc.top,
                   rc.right-rc.left-1, rc.bottom-rc.top-1, istart_angle, idiff_angle );
         wine_tsx11_unlock();
-	update = TRUE;
     }
 
       /* Draw arc and lines */
@@ -693,12 +699,8 @@ static BOOL X11DRV_DrawArc( PHYSDEV dev, INT left, INT top, INT right, INT botto
                         points, lines+1, CoordModeOrigin );
         }
         wine_tsx11_unlock();
-	update = TRUE;
     }
 
-    /* Update the DIBSection of the pixmap */
-    X11DRV_UnlockDIBSection(physDev, update);
-
     physDev->pen.width = oldwidth;
     return TRUE;
 }
@@ -740,7 +742,6 @@ BOOL X11DRV_Ellipse( PHYSDEV dev, INT left, INT top, INT right, INT bottom )
 {
     X11DRV_PDEVICE *physDev = get_x11drv_dev( dev );
     INT width, oldwidth;
-    BOOL update = FALSE;
     RECT rc = get_device_rect( dev->hdc, left, top, right, bottom );
 
     if ((rc.left == rc.right) || (rc.top == rc.bottom)) return TRUE;
@@ -761,9 +762,6 @@ BOOL X11DRV_Ellipse( PHYSDEV dev, INT left, INT top, INT right, INT bottom )
     if(width == 0) width = 1; /* more accurate */
     physDev->pen.width = width;
 
-    /* Update the pixmap from the DIB section */
-    X11DRV_LockDIBSection(physDev, DIB_Status_GdiMod);
-
     if (X11DRV_SetupGCForBrush( physDev ))
     {
         wine_tsx11_lock();
@@ -771,7 +769,6 @@ BOOL X11DRV_Ellipse( PHYSDEV dev, INT left, INT top, INT right, INT bottom )
                   physDev->dc_rect.left + rc.left, physDev->dc_rect.top + rc.top,
                   rc.right-rc.left-1, rc.bottom-rc.top-1, 0, 360*64 );
         wine_tsx11_unlock();
-	update = TRUE;
     }
     if (X11DRV_SetupGCForPen( physDev ))
     {
@@ -780,12 +777,8 @@ BOOL X11DRV_Ellipse( PHYSDEV dev, INT left, INT top, INT right, INT bottom )
                   physDev->dc_rect.left + rc.left, physDev->dc_rect.top + rc.top,
                   rc.right-rc.left-1, rc.bottom-rc.top-1, 0, 360*64 );
         wine_tsx11_unlock();
-	update = TRUE;
     }
 
-    /* Update the DIBSection from the pixmap */
-    X11DRV_UnlockDIBSection(physDev, update);
-
     physDev->pen.width = oldwidth;
     return TRUE;
 }
@@ -798,7 +791,6 @@ BOOL X11DRV_Rectangle(PHYSDEV dev, INT left, INT top, INT right, INT bottom)
 {
     X11DRV_PDEVICE *physDev = get_x11drv_dev( dev );
     INT width, oldwidth, oldjoinstyle;
-    BOOL update = FALSE;
     RECT rc = get_device_rect( dev->hdc, left, top, right, bottom );
 
     TRACE("(%d %d %d %d)\n", left, top, right, bottom);
@@ -824,9 +816,6 @@ BOOL X11DRV_Rectangle(PHYSDEV dev, INT left, INT top, INT right, INT bottom)
     if(physDev->pen.type != PS_GEOMETRIC)
         physDev->pen.linejoin = PS_JOIN_MITER;
 
-    /* Update the pixmap from the DIB section */
-    X11DRV_LockDIBSection(physDev, DIB_Status_GdiMod);
-
     if ((rc.right > rc.left + width) && (rc.bottom > rc.top + width))
     {
         if (X11DRV_SetupGCForBrush( physDev ))
@@ -837,7 +826,6 @@ BOOL X11DRV_Rectangle(PHYSDEV dev, INT left, INT top, INT right, INT bottom)
                             physDev->dc_rect.top + rc.top + (width + 1) / 2,
                             rc.right-rc.left-width-1, rc.bottom-rc.top-width-1);
             wine_tsx11_unlock();
-	    update = TRUE;
 	}
     }
     if (X11DRV_SetupGCForPen( physDev ))
@@ -847,12 +835,8 @@ BOOL X11DRV_Rectangle(PHYSDEV dev, INT left, INT top, INT right, INT bottom)
                         physDev->dc_rect.left + rc.left, physDev->dc_rect.top + rc.top,
                         rc.right-rc.left-1, rc.bottom-rc.top-1 );
         wine_tsx11_unlock();
-	update = TRUE;
     }
 
-    /* Update the DIBSection from the pixmap */
-    X11DRV_UnlockDIBSection(physDev, update);
-
     physDev->pen.width = oldwidth;
     physDev->pen.linejoin = oldjoinstyle;
     return TRUE;
@@ -866,7 +850,6 @@ BOOL X11DRV_RoundRect( PHYSDEV dev, INT left, INT top, INT right, INT bottom,
 {
     X11DRV_PDEVICE *physDev = get_x11drv_dev( dev );
     INT width, oldwidth, oldendcap;
-    BOOL update = FALSE;
     POINT pts[2];
     RECT rc = get_device_rect( dev->hdc, left, top, right, bottom );
 
@@ -903,9 +886,6 @@ BOOL X11DRV_RoundRect( PHYSDEV dev, INT left, INT top, INT right, INT bottom,
     physDev->pen.width = width;
     physDev->pen.endcap = PS_ENDCAP_SQUARE;
 
-    /* Update the pixmap from the DIB section */
-    X11DRV_LockDIBSection(physDev, DIB_Status_GdiMod);
-
     if (X11DRV_SetupGCForBrush( physDev ))
     {
         wine_tsx11_lock();
@@ -971,7 +951,6 @@ BOOL X11DRV_RoundRect( PHYSDEV dev, INT left, INT top, INT right, INT bottom,
                             rc.bottom - rc.top - ell_height - 1);
         }
         wine_tsx11_unlock();
-	update = TRUE;
     }
     /* FIXME: this could be done with on X call
      * more efficient and probably more correct
@@ -1049,10 +1028,7 @@ BOOL X11DRV_RoundRect( PHYSDEV dev, INT left, INT top, INT right, INT bottom,
                        physDev->dc_rect.top + rc.bottom - (ell_height+1) / 2);
 	}
         wine_tsx11_unlock();
-	update = TRUE;
     }
-    /* Update the DIBSection from the pixmap */
-    X11DRV_UnlockDIBSection(physDev, update);
 
     physDev->pen.width = oldwidth;
     physDev->pen.endcap = oldendcap;
@@ -1074,10 +1050,6 @@ COLORREF X11DRV_SetPixel( PHYSDEV dev, INT x, INT y, COLORREF color )
     LPtoDP( dev->hdc, &pt, 1 );
     pixel = X11DRV_PALETTE_ToPhysical( physDev, color );
 
-    /* Update the pixmap from the DIB section */
-    X11DRV_LockDIBSection(physDev, DIB_Status_GdiMod);
-
-    /* inefficient but simple... */
     wine_tsx11_lock();
     XSetForeground( gdi_display, physDev->gc, pixel );
     XSetFunction( gdi_display, physDev->gc, GXcopy );
@@ -1085,9 +1057,6 @@ COLORREF X11DRV_SetPixel( PHYSDEV dev, INT x, INT y, COLORREF color )
                 physDev->dc_rect.left + pt.x, physDev->dc_rect.top + pt.y );
     wine_tsx11_unlock();
 
-    /* Update the DIBSection from the pixmap */
-    X11DRV_UnlockDIBSection(physDev, TRUE);
-
     return X11DRV_PALETTE_ToLogical(physDev, pixel);
 }
 
@@ -1113,11 +1082,9 @@ BOOL X11DRV_PaintRgn( PHYSDEV dev, HRGN hrgn )
             rect[i].y += physDev->dc_rect.top;
         }
 
-        X11DRV_LockDIBSection(physDev, DIB_Status_GdiMod);
         wine_tsx11_lock();
         XFillRectangles( gdi_display, physDev->drawable, physDev->gc, rect, data->rdh.nCount );
         wine_tsx11_unlock();
-        X11DRV_UnlockDIBSection(physDev, TRUE);
         HeapFree( GetProcessHeap(), 0, data );
     }
     return TRUE;
@@ -1147,12 +1114,10 @@ BOOL X11DRV_Polyline( PHYSDEV dev, const POINT* pt, INT count )
 
     if (X11DRV_SetupGCForPen ( physDev ))
     {
-        X11DRV_LockDIBSection(physDev, DIB_Status_GdiMod);
         wine_tsx11_lock();
         XDrawLines( gdi_display, physDev->drawable, physDev->gc,
                     points, count, CoordModeOrigin );
         wine_tsx11_unlock();
-        X11DRV_UnlockDIBSection(physDev, TRUE);
     }
 
     HeapFree( GetProcessHeap(), 0, points );
@@ -1168,7 +1133,6 @@ BOOL X11DRV_Polygon( PHYSDEV dev, const POINT* pt, INT count )
     X11DRV_PDEVICE *physDev = get_x11drv_dev( dev );
     int i;
     XPoint *points;
-    BOOL update = FALSE;
 
     if (!(points = HeapAlloc( GetProcessHeap(), 0, sizeof(XPoint) * (count+1) )))
     {
@@ -1184,16 +1148,12 @@ BOOL X11DRV_Polygon( PHYSDEV dev, const POINT* pt, INT count )
     }
     points[count] = points[0];
 
-    /* Update the pixmap from the DIB section */
-    X11DRV_LockDIBSection(physDev, DIB_Status_GdiMod);
-
     if (X11DRV_SetupGCForBrush( physDev ))
     {
         wine_tsx11_lock();
         XFillPolygon( gdi_display, physDev->drawable, physDev->gc,
                       points, count+1, Complex, CoordModeOrigin);
         wine_tsx11_unlock();
-	update = TRUE;
     }
     if (X11DRV_SetupGCForPen ( physDev ))
     {
@@ -1201,12 +1161,8 @@ BOOL X11DRV_Polygon( PHYSDEV dev, const POINT* pt, INT count )
         XDrawLines( gdi_display, physDev->drawable, physDev->gc,
                     points, count+1, CoordModeOrigin );
         wine_tsx11_unlock();
-	update = TRUE;
     }
 
-    /* Update the DIBSection from the pixmap */
-    X11DRV_UnlockDIBSection(physDev, update);
-
     HeapFree( GetProcessHeap(), 0, points );
     return TRUE;
 }
@@ -1235,9 +1191,6 @@ BOOL X11DRV_PolyPolygon( PHYSDEV dev, const POINT* pt, const INT* counts, UINT p
 	int j, max = 0;
 	XPoint *points;
 
-	/* Update the pixmap from the DIB section */
-	X11DRV_LockDIBSection(physDev, DIB_Status_GdiMod);
-
 	for (i = 0; i < polygons; i++) if (counts[i] > max) max = counts[i];
         if (!(points = HeapAlloc( GetProcessHeap(), 0, sizeof(XPoint) * (max+1) )))
         {
@@ -1260,10 +1213,6 @@ BOOL X11DRV_PolyPolygon( PHYSDEV dev, const POINT* pt, const INT* counts, UINT p
                         points, j + 1, CoordModeOrigin );
             wine_tsx11_unlock();
 	}
-
-	/* Update the DIBSection of the dc's bitmap */
-	X11DRV_UnlockDIBSection(physDev, TRUE);
-
 	HeapFree( GetProcessHeap(), 0, points );
     }
     return TRUE;
@@ -1282,9 +1231,6 @@ BOOL X11DRV_PolyPolyline( PHYSDEV dev, const POINT* pt, const DWORD* counts, DWO
         unsigned int i, j, max = 0;
         XPoint *points;
 
-	/* Update the pixmap from the DIB section */
-	X11DRV_LockDIBSection(physDev, DIB_Status_GdiMod);
-
         for (i = 0; i < polylines; i++) if (counts[i] > max) max = counts[i];
         if (!(points = HeapAlloc( GetProcessHeap(), 0, sizeof(XPoint) * max )))
         {
@@ -1306,10 +1252,6 @@ BOOL X11DRV_PolyPolyline( PHYSDEV dev, const POINT* pt, const DWORD* counts, DWO
                         points, j, CoordModeOrigin );
             wine_tsx11_unlock();
         }
-
-	/* Update the DIBSection of the dc's bitmap */
-    	X11DRV_UnlockDIBSection(physDev, TRUE);
-
 	HeapFree( GetProcessHeap(), 0, points );
     }
     return TRUE;
@@ -1436,12 +1378,7 @@ BOOL X11DRV_ExtFloodFill( PHYSDEV dev, INT x, INT y, COLORREF color, UINT fillTy
     {
         unsigned long pixel = X11DRV_PALETTE_ToPhysical( physDev, color );
 
-	/* Update the pixmap from the DIB section */
-	X11DRV_LockDIBSection(physDev, DIB_Status_GdiMod);
-
-          /* ROP mode is always GXcopy for flood-fill */
         wine_tsx11_lock();
-        XSetFunction( gdi_display, physDev->gc, GXcopy );
         X11DRV_InternalFloodFill(image, physDev,
                                  pt.x - rect.left,
                                  pt.y - rect.top,
@@ -1449,8 +1386,6 @@ BOOL X11DRV_ExtFloodFill( PHYSDEV dev, INT x, INT y, COLORREF color, UINT fillTy
                                  physDev->dc_rect.top + rect.top,
                                  pixel, fillType );
         wine_tsx11_unlock();
-        /* Update the DIBSection of the dc's bitmap */
-        X11DRV_UnlockDIBSection(physDev, TRUE);
     }
 
     wine_tsx11_lock();
@@ -1488,7 +1423,6 @@ BOOL X11DRV_GradientFill( PHYSDEV dev, TRIVERTEX *vert_array, ULONG nvert,
                    GCFunction | GCLineWidth | GCLineStyle | GCCapStyle | GCFillStyle, &val );
         wine_tsx11_unlock();
 
-	X11DRV_LockDIBSection( physdev, DIB_Status_GdiMod );
         for (i = 0; i < ngrad; i++, rect++)
         {
             int pos, x, dx;
@@ -1510,18 +1444,19 @@ BOOL X11DRV_GradientFill( PHYSDEV dev, TRIVERTEX *vert_array, ULONG nvert,
             }
             for (x = 0, pos = min( pt[0].x, pt[1].x ); x < dx; x++, pos++)
             {
-                COLORREF color = RGB( (v[0].Red   * (dx - x) + v[1].Red   * x) / dx / 256,
+                int color = X11DRV_PALETTE_ToPhysical( physdev,
+                                 RGB( (v[0].Red   * (dx - x) + v[1].Red   * x) / dx / 256,
                                       (v[0].Green * (dx - x) + v[1].Green * x) / dx / 256,
-                                      (v[0].Blue  * (dx - x) + v[1].Blue  * x) / dx / 256);
+                                      (v[0].Blue  * (dx - x) + v[1].Blue  * x) / dx / 256) );
+
                 wine_tsx11_lock();
-                XSetForeground( gdi_display, physdev->gc, X11DRV_PALETTE_ToPhysical( physdev, color ));
+                XSetForeground( gdi_display, physdev->gc, color );
                 XDrawLine( gdi_display, physdev->drawable, physdev->gc,
                            physdev->dc_rect.left + pos, physdev->dc_rect.top + pt[0].y,
                            physdev->dc_rect.left + pos, physdev->dc_rect.top + pt[1].y );
                 wine_tsx11_unlock();
             }
         }
-        X11DRV_UnlockDIBSection( physdev, TRUE );
         return TRUE;
 
     case GRADIENT_FILL_RECT_V:
@@ -1535,7 +1470,6 @@ BOOL X11DRV_GradientFill( PHYSDEV dev, TRIVERTEX *vert_array, ULONG nvert,
                    GCFunction | GCLineWidth | GCLineStyle | GCCapStyle | GCFillStyle, &val );
         wine_tsx11_unlock();
 
-	X11DRV_LockDIBSection( physdev, DIB_Status_GdiMod );
         for (i = 0; i < ngrad; i++, rect++)
         {
             int pos, y, dy;
@@ -1557,18 +1491,19 @@ BOOL X11DRV_GradientFill( PHYSDEV dev, TRIVERTEX *vert_array, ULONG nvert,
             }
             for (y = 0, pos = min( pt[0].y, pt[1].y ); y < dy; y++, pos++)
             {
-                COLORREF color = RGB( (v[0].Red   * (dy - y) + v[1].Red   * y) / dy / 256,
+                int color = X11DRV_PALETTE_ToPhysical( physdev,
+                                 RGB( (v[0].Red   * (dy - y) + v[1].Red   * y) / dy / 256,
                                       (v[0].Green * (dy - y) + v[1].Green * y) / dy / 256,
-                                      (v[0].Blue  * (dy - y) + v[1].Blue  * y) / dy / 256);
+                                      (v[0].Blue  * (dy - y) + v[1].Blue  * y) / dy / 256) );
+
                 wine_tsx11_lock();
-                XSetForeground( gdi_display, physdev->gc, X11DRV_PALETTE_ToPhysical( physdev, color ));
+                XSetForeground( gdi_display, physdev->gc, color );
                 XDrawLine( gdi_display, physdev->drawable, physdev->gc,
                            physdev->dc_rect.left + pt[0].x, physdev->dc_rect.top + pos,
                            physdev->dc_rect.left + pt[1].x, physdev->dc_rect.top + pos );
                 wine_tsx11_unlock();
             }
         }
-        X11DRV_UnlockDIBSection( physdev, TRUE );
         return TRUE;
     }
 
@@ -1577,29 +1512,6 @@ fallback:
     return dev->funcs->pGradientFill( dev, vert_array, nvert, grad_array, ngrad, mode );
 }
 
-/**********************************************************************
- *          X11DRV_SetBkColor
- */
-COLORREF X11DRV_SetBkColor( PHYSDEV dev, COLORREF color )
-{
-    X11DRV_PDEVICE *physDev = get_x11drv_dev( dev );
-
-    physDev->backgroundPixel = X11DRV_PALETTE_ToPhysical( physDev, color );
-    return color;
-}
-
-/**********************************************************************
- *          X11DRV_SetTextColor
- */
-COLORREF X11DRV_SetTextColor( PHYSDEV dev, COLORREF color )
-{
-    X11DRV_PDEVICE *physDev = get_x11drv_dev( dev );
-
-    physDev->textPixel = X11DRV_PALETTE_ToPhysical( physDev, color );
-    return color;
-}
-
-
 static unsigned char *get_icm_profile( unsigned long *size )
 {
     Atom type;
