@@ -429,6 +429,7 @@ static INT X11DRV_ExtEscape( PHYSDEV dev, INT escape, INT in_count, LPCVOID in_d
                 break;
             case X11DRV_GET_DCE:
             case X11DRV_SET_DCE:
+            case X11DRV_SYNC_PIXMAP:
                 FIXME( "%x escape no longer supported\n", *(const enum x11drv_escape_codes *)in_data );
                 break;
             case X11DRV_GET_GLX_DRAWABLE:
@@ -438,13 +439,6 @@ static INT X11DRV_ExtEscape( PHYSDEV dev, INT escape, INT in_count, LPCVOID in_d
                     return TRUE;
                 }
                 break;
-            case X11DRV_SYNC_PIXMAP:
-                if(physDev->bitmap)
-                {
-                    X11DRV_CoerceDIBSection(physDev, DIB_Status_GdiMod);
-                    return TRUE;
-                }
-                return FALSE;
             case X11DRV_FLUSH_GL_DRAWABLE:
                 flush_gl_drawable(physDev);
                 return TRUE;
@@ -473,7 +467,6 @@ static const struct gdi_dc_funcs x11drv_funcs =
     X11DRV_CreateBitmap,                /* pCreateBitmap */
     X11DRV_CreateCompatibleDC,          /* pCreateCompatibleDC */
     X11DRV_CreateDC,                    /* pCreateDC */
-    X11DRV_CreateDIBSection,            /* pCreateDIBSection */
     X11DRV_DeleteBitmap,                /* pDeleteBitmap */
     X11DRV_DeleteDC,                    /* pDeleteDC */
     NULL,                               /* pDeleteObject */
@@ -557,11 +550,10 @@ static const struct gdi_dc_funcs x11drv_funcs =
     NULL,                               /* pSelectPalette */
     X11DRV_SelectPen,                   /* pSelectPen */
     NULL,                               /* pSetArcDirection */
-    X11DRV_SetBkColor,                  /* pSetBkColor */
+    NULL,                               /* pSetBkColor */
     NULL,                               /* pSetBkMode */
     X11DRV_SetDCBrushColor,             /* pSetDCBrushColor */
     X11DRV_SetDCPenColor,               /* pSetDCPenColor */
-    X11DRV_SetDIBColorTable,            /* pSetDIBColorTable */
     NULL,                               /* pSetDIBitsToDevice */
     X11DRV_SetDeviceClipping,           /* pSetDeviceClipping */
     X11DRV_SetDeviceGammaRamp,          /* pSetDeviceGammaRamp */
@@ -576,7 +568,7 @@ static const struct gdi_dc_funcs x11drv_funcs =
     NULL,                               /* pSetStretchBltMode */
     NULL,                               /* pSetTextAlign */
     NULL,                               /* pSetTextCharacterExtra */
-    X11DRV_SetTextColor,                /* pSetTextColor */
+    NULL,                               /* pSetTextColor */
     NULL,                               /* pSetTextJustification */
     NULL,                               /* pSetViewportExt */
     NULL,                               /* pSetViewportOrg */
