@@ -31,7 +31,6 @@
 #include "windef.h"
 #include "winreg.h"
 #include "wingdi.h"
-#include "ddrawi.h"
 #include "wine/debug.h"
 
 WINE_DEFAULT_DEBUG_CHANNEL(x11settings);
@@ -150,7 +149,8 @@ static int X11DRV_nores_GetCurrentMode(void)
 
 static LONG X11DRV_nores_SetCurrentMode(int mode)
 {
-    TRACE("Ignoring mode change request\n");
+    if (mode == 0) return DISP_CHANGE_SUCCESSFUL;
+    TRACE("Ignoring mode change request mode=%d\n", mode);
     return DISP_CHANGE_FAILED;
 }
 
@@ -243,7 +243,7 @@ static BOOL write_registry_settings(const DEVMODEW *dm)
         return FALSE;
 
 #define set_value(name, data) \
-    if (RegSetValueExA(hkey, name, 0, REG_DWORD, (LPBYTE)(data), sizeof(DWORD))) \
+    if (RegSetValueExA(hkey, name, 0, REG_DWORD, (const BYTE*)(data), sizeof(DWORD))) \
         ret = FALSE
 
     set_value("DefaultSettings.BitsPerPel", &dm->dmBitsPerPel);
@@ -438,39 +438,3 @@ LONG CDECL X11DRV_ChangeDisplaySettingsEx( LPCWSTR devname, LPDEVMODEW devmode,
         devmode->dmBitsPerPel, devmode->dmDisplayFrequency, handler_name);
     return DISP_CHANGE_BADMODE;
 }
-
-
-
-
-/***********************************************************************
- * DirectDraw HAL interface
- *
- */
-static DWORD PASCAL X11DRV_Settings_SetMode(LPDDHAL_SETMODEDATA data)
-{
-    TRACE("Mode %d requested by DDHAL (%s)\n", data->dwModeIndex, handler_name);
-    switch (pSetCurrentMode(data->dwModeIndex))
-    {
-    case DISP_CHANGE_SUCCESSFUL:
-        X11DRV_DDHAL_SwitchMode(data->dwModeIndex, NULL, NULL);
-        data->ddRVal = DD_OK;
-        break;
-    case DISP_CHANGE_BADMODE:
-        data->ddRVal = DDERR_WRONGMODE;
-        break;
-    default:
-        data->ddRVal = DDERR_UNSUPPORTEDMODE;
-    }
-    return DDHAL_DRIVER_HANDLED;
-}
-int X11DRV_Settings_CreateDriver(LPDDHALINFO info)
-{
-    if (!dd_mode_count) return 0; /* no settings defined */
-
-    TRACE("Setting up display settings for DDRAW (%s)\n", handler_name);
-    info->dwNumModes = dd_mode_count;
-    info->lpModeInfo = dd_modes;
-    X11DRV_DDHAL_SwitchMode(pGetCurrentMode(), NULL, NULL);
-    info->lpDDCallbacks->SetMode = X11DRV_Settings_SetMode;
-    return TRUE;
-}
