@@ -159,12 +159,15 @@ struct has_popup_result
     BOOL found;
 };
 
-static BOOL CALLBACK has_popup( HWND hwnd, LPARAM lparam )
+static BOOL CALLBACK has_managed_popup( HWND hwnd, LPARAM lparam )
 {
     struct has_popup_result *result = (struct has_popup_result *)lparam;
+    struct x11drv_win_data *data;
 
     if (hwnd == result->hwnd) return FALSE;  /* popups are always above owner */
-    result->found = (GetWindow( hwnd, GW_OWNER ) == result->hwnd);
+    if (!(data = X11DRV_get_win_data( hwnd ))) return TRUE;
+    if (GetWindow( hwnd, GW_OWNER ) != result->hwnd) return TRUE;
+    result->found = data->managed;
     return !result->found;
 }
 
@@ -174,7 +177,7 @@ static BOOL has_owned_popups( HWND hwnd )
 
     result.hwnd = hwnd;
     result.found = FALSE;
-    EnumWindows( has_popup, (LPARAM)&result );
+    EnumWindows( has_managed_popup, (LPARAM)&result );
     return result.found;
 }
 
@@ -588,7 +591,7 @@ static BOOL set_win_format( HWND hwnd, XID fbconfig_id )
         XInstallColormap(gdi_display, attrib.colormap);
 
         if(data->gl_drawable) XDestroyWindow(gdi_display, data->gl_drawable);
-        data->gl_drawable = XCreateWindow(gdi_display, dummy_parent, -w, 0, w, h, 0,
+        data->gl_drawable = XCreateWindow(gdi_display, dummy_parent, 0, 0, w, h, 0,
                                           vis->depth, InputOutput, vis->visual,
                                           CWColormap | CWOverrideRedirect,
                                           &attrib);
@@ -666,7 +669,7 @@ static void sync_gl_drawable(struct x11drv_win_data *data)
     if(usexcomposite)
     {
         wine_tsx11_lock();
-        XMoveResizeWindow(gdi_display, data->gl_drawable, -w, 0, w, h);
+        XMoveResizeWindow(gdi_display, data->gl_drawable, 0, 0, w, h);
         wine_tsx11_unlock();
         return;
     }
@@ -1007,19 +1010,28 @@ static void set_mwm_hints( Display *display, struct x11drv_win_data *data, DWORD
 {
     MwmHints mwm_hints;
 
-    mwm_hints.flags = MWM_HINTS_FUNCTIONS | MWM_HINTS_DECORATIONS;
-    mwm_hints.decorations = get_mwm_decorations( data, style, ex_style );
-    mwm_hints.functions = MWM_FUNC_MOVE;
-    if (is_window_resizable( data, style )) mwm_hints.functions |= MWM_FUNC_RESIZE;
-    if (!(style & WS_DISABLED))
+    if (data->hwnd == GetDesktopWindow())
     {
-        if (style & WS_MINIMIZEBOX) mwm_hints.functions |= MWM_FUNC_MINIMIZE;
-        if (style & WS_MAXIMIZEBOX) mwm_hints.functions |= MWM_FUNC_MAXIMIZE;
-        if (style & WS_SYSMENU)     mwm_hints.functions |= MWM_FUNC_CLOSE;
+        mwm_hints.decorations = MWM_DECOR_TITLE | MWM_DECOR_BORDER | MWM_DECOR_MENU | MWM_DECOR_MINIMIZE;
+        mwm_hints.functions   = MWM_FUNC_MOVE | MWM_FUNC_MINIMIZE | MWM_FUNC_CLOSE;
     }
+    else
+    {
+        mwm_hints.decorations = get_mwm_decorations( data, style, ex_style );
+        mwm_hints.functions = MWM_FUNC_MOVE;
+        if (is_window_resizable( data, style )) mwm_hints.functions |= MWM_FUNC_RESIZE;
+        if (!(style & WS_DISABLED))
+        {
+            if (style & WS_MINIMIZEBOX) mwm_hints.functions |= MWM_FUNC_MINIMIZE;
+            if (style & WS_MAXIMIZEBOX) mwm_hints.functions |= MWM_FUNC_MAXIMIZE;
+            if (style & WS_SYSMENU)     mwm_hints.functions |= MWM_FUNC_CLOSE;
+        }
+    }
+
     TRACE( "%p setting mwm hints to %lx,%lx (style %x exstyle %x)\n",
            data->hwnd, mwm_hints.decorations, mwm_hints.functions, style, ex_style );
 
+    mwm_hints.flags = MWM_HINTS_FUNCTIONS | MWM_HINTS_DECORATIONS;
     XChangeProperty( display, data->whole_window, x11drv_atom(_MOTIF_WM_HINTS),
                      x11drv_atom(_MOTIF_WM_HINTS), 32, PropModeReplace,
                      (unsigned char*)&mwm_hints, sizeof(mwm_hints)/sizeof(long) );
@@ -1185,7 +1197,7 @@ static void set_wm_hints( Display *display, struct x11drv_win_data *data )
      * only normal windows, and doesn't handle correctly TRANSIENT_FOR hint for
      * dialogs owned by fullscreen windows.
      */
-    if ((style & WS_POPUP) && owner) window_type = x11drv_atom(_NET_WM_WINDOW_TYPE_DIALOG);
+    if (((style & WS_POPUP) || (ex_style & WS_EX_DLGMODALFRAME)) && owner) window_type = x11drv_atom(_NET_WM_WINDOW_TYPE_DIALOG);
     else window_type = x11drv_atom(_NET_WM_WINDOW_TYPE_NORMAL);
 
     XChangeProperty(display, data->whole_window, x11drv_atom(_NET_WM_WINDOW_TYPE),
@@ -2004,6 +2016,7 @@ BOOL CDECL X11DRV_CreateWindow( HWND hwnd )
         wine_tsx11_lock();
         data->clip_window = XCreateWindow( data->display, root_window, 0, 0, 1, 1, 0, 0,
                                            InputOnly, visual, CWOverrideRedirect | CWEventMask, &attr );
+        XFlush( data->display );
         wine_tsx11_unlock();
         SetPropA( hwnd, clip_window_prop, (HANDLE)data->clip_window );
     }
@@ -2260,10 +2273,7 @@ void CDECL X11DRV_GetDC( HDC hdc, HWND hwnd, HWND top, const RECT *win_rect,
     escape.dc_rect.top          = win_rect->top - top_rect->top;
     escape.dc_rect.right        = win_rect->right - top_rect->left;
     escape.dc_rect.bottom       = win_rect->bottom - top_rect->top;
-    escape.drawable_rect.left   = top_rect->left;
-    escape.drawable_rect.top    = top_rect->top;
-    escape.drawable_rect.right  = top_rect->right;
-    escape.drawable_rect.bottom = top_rect->bottom;
+    escape.drawable_rect        = *top_rect;
 
     if (top == hwnd)
     {
@@ -2534,7 +2544,10 @@ void CDECL X11DRV_WindowPosChanged( HWND hwnd, HWND insert_after, UINT swp_flags
         if (((swp_flags & SWP_HIDEWINDOW) && !(new_style & WS_VISIBLE)) ||
             (!event_type &&
              !is_window_rect_mapped( rectWindow ) && is_window_rect_mapped( &old_window_rect )))
+        {
             unmap_window( display, data );
+            if (is_window_rect_fullscreen( &old_window_rect )) reset_clipping_window();
+        }
     }
 
     /* don't change position if we are about to minimize or maximize a managed window */
@@ -2767,9 +2780,7 @@ static BOOL is_netwm_supported( Display *display, Atom atom )
 LRESULT CDECL X11DRV_SysCommand( HWND hwnd, WPARAM wparam, LPARAM lparam )
 {
     WPARAM hittest = wparam & 0x0f;
-    DWORD dwPoint;
-    int x, y, dir;
-    XEvent xev;
+    int dir;
     Display *display = thread_display();
     struct x11drv_win_data *data;
 
@@ -2821,30 +2832,6 @@ LRESULT CDECL X11DRV_SysCommand( HWND hwnd, WPARAM wparam, LPARAM lparam )
         return -1;
     }
 
-    dwPoint = GetMessagePos();
-    x = (short)LOWORD(dwPoint);
-    y = (short)HIWORD(dwPoint);
-
-    TRACE("hwnd %p, x %d, y %d, dir %d\n", hwnd, x, y, dir);
-
-    xev.xclient.type = ClientMessage;
-    xev.xclient.window = X11DRV_get_whole_window(hwnd);
-    xev.xclient.message_type = x11drv_atom(_NET_WM_MOVERESIZE);
-    xev.xclient.serial = 0;
-    xev.xclient.display = display;
-    xev.xclient.send_event = True;
-    xev.xclient.format = 32;
-    xev.xclient.data.l[0] = x - virtual_screen_rect.left; /* x coord */
-    xev.xclient.data.l[1] = y - virtual_screen_rect.top;  /* y coord */
-    xev.xclient.data.l[2] = dir; /* direction */
-    xev.xclient.data.l[3] = 1; /* button */
-    xev.xclient.data.l[4] = 0; /* unused */
-
-    /* need to ungrab the pointer that may have been automatically grabbed
-     * with a ButtonPress event */
-    wine_tsx11_lock();
-    XUngrabPointer( display, CurrentTime );
-    XSendEvent(display, root_window, False, SubstructureNotifyMask | SubstructureRedirectMask, &xev);
-    wine_tsx11_unlock();
+    move_resize_window( display, data, dir );
     return 0;
 }
