@@ -34,10 +34,10 @@ extern "C" {
  * Common FCI/TDI declarations
  */
 
-typedef unsigned long CHECKSUM;
+typedef ULONG CHECKSUM;
 
-typedef unsigned long UOFF;
-typedef unsigned long COFF;
+typedef ULONG UOFF;
+typedef ULONG COFF;
 
 /**********************************************************************/
 
@@ -50,7 +50,7 @@ typedef struct {
 /**********************************************************************/
 
 #define CB_MAX_CHUNK         32768U
-#define CB_MAX_DISK          0x7fffffffL
+#define CB_MAX_DISK          __MSABI_LONG(0x7fffffff)
 #define CB_MAX_FILENAME      256
 #define CB_MAX_CABINET_NAME  256
 #define CB_MAX_CAB_PATH      256
@@ -163,7 +163,7 @@ typedef struct {
 
 /**********************************************************************/
 
-typedef void * (__cdecl *PFNFCIALLOC)(ULONG cb);
+typedef void * (__cdecl __WINE_ALLOC_SIZE(1) *PFNFCIALLOC)(ULONG cb);
 #define FNFCIALLOC(fn) void * __cdecl fn(ULONG cb)
 
 typedef void (__cdecl *PFNFCIFREE)(void *memory);
@@ -181,8 +181,8 @@ typedef UINT (__cdecl *PFNFCIWRITE)(INT_PTR hf, void *memory, UINT cb, int *err,
 typedef int  (__cdecl *PFNFCICLOSE)(INT_PTR hf, int *err, void *pv);
 #define FNFCICLOSE(fn) int __cdecl fn(INT_PTR hf, int *err, void *pv)
 
-typedef long (__cdecl *PFNFCISEEK) (INT_PTR hf, long dist, int seektype, int *err, void *pv);
-#define FNFCISEEK(fn) long __cdecl fn(INT_PTR hf, long dist, int seektype, int *err, void *pv)
+typedef LONG (__cdecl *PFNFCISEEK) (INT_PTR hf, LONG dist, int seektype, int *err, void *pv);
+#define FNFCISEEK(fn) LONG __cdecl fn(INT_PTR hf, LONG dist, int seektype, int *err, void *pv)
 
 typedef int  (__cdecl *PFNFCIDELETE) (char *pszFile, int *err, void *pv);
 #define FNFCIDELETE(fn) int __cdecl fn(char *pszFile, int *err, void *pv)
@@ -194,12 +194,12 @@ typedef BOOL (__cdecl *PFNFCIGETNEXTCABINET)(PCCAB pccab, ULONG  cbPrevCab, void
 
 typedef int (__cdecl *PFNFCIFILEPLACED)(PCCAB pccab,
 					char *pszFile,
-					long  cbFile,
+					LONG  cbFile,
 					BOOL  fContinuation,
 					void *pv);
 #define FNFCIFILEPLACED(fn) int __cdecl fn(PCCAB pccab, \
 					   char *pszFile, \
-					   long  cbFile, \
+                                           LONG  cbFile, \
 					   BOOL  fContinuation, \
 					   void *pv)
 
@@ -220,11 +220,11 @@ typedef INT_PTR (__cdecl *PFNFCIGETOPENINFO)(char *pszName,
 #define statusFolder   1  /* Add Folder to Cabinet callback */
 #define statusCabinet  2  /* Write out a completed cabinet callback */
 
-typedef long (__cdecl *PFNFCISTATUS)(UINT typeStatus,
+typedef LONG (__cdecl *PFNFCISTATUS)(UINT typeStatus,
 				     ULONG cb1,
 				     ULONG cb2,
 				     void *pv);
-#define FNFCISTATUS(fn) long __cdecl fn(UINT typeStatus, \
+#define FNFCISTATUS(fn) LONG __cdecl fn(UINT typeStatus, \
 					ULONG  cb1, \
 					ULONG  cb2, \
 					void *pv)
