@@ -22,6 +22,8 @@
 extern "C" {
 #endif
 
+#include <lmcons.h>
+
 typedef struct _SHARE_INFO_0 {
     LMSTR shi0_netname;
 } SHARE_INFO_0, *PSHARE_INFO_0, *LPSHARE_INFO_0;
@@ -32,10 +34,15 @@ typedef struct _SHARE_INFO_1 {
     LMSTR shi1_remark;
 } SHARE_INFO_1, *PSHARE_INFO_1, *LPSHARE_INFO_1;
 
-NET_API_STATUS WINAPI NetShareDel(LMSTR servername, LMSTR netname, DWORD reserved);
-NET_API_STATUS WINAPI NetShareEnum(LMSTR servername, DWORD level,
- LPBYTE *bufptr, DWORD prefmaxlen, LPDWORD entriesread, LPDWORD totalentries,
- LPDWORD resume_handle);
+NET_API_STATUS WINAPI NetShareAdd(LMSTR,DWORD,LPBYTE,LPDWORD);
+NET_API_STATUS WINAPI NetShareCheck(LMSTR,LMSTR,LPDWORD);
+NET_API_STATUS WINAPI NetShareDel(LMSTR,LMSTR,DWORD);
+NET_API_STATUS WINAPI NetShareDelEx(LMSTR,DWORD,LPBYTE);
+NET_API_STATUS WINAPI NetShareDelSticky(LMSTR,LMSTR,DWORD);
+NET_API_STATUS WINAPI NetShareEnum(LMSTR,DWORD,LPBYTE*,DWORD,LPDWORD,LPDWORD,LPDWORD);
+NET_API_STATUS WINAPI NetShareEnumSticky(LMSTR,DWORD,LPBYTE*,DWORD,LPDWORD,LPDWORD,LPDWORD);
+NET_API_STATUS WINAPI NetShareGetInfo(LMSTR,LMSTR,DWORD,LPBYTE*);
+NET_API_STATUS WINAPI NetShareSetInfo(LMSTR,LMSTR,DWORD,LPBYTE,LPDWORD);
 
 #define STYPE_DISKTREE 0
 #define STYPE_PRINTQ   1
@@ -43,9 +50,9 @@ NET_API_STATUS WINAPI NetShareEnum(LMSTR servername, DWORD level,
 #define STYPE_IPC      3
 #define STYPE_SPECIAL  0x80000000
 
-NET_API_STATUS NET_API_FUNCTION NetSessionEnum(LMSTR servername, LMSTR UncClientName,
-    LMSTR username, DWORD level, LPBYTE *bufptr, DWORD prefmaxlen, LPDWORD entriesread,
-    LPDWORD totalentries, LPDWORD resume_handle);
+NET_API_STATUS WINAPI NetSessionDel(LMSTR,LMSTR,LMSTR);
+NET_API_STATUS WINAPI NetSessionEnum(LMSTR,LMSTR,LMSTR,DWORD,LPBYTE*,DWORD,LPDWORD,LPDWORD,LPDWORD);
+NET_API_STATUS WINAPI NetSessionGetInfo(LMSTR,LMSTR,LMSTR,DWORD,LPBYTE*);
 
 #ifdef __cplusplus
 }
