@@ -195,16 +195,16 @@ typedef enum tagMSIINSTALLCONTEXT
 
 typedef enum tagMSISOURCETYPE
 {
-    MSISOURCETYPE_UNKNOWN = 0x00000000L,
-    MSISOURCETYPE_NETWORK = 0x00000001L,
-    MSISOURCETYPE_URL     = 0x00000002L,
-    MSISOURCETYPE_MEDIA   = 0x00000004
+    MSISOURCETYPE_UNKNOWN = __MSABI_LONG(0x00000000),
+    MSISOURCETYPE_NETWORK = __MSABI_LONG(0x00000001),
+    MSISOURCETYPE_URL     = __MSABI_LONG(0x00000002),
+    MSISOURCETYPE_MEDIA   = __MSABI_LONG(0x00000004)
 } MSISOURCETYPE;
 
 typedef enum tagMSICODE
 {
-    MSICODE_PRODUCT = 0x00000000L,
-    MSICODE_PATCH = 0x40000000L
+    MSICODE_PRODUCT = __MSABI_LONG(0x00000000),
+    MSICODE_PATCH   = __MSABI_LONG(0x40000000)
 } MSICODE;
 
 typedef enum tagINSTALLFEATUREATTRIBUTE
