@@ -70,34 +70,12 @@ static inline void fill_modify_ldt_struct( struct modify_ldt_s *ptr, const LDT_E
 
 static inline int modify_ldt( int func, struct modify_ldt_s *ptr, unsigned long count )
 {
-    int res;
-    __asm__ __volatile__( "pushl %%ebx\n\t"
-                          "movl %2,%%ebx\n\t"
-                          "int $0x80\n\t"
-                          "popl %%ebx"
-                          : "=a" (res)
-                          : "0" (SYS_modify_ldt),
-                            "r" (func),
-                            "c" (ptr),
-                            "d" (count),
-                            "m" (*ptr) );
-    if (res >= 0) return res;
-    errno = -res;
-    return -1;
+    return syscall( SYS_modify_ldt, func, ptr, count );
 }
 
 static inline int set_thread_area( struct modify_ldt_s *ptr )
 {
-    int res;
-    __asm__ __volatile__( "pushl %%ebx\n\t"
-                          "movl %3,%%ebx\n\t"
-                          "int $0x80\n\t"
-                          "popl %%ebx"
-                          : "=a" (res), "=m" (*ptr)
-                          : "0" (243) /* SYS_set_thread_area */, "q" (ptr), "m" (*ptr) );
-    if (res >= 0) return res;
-    errno = -res;
-    return -1;
+    return syscall( 243 /* SYS_set_thread_area */, ptr );
 }
 
 #endif  /* linux */
@@ -406,7 +384,7 @@ unsigned short wine_ldt_alloc_fs(void)
             if (errno != ENOSYS) perror( "set_thread_area" );
         }
         else global_fs_sel = (ldt_info.entry_number << 3) | 3;
-#elif defined(__FreeBSD__)
+#elif defined(__FreeBSD__) || defined (__FreeBSD_kernel__)
         global_fs_sel = GSEL( GUFS_SEL, SEL_UPL );
 #endif
     }
@@ -434,7 +412,7 @@ void wine_ldt_init_fs( unsigned short sel, const LDT_ENTRY *entry )
         ldt_info.entry_number = sel >> 3;
         fill_modify_ldt_struct( &ldt_info, entry );
         if ((ret = set_thread_area( &ldt_info ) < 0)) perror( "set_thread_area" );
-#elif defined(__FreeBSD__)
+#elif defined(__FreeBSD__) || defined (__FreeBSD_kernel__)
         i386_set_fsbase( wine_ldt_get_base( entry ));
 #endif
     }
