@@ -24,10 +24,6 @@
 
 WINE_DEFAULT_DEBUG_CHANNEL(cmd);
 
-extern WCHAR quals[MAX_PATH], param1[MAX_PATH], param2[MAX_PATH];
-extern BATCH_CONTEXT *context;
-extern DWORD errorlevel;
-
 /****************************************************************************
  * WCMD_batch
  *
@@ -186,12 +182,12 @@ WCHAR *WCMD_parameter (WCHAR *s, int n, WCHAR **start, WCHAR **end) {
  *       NULL on error or EOF
  */
 
-WCHAR *WCMD_fgets(WCHAR *buf, int noChars, HANDLE h)
+WCHAR *WCMD_fgets(WCHAR *buf, DWORD noChars, HANDLE h)
 {
   DWORD charsRead;
   BOOL status;
   LARGE_INTEGER filepos;
-  int i;
+  DWORD i;
 
   /* We can't use the native f* functions because of the filename syntax differences
      between DOS and Unix. Also need to lose the LF (or CRLF) from the line. */
@@ -317,7 +313,6 @@ void WCMD_HandleTildaModifiers(WCHAR **start, const WCHAR *forVariable,
   static const WCHAR validmodifiers[NUMMODIFIERS] = {
         '~', 'f', 'd', 'p', 'n', 'x', 's', 'a', 't', 'z', '$'
   };
-  static const WCHAR space[] = {' ', '\0'};
 
   WIN32_FILE_ATTRIBUTE_DATA fileInfo;
   WCHAR  outputparam[MAX_PATH];
@@ -480,13 +475,13 @@ void WCMD_HandleTildaModifiers(WCHAR **start, const WCHAR *forVariable,
       int datelen;
 
       doneModifier = TRUE;
-      if (finaloutput[0] != 0x00) strcatW(finaloutput, space);
+      if (finaloutput[0] != 0x00) strcatW(finaloutput, spaceW);
 
       /* Format the time */
       FileTimeToSystemTime(&fileInfo.ftLastWriteTime, &systime);
       GetDateFormatW(LOCALE_USER_DEFAULT, DATE_SHORTDATE, &systime,
                         NULL, thisoutput, MAX_PATH);
-      strcatW(thisoutput, space);
+      strcatW(thisoutput, spaceW);
       datelen = strlenW(thisoutput);
       GetTimeFormatW(LOCALE_USER_DEFAULT, TIME_NOSECONDS, &systime,
                         NULL, (thisoutput+datelen), MAX_PATH-datelen);
@@ -502,14 +497,14 @@ void WCMD_HandleTildaModifiers(WCHAR **start, const WCHAR *forVariable,
       static const WCHAR fmt[] = {'%','u','\0'};
 
       doneModifier = TRUE;
-      if (finaloutput[0] != 0x00) strcatW(finaloutput, space);
+      if (finaloutput[0] != 0x00) strcatW(finaloutput, spaceW);
       wsprintfW(thisoutput, fmt, fullsize);
       strcatW(finaloutput, thisoutput);
     }
 
     /* 4. Handle 's' : Use short paths (File doesn't have to exist) */
     if (memchrW(firstModifier, 's', modifierLen) != NULL) {
-      if (finaloutput[0] != 0x00) strcatW(finaloutput, space);
+      if (finaloutput[0] != 0x00) strcatW(finaloutput, spaceW);
       /* Don't flag as doneModifier - %~s on its own is processed later */
       GetShortPathNameW(outputparam, outputparam, sizeof(outputparam)/sizeof(outputparam[0]));
     }
@@ -518,7 +513,7 @@ void WCMD_HandleTildaModifiers(WCHAR **start, const WCHAR *forVariable,
     /*      Note this overrides d,p,n,x                                 */
     if (memchrW(firstModifier, 'f', modifierLen) != NULL) {
       doneModifier = TRUE;
-      if (finaloutput[0] != 0x00) strcatW(finaloutput, space);
+      if (finaloutput[0] != 0x00) strcatW(finaloutput, spaceW);
       strcatW(finaloutput, fullfilename);
     } else {
 
@@ -528,7 +523,7 @@ void WCMD_HandleTildaModifiers(WCHAR **start, const WCHAR *forVariable,
       WCHAR ext[MAX_PATH];
       BOOL doneFileModifier = FALSE;
 
-      if (finaloutput[0] != 0x00) strcatW(finaloutput, space);
+      if (finaloutput[0] != 0x00) strcatW(finaloutput, spaceW);
 
       /* Split into components */
       WCMD_splitpath(fullfilename, drive, dir, fname, ext);
@@ -565,7 +560,7 @@ void WCMD_HandleTildaModifiers(WCHAR **start, const WCHAR *forVariable,
       if (!doneFileModifier &&
           memchrW(firstModifier, 's', modifierLen) != NULL) {
         doneModifier = TRUE;
-        if (finaloutput[0] != 0x00) strcatW(finaloutput, space);
+        if (finaloutput[0] != 0x00) strcatW(finaloutput, spaceW);
         strcatW(finaloutput, outputparam);
       }
     }
