@@ -26,7 +26,9 @@
  */
 
 #include "config.h"
+#include <time.h>
 #include "wcmd.h"
+#include "shellapi.h"
 #include "wine/debug.h"
 
 WINE_DEFAULT_DEBUG_CHANNEL(cmd);
@@ -42,8 +44,8 @@ int defaultColor = 7;
 BOOL echo_mode = TRUE;
 
 WCHAR anykey[100], version_string[100];
-const WCHAR newline[] = {'\r','\n','\0'};
-const WCHAR space[]   = {' ','\0'};
+const WCHAR newlineW[] = {'\r','\n','\0'};
+const WCHAR spaceW[]   = {' ','\0'};
 
 static BOOL opt_c, opt_k, opt_s, unicodeOutput = FALSE;
 
@@ -316,7 +318,7 @@ void WCMD_print_error (void) {
   WCMD_output_asis_len(lpMsgBuf, lstrlenW(lpMsgBuf),
                        GetStdHandle(STD_ERROR_HANDLE));
   LocalFree (lpMsgBuf);
-  WCMD_output_asis_len (newline, lstrlenW(newline),
+  WCMD_output_asis_len (newlineW, lstrlenW(newlineW),
                         GetStdHandle(STD_ERROR_HANDLE));
   return;
 }
@@ -725,8 +727,6 @@ static WCHAR *WCMD_expand_envvar(WCHAR *start,
         WCMD_strsubstW(start, endOfVar + 1, startCopy, substrlength);
       }
 
-      return start;
-
     /* search and replace manipulation */
     } else {
       WCHAR *equalspos = strstrW(colonpos, equalW);
@@ -786,9 +786,8 @@ static WCHAR *WCMD_expand_envvar(WCHAR *start,
       HeapFree(GetProcessHeap(), 0, s);
       HeapFree(GetProcessHeap(), 0, searchIn);
       HeapFree(GetProcessHeap(), 0, searchFor);
-      return start;
     }
-    return start+1;
+    return start;
 }
 
 /*****************************************************************************
@@ -1161,10 +1160,7 @@ void WCMD_run_program (WCHAR *command, int called) {
       launched = TRUE;
 
       /* Special case BAT and CMD */
-      if (ext && !strcmpiW(ext, batExt)) {
-        WCMD_batch (thisDir, command, called, NULL, INVALID_HANDLE_VALUE);
-        return;
-      } else if (ext && !strcmpiW(ext, cmdExt)) {
+      if (ext && (!strcmpiW(ext, batExt) || !strcmpiW(ext, cmdExt))) {
         WCMD_batch (thisDir, command, called, NULL, INVALID_HANDLE_VALUE);
         return;
       } else {
@@ -1540,6 +1536,9 @@ void WCMD_execute (const WCHAR *command, const WCHAR *redirects,
       case WCMD_SHIFT:
         WCMD_shift (p);
         break;
+      case WCMD_START:
+        WCMD_start (p);
+        break;
       case WCMD_TIME:
         WCMD_setshow_time ();
         break;
@@ -1551,7 +1550,7 @@ void WCMD_execute (const WCHAR *command, const WCHAR *redirects,
         WCMD_type (p);
 	break;
       case WCMD_VER:
-        WCMD_output_asis(newline);
+        WCMD_output_asis(newlineW);
         WCMD_version ();
         break;
       case WCMD_VERIFY:
@@ -1814,7 +1813,7 @@ WCHAR *WCMD_ReadAndParseLine(const WCHAR *optionalcmd, CMD_LIST **output, HANDLE
     if (strlenW(extraSpace) == MAXSTRING -1) {
         WCMD_output_asis_stderr(WCMD_LoadMessage(WCMD_TRUNCATEDLINE));
         WCMD_output_asis_stderr(extraSpace);
-        WCMD_output_asis_stderr(newline);
+        WCMD_output_asis_stderr(newlineW);
     }
 
     /* Replace env vars if in a batch context */
@@ -1835,9 +1834,9 @@ WCHAR *WCMD_ReadAndParseLine(const WCHAR *optionalcmd, CMD_LIST **output, HANDLE
           && CompareStringW(LOCALE_SYSTEM_DEFAULT, NORM_IGNORECASE,
                          extraSpace, min_len, echoCol, len) != CSTR_EQUAL)
       {
-          WCMD_output_asis(space);
+          WCMD_output_asis(spaceW);
       }
-      WCMD_output_asis(newline);
+      WCMD_output_asis(newlineW);
     }
 
     /* Start with an empty string, copying to the command string */
@@ -2173,7 +2172,7 @@ WCHAR *WCMD_ReadAndParseLine(const WCHAR *optionalcmd, CMD_LIST **output, HANDLE
         /* Continue to echo commands IF echo is on and in batch program */
         if (context && echo_mode && extraSpace[0] && (extraSpace[0] != '@')) {
           WCMD_output_asis(extraSpace);
-          WCMD_output_asis(newline);
+          WCMD_output_asis(newlineW);
         }
       }
     }
