@@ -25,7 +25,7 @@ WINE_DEFAULT_DEBUG_CHANNEL(winedbg);
 
 #ifdef __i386__
 
-  /* debugger/db_disasm.c */
+  /* db_disasm.c */
 extern void             be_i386_disasm_one_insn(ADDRESS64* addr, int display);
 
 #define STEP_FLAG 0x00000100 /* single step flag */
@@ -145,7 +145,7 @@ static void be_i386_all_print_context(HANDLE hThread, const CONTEXT* ctx)
                (ctx->FloatSave.StatusWord & 0x00000200) >> 9,
                (ctx->FloatSave.StatusWord & 0x00000100) >> 8);
 
-    /* Now pull out hte 3 bit of the TOP stack pointer */
+    /* Now pull out the 3 bit of the TOP stack pointer */
     dbg_printf(" TOP:%01x", (unsigned int) (ctx->FloatSave.StatusWord & 0x00003800) >> 11);
 
     /* Lets analyse the error bits and indicate the status  
@@ -354,6 +354,11 @@ static unsigned be_i386_is_function_return(const void* insn)
     BYTE ch;
 
     if (!dbg_read_memory(insn, &ch, sizeof(ch))) return FALSE;
+    if (ch == 0xF3) /* REP */
+    {
+        insn = (const char*)insn + 1;
+        if (!dbg_read_memory(insn, &ch, sizeof(ch))) return FALSE;
+    }
     return (ch == 0xC2) || (ch == 0xC3);
 }
 
@@ -772,6 +777,13 @@ static int be_i386_fetch_float(const struct dbg_lvalue* lvalue, unsigned size,
     return TRUE;
 }
 
+static int be_i386_store_integer(const struct dbg_lvalue* lvalue, unsigned size,
+                                 unsigned is_signed, LONGLONG val)
+{
+    /* this is simple as we're on a little endian CPU */
+    return memory_write_value(lvalue, size, &val);
+}
+
 struct backend_cpu be_i386 =
 {
     IMAGE_FILE_MACHINE_I386,
@@ -797,5 +809,6 @@ struct backend_cpu be_i386 =
     be_i386_adjust_pc_for_break,
     be_i386_fetch_integer,
     be_i386_fetch_float,
+    be_i386_store_integer,
 };
 #endif
