@@ -25,7 +25,15 @@
 static unsigned be_sparc_get_addr(HANDLE hThread, const CONTEXT* ctx,
                                  enum be_cpu_addr bca, ADDRESS64* addr)
 {
-    dbg_printf("not done for Sparc\n");
+    switch (bca)
+    {
+    case be_cpu_addr_pc:
+        return be_cpu_build_addr(hThread, ctx, addr, 0, ctx->pc);
+    case be_cpu_addr_stack:
+        return be_cpu_build_addr(hThread, ctx, addr, 0, ctx->o6);
+    case be_cpu_addr_frame:
+        return be_cpu_build_addr(hThread, ctx, addr, 0, ctx->i6);
+    }
     return FALSE;
 }
 
@@ -117,8 +125,13 @@ static void be_sparc_clear_watchpoint(CONTEXT* ctx, unsigned idx)
 
 static int be_sparc_adjust_pc_for_break(CONTEXT* ctx, BOOL way)
 {
-    dbg_printf("not done for Sparc\n");
-    return 0;
+    if (way)
+    {
+        ctx->pc--;
+        return -1;
+    }
+    ctx->pc++;
+    return 1;
 }
 
 static int be_sparc_fetch_integer(const struct dbg_lvalue* lvalue, unsigned size,
@@ -135,6 +148,13 @@ static int be_sparc_fetch_float(const struct dbg_lvalue* lvalue, unsigned size,
     return FALSE;
 }
 
+static int be_sparc_store_integer(const struct dbg_lvalue* lvalue, unsigned size,
+                                  unsigned is_signed, LONGLONG val)
+{
+    dbg_printf("be_sparc_store_integer: not done\n");
+    return FALSE;
+}
+
 struct backend_cpu be_sparc =
 {
     IMAGE_FILE_MACHINE_SPARC,
@@ -160,5 +180,6 @@ struct backend_cpu be_sparc =
     be_sparc_adjust_pc_for_break,
     be_sparc_fetch_integer,
     be_sparc_fetch_float,
+    be_sparc_store_integer,
 };
 #endif
