@@ -89,11 +89,11 @@ DWORD_PTR	        dbg_curr_tid = 0;
 DWORD_PTR	        dbg_curr_pid = 0;
 CONTEXT                 dbg_context;
 BOOL    	        dbg_interactiveP = FALSE;
+HANDLE                  dbg_houtput = 0;
 
 static struct list      dbg_process_list = LIST_INIT(dbg_process_list);
 
 struct dbg_internal_var         dbg_internal_vars[DBG_IV_LAST];
-static HANDLE                   dbg_houtput;
 
 static void dbg_outputA(const char* buffer, int len)
 {
@@ -668,11 +668,8 @@ int main(int argc, char** argv)
     SymSetOptions((SymGetOptions() & ~(SYMOPT_UNDNAME)) |
                   SYMOPT_LOAD_LINES | SYMOPT_DEFERRED_LOADS | SYMOPT_AUTO_PUBLICS);
 
-    if (argc && (!strcmp(argv[0], "--auto") || !strcmp(argv[0], "--minidump")))
+    if (argc && !strcmp(argv[0], "--auto"))
     {
-        /* force some internal variables */
-        DBG_IVAR(BreakOnDllLoad) = 0;
-        dbg_houtput = GetStdHandle(STD_ERROR_HANDLE);
         switch (dbg_active_auto(argc, argv))
         {
         case start_ok:          return 0;
@@ -680,6 +677,15 @@ int main(int argc, char** argv)
         case start_error_init:  return -1;
         }
     }
+    if (argc && !strcmp(argv[0], "--minidump"))
+    {
+        switch (dbg_active_minidump(argc, argv))
+        {
+        case start_ok:          return 0;
+        case start_error_parse: return dbg_winedbg_usage(FALSE);
+        case start_error_init:  return -1;
+        }
+    }
     /* parse options */
     while (argc > 0 && argv[0][0] == '-')
     {
