@@ -300,6 +300,9 @@ sub process_source_file($)
     {
       if ( /^\/\**$/ )
       {
+        # This file is used by the DLL - Make sure we get our contributors right
+        @{$spec_files{$comment->{DLL_NAME}}[0]->{CURRENT_EXTRA}} = ();
+        push (@{$spec_files{$comment->{DLL_NAME}}[0]->{SOURCES}},$comment->{FILE});
         # Found a comment start
         $comment->{COMMENT_NAME} = "";
         $comment->{ALT_NAME} = "";
@@ -419,9 +422,6 @@ sub process_source_file($)
 
     if ($parse_state == 4) # Reading in the function definition
     {
-      # This file is used by the DLL - Make sure we get our contributors right
-      push (@{$spec_files{$comment->{DLL_NAME}}[0]->{SOURCES}},$comment->{FILE});
-
       push (@{$comment->{PROTOTYPE}},$_);
       # Strip comments from the line before checking for ')'
       my $stripped_line = $_;
@@ -1132,13 +1132,12 @@ sub output_spec($)
     $percent_documented = int($percent_documented);
   }
 
-  # Make a list of the contributors to this DLL. Do this only for the source
-  # files that make up the DLL, because some directories specify multiple dlls.
+  # Make a list of the contributors to this DLL.
   my @contributors;
 
-  for (@{$spec_details->{SOURCES}})
+  foreach my $source_file (keys %source_files)
   {
-    my $source_details = $source_files{$_}[0];
+    my $source_details = $source_files{$source_file}[0];
     for (@{$source_details->{CONTRIBUTORS}})
     {
       push (@contributors, $_);
