@@ -40,16 +40,49 @@
 #include FT_SFNT_NAMES_H
 #include FT_TRUETYPE_TABLES_H
 #include FT_TRUETYPE_TAGS_H
-#ifdef HAVE_FREETYPE_INTERNAL_SFNT_H
-#include <freetype/internal/sfnt.h>
-#endif
 
 #include "wine/unicode.h"
-#include "wine/wingdi16.h"
 #include "wingdi.h"
 
 #include "pshpack1.h"
 
+typedef struct
+{
+    INT16 dfType;
+    INT16 dfPoints;
+    INT16 dfVertRes;
+    INT16 dfHorizRes;
+    INT16 dfAscent;
+    INT16 dfInternalLeading;
+    INT16 dfExternalLeading;
+    BYTE  dfItalic;
+    BYTE  dfUnderline;
+    BYTE  dfStrikeOut;
+    INT16 dfWeight;
+    BYTE  dfCharSet;
+    INT16 dfPixWidth;
+    INT16 dfPixHeight;
+    BYTE  dfPitchAndFamily;
+    INT16 dfAvgWidth;
+    INT16 dfMaxWidth;
+    BYTE  dfFirstChar;
+    BYTE  dfLastChar;
+    BYTE  dfDefaultChar;
+    BYTE  dfBreakChar;
+    INT16 dfWidthBytes;
+    LONG  dfDevice;
+    LONG  dfFace;
+    LONG  dfBitsPointer;
+    LONG  dfBitsOffset;
+    BYTE  dfReserved;
+    LONG  dfFlags;
+    INT16 dfAspace;
+    INT16 dfBspace;
+    INT16 dfCspace;
+    LONG  dfColorPointer;
+    LONG  dfReserved1[4];
+} FONTINFO16;
+
 typedef struct
 {
     WORD dfVersion;
@@ -58,6 +91,54 @@ typedef struct
     FONTINFO16 fi;
 } FNT_HEADER;
 
+typedef struct
+{
+    WORD  offset;
+    WORD  length;
+    WORD  flags;
+    WORD  id;
+    WORD  handle;
+    WORD  usage;
+} NE_NAMEINFO;
+
+typedef struct
+{
+    WORD  type_id;
+    WORD  count;
+    DWORD resloader;
+} NE_TYPEINFO;
+
+#define NE_FFLAGS_SINGLEDATA    0x0001
+#define NE_FFLAGS_MULTIPLEDATA  0x0002
+#define NE_FFLAGS_WIN32         0x0010
+#define NE_FFLAGS_FRAMEBUF      0x0100
+#define NE_FFLAGS_CONSOLE       0x0200
+#define NE_FFLAGS_GUI           0x0300
+#define NE_FFLAGS_SELFLOAD      0x0800
+#define NE_FFLAGS_LINKERROR     0x2000
+#define NE_FFLAGS_CALLWEP       0x4000
+#define NE_FFLAGS_LIBMODULE     0x8000
+
+#define NE_OSFLAGS_WINDOWS      0x02
+
+#define NE_RSCTYPE_FONTDIR            0x8007
+#define NE_RSCTYPE_FONT               0x8008
+#define NE_RSCTYPE_SCALABLE_FONTPATH  0x80cc
+
+#define NE_SEGFLAGS_DATA        0x0001
+#define NE_SEGFLAGS_ALLOCATED   0x0002
+#define NE_SEGFLAGS_LOADED      0x0004
+#define NE_SEGFLAGS_ITERATED    0x0008
+#define NE_SEGFLAGS_MOVEABLE    0x0010
+#define NE_SEGFLAGS_SHAREABLE   0x0020
+#define NE_SEGFLAGS_PRELOAD     0x0040
+#define NE_SEGFLAGS_EXECUTEONLY 0x0080
+#define NE_SEGFLAGS_READONLY    0x0080
+#define NE_SEGFLAGS_RELOC_DATA  0x0100
+#define NE_SEGFLAGS_SELFLOAD    0x0800
+#define NE_SEGFLAGS_DISCARDABLE 0x1000
+#define NE_SEGFLAGS_32BIT       0x2000
+
 typedef struct {
     WORD width;
     DWORD offset;
@@ -248,40 +329,11 @@ static int get_char(const union cptable *cptable, int enc, int index)
     return cptable->sbcs.cp2uni[index];
 }
 
-/* from gdi32/freetype.c */
-static FT_Error load_sfnt_table(FT_Face ft_face, FT_ULong table, FT_Long offset, FT_Byte *buf, FT_ULong *len)
-{
-
-    FT_Error err;
-
-    /* If the FT_Load_Sfnt_Table function is there we'll use it */
-#ifdef HAVE_FT_LOAD_SFNT_TABLE
-    err = FT_Load_Sfnt_Table(ft_face, table, offset, buf, len);
-#elif defined(HAVE_FREETYPE_INTERNAL_SFNT_H)
-    TT_Face tt_face = (TT_Face) ft_face;
-    SFNT_Interface *sfnt;
-    if (FT_Version.major==2 && FT_Version.minor==0)
-    {
-        /* 2.0.x */
-        sfnt = *(SFNT_Interface**)((char*)tt_face + 528);
-    }
-    else
-    {
-        /* A field was added in the middle of the structure in 2.1.x */
-        sfnt = *(SFNT_Interface**)((char*)tt_face + 532);
-    }
-    err = sfnt->load_any(tt_face, table, offset, buf, len);
-#else
-    err = FT_Err_Unimplemented_Feature;
-#endif
-    return err;
-}
-
 static struct fontinfo *fill_fontinfo( const char *face_name, int ppem, int enc, int dpi,
                                        unsigned char def_char, int avg_width )
 {
     FT_Face face;
-    int ascent = 0, il, el, descent = 0, width_bytes = 0, space_size, max_width = 0;
+    int ascent = 0, il, el, width_bytes = 0, space_size, max_width = 0;
     BYTE left_byte, right_byte, byte;
     DWORD start;
     int i, x, y, x_off, x_end, first_char;
@@ -314,12 +366,12 @@ static struct fontinfo *fill_fontinfo( const char *face_name, int ppem, int enc,
     assert( face->size->metrics.y_ppem == ppem );
 
     needed = 0;
-    if (load_sfnt_table(face, TTAG_EBLC, 0, NULL, &needed))
+    if (FT_Load_Sfnt_Table(face, TTAG_EBLC, 0, NULL, &needed))
         fprintf(stderr,"Can't find EBLC table\n");
     else
     {
         eblc = malloc(needed);
-        load_sfnt_table(face, TTAG_EBLC, 0, (FT_Byte *)eblc, &needed);
+        FT_Load_Sfnt_Table(face, TTAG_EBLC, 0, (FT_Byte *)eblc, &needed);
 
         num_sizes = GET_BE_DWORD(&eblc->numSizes);
 
@@ -329,7 +381,6 @@ static struct fontinfo *fill_fontinfo( const char *face_name, int ppem, int enc,
             if(size_table->hori.ascender - size_table->hori.descender == ppem)
             {
                 ascent = size_table->hori.ascender;
-                descent = -size_table->hori.descender;
                 break;
             }
             size_table++;
@@ -347,7 +398,6 @@ static struct fontinfo *fill_fontinfo( const char *face_name, int ppem, int enc,
         if(FT_Load_Char(face, 0xc5, FT_LOAD_DEFAULT))
             error("Can't find Aring\n");
         ascent = face->glyph->metrics.horiBearingY >> 6;
-        descent = ppem - ascent;
     }
 
     start = sizeof(FNT_HEADER);
@@ -497,7 +547,7 @@ static struct fontinfo *fill_fontinfo( const char *face_name, int ppem, int enc,
                 else
                     left_byte = face->glyph->bitmap.buffer[(y - (ascent - face->glyph->bitmap_top)) * face->glyph->bitmap.pitch + x - x_off - 1];
 
-                /* On the last non-trival output byte (x == x_end) have we got one or two input bytes */
+                /* On the last non-trivial output byte (x == x_end) have we got one or two input bytes */
                 if(x == x_end && (face->glyph->bitmap_left % 8 != 0) && ((face->glyph->bitmap.width % 8 == 0) || (x != (((face->glyph->bitmap.width) & ~0x7) + face->glyph->bitmap_left) / 8)))
                     right_byte = 0;
                 else
