@@ -199,6 +199,7 @@ struct options
     int force_pointer_size;
     int large_address_aware;
     int unwind_tables;
+    int strip;
     const char* wine_objdir;
     const char* output_name;
     const char* image_base;
@@ -394,10 +395,10 @@ static char *get_lib_dir( struct options *opts )
 static void compile(struct options* opts, const char* lang)
 {
     strarray* comp_args = strarray_alloc();
-    unsigned int j;
+    unsigned int i, j;
     int gcc_defs = 0;
-    char* gcc;
-    char* gpp;
+    strarray* gcc;
+    strarray* gpp;
 
     strarray_addall(comp_args, get_translator(opts));
     switch(opts->processor)
@@ -408,16 +409,19 @@ static void compile(struct options* opts, const char* lang)
 	/* mixing different C and C++ compilers isn't supported in configure anyway */
 	case proc_cc:
 	case proc_cxx:
-            gcc = build_tool_name(opts, "gcc", CC);
-            gpp = build_tool_name(opts, "g++", CXX);
+            gcc = strarray_fromstring(build_tool_name(opts, "gcc", CC), " ");
+            gpp = strarray_fromstring(build_tool_name(opts, "g++", CXX), " ");
             for ( j = 0; !gcc_defs && j < comp_args->size; j++ )
             {
                 const char *cc = comp_args->base[j];
 
-                gcc_defs = strendswith(cc, gcc) || strendswith(cc, gpp);
+                for (i = 0; !gcc_defs && i < gcc->size; i++)
+                    gcc_defs = gcc->base[i][0] != '-' && strendswith(cc, gcc->base[i]);
+                for (i = 0; !gcc_defs && i < gpp->size; i++)
+                    gcc_defs = gpp->base[i][0] != '-' && strendswith(cc, gpp->base[i]);
             }
-            free(gcc);
-            free(gpp);
+            strarray_free(gcc);
+            strarray_free(gpp);
             break;
     }
 
@@ -647,16 +651,17 @@ static const char *mingw_unicode_hack( struct options *opts )
     char *main_stub = get_temp_file( opts->output_name, ".c" );
 
     create_file( main_stub, 0644,
-                 "#include <stdarg.h>\n"
-                 "#include <windef.h>\n"
-                 "#include <winbase.h>\n"
+                 "typedef unsigned short wchar_t;\n"
+                 "extern void * __stdcall LoadLibraryA(const char *);\n"
+                 "extern void * __stdcall GetProcAddress(void *,const char *);\n"
+                 "extern int wmain( int argc, wchar_t *argv[] );\n\n"
                  "int main( int argc, char *argv[] )\n{\n"
                  "    int wargc;\n"
                  "    wchar_t **wargv, **wenv;\n"
-                 "    HMODULE msvcrt = LoadLibraryA( \"msvcrt.dll\" );\n"
-                 "    void __cdecl (*__wgetmainargs)(int *argc, wchar_t** *wargv, wchar_t** *wenvp, int expand_wildcards,\n"
-                 "                                   int *new_mode) = (void *)GetProcAddress( msvcrt, \"__wgetmainargs\" );\n"
-                 "    __wgetmainargs( &wargc, &wargv, &wenv, 0, NULL );\n"
+                 "    void *msvcrt = LoadLibraryA( \"msvcrt.dll\" );\n"
+                 "    void (*__wgetmainargs)(int *argc, wchar_t** *wargv, wchar_t** *wenvp, int expand_wildcards,\n"
+                 "                           int *new_mode) = GetProcAddress( msvcrt, \"__wgetmainargs\" );\n"
+                 "    __wgetmainargs( &wargc, &wargv, &wenv, 0, 0 );\n"
                  "    return wmain( wargc, wargv );\n}\n" );
     return compile_to_object( opts, main_stub, NULL );
 }
@@ -1009,6 +1014,8 @@ static void build(struct options* opts)
             strarray_add(link_args, "-image_base");
             strarray_add(link_args, opts->image_base);
         }
+        if (opts->strip)
+            strarray_add(link_args, "-Wl,-x");
         break;
     case PLATFORM_SOLARIS:
         {
@@ -1252,7 +1259,7 @@ int main(int argc, char **argv)
     {
         if (argv[i][0] == '-')  /* option */
 	{
-	    /* determine if tihs switch is followed by a separate argument */
+	    /* determine if this switch is followed by a separate argument */
 	    next_is_arg = 0;
 	    option_arg = 0;
 	    switch(argv[i][1])
@@ -1326,6 +1333,7 @@ int main(int argc, char **argv)
 	    {
 		case 'B':
 		    str = strdup(option_arg);
+		    if (strendswith(str, "/")) str[strlen(str) - 1] = 0;
 		    if (strendswith(str, "/tools/winebuild"))
                     {
                         char *objdir = strdup(str);
@@ -1334,7 +1342,6 @@ int main(int argc, char **argv)
                         /* don't pass it to the compiler, this generates warnings */
                         raw_compiler_arg = raw_linker_arg = 0;
                     }
-		    if (strendswith(str, "/")) str[strlen(str) - 1] = 0;
                     if (!opts.prefix) opts.prefix = strarray_alloc();
                     strarray_add(opts.prefix, str);
 		    break;
@@ -1417,6 +1424,15 @@ int main(int argc, char **argv)
 			opts.shared = 1;
                         raw_compiler_arg = raw_linker_arg = 0;
 		    }
+                    else if (strcmp("-s", argv[i]) == 0 && opts.target_platform == PLATFORM_APPLE)
+                    {
+                        /* On Mac, change -s into -Wl,-x. ld's -s switch
+                         * is deprecated, and it doesn't work on Tiger with
+                         * MH_BUNDLEs anyway
+                         */
+                        opts.strip = 1;
+                        raw_linker_arg = 0;
+                    }
                     break;
                 case 'v':
                     if (argv[i][2] == 0) verbose++;
